Crate qt_core

Crate qt_core 

Bindings for QtCore5 C++ library.

Starting guide and examples are available at https://github.com/rust-qt/examples.

This crate was generated for Qt 5.15.13. It should work with other Qt versions later than 5.15.13, but API specific to other versions will not be available.

This crate was generated by ritual. See README for more information.

Re-exports

pub use ::cpp_core;

Modules

ops
Functions that provide access to C++ operators
q_abstract_animation
C++ type: QAbstractAnimation
q_abstract_event_dispatcher
C++ type: QAbstractEventDispatcher
q_abstract_item_model
C++ type: QAbstractItemModel
q_abstract_transition
C++ type: QAbstractTransition
q_associative_iterable
C++ type: QAssociativeIterable
q_byte_array
C++ type: QByteArray
q_calendar
C++ type: QCalendar
q_cbor_array
C++ type: QCborArray
q_cbor_error
C++ type: QCborError
q_cbor_map
C++ type: QCborMap
q_cbor_stream_reader
C++ type: QCborStreamReader
q_cbor_value
C++ type: QCborValue
q_char
C++ type: QChar
q_command_line_option
C++ type: QCommandLineOption
q_command_line_parser
C++ type: QCommandLineParser
q_cryptographic_hash
C++ type: QCryptographicHash
q_data_stream
C++ type: QDataStream
q_date
C++ type: QDate
q_date_time
C++ type: QDateTime
q_deadline_timer
C++ type: QDeadlineTimer
q_debug
C++ type: QDebug
q_dir
C++ type: QDir
q_dir_iterator
C++ type: QDirIterator
q_easing_curve
C++ type: QEasingCurve
q_elapsed_timer
C++ type: QElapsedTimer
q_event
C++ type: QEvent
q_event_loop
C++ type: QEventLoop
q_file_device
C++ type: QFileDevice
q_future_of
C++ type: QFuture<void>
q_hash_of_int_q_byte_array
C++ type: QHash<int, QByteArray>
q_hash_of_q_string_q_variant
C++ type: QHash<QString, QVariant>
q_history_state
C++ type: QHistoryState
q_io_device
C++ type: QIODevice
q_item_selection_model
C++ type: QItemSelectionModel
q_json_array
C++ type: QJsonArray
q_json_document
C++ type: QJsonDocument
q_json_object
C++ type: QJsonObject
q_json_parse_error
C++ type: QJsonParseError
q_json_value
C++ type: QJsonValue
q_library
C++ type: QLibrary
q_library_info
C++ type: QLibraryInfo
q_line_f
C++ type: QLineF
q_list_of_country
C++ type: QList<QLocale::Country>
q_list_of_day_of_week
C++ type: QList<Qt::DayOfWeek>
q_list_of_int
C++ type: QList<int>
q_list_of_q_abstract_animation
C++ type: QList<QAbstractAnimation*>
q_list_of_q_abstract_item_model
C++ type: QList<QAbstractItemModel*>
q_list_of_q_abstract_state
C++ type: QList<QAbstractState*>
q_list_of_q_abstract_transition
C++ type: QList<QAbstractTransition*>
q_list_of_q_byte_array
C++ type: QList<QByteArray>
q_list_of_q_command_line_option
C++ type: QList<QCommandLineOption>
q_list_of_q_file_info
C++ type: QList<QFileInfo>
q_list_of_q_item_selection_range
C++ type: QList<QItemSelectionRange>
q_list_of_q_locale
C++ type: QList<QLocale>
q_list_of_q_mime_type
C++ type: QList<QMimeType>
q_list_of_q_model_index
C++ type: QList<QModelIndex>
q_list_of_q_object
C++ type: QList<QObject*>
q_list_of_q_pair_of_q_string_q_string
C++ type: QList<QPair<QString, QString>>
q_list_of_q_persistent_model_index
C++ type: QList<QPersistentModelIndex>
q_list_of_q_storage_info
C++ type: QList<QStorageInfo>
q_list_of_q_string
C++ type: QList<QString>
q_list_of_q_string_view
C++ type: QList<QStringView>
q_list_of_q_url
C++ type: QList<QUrl>
q_list_of_q_variant
C++ type: QList<QVariant>
q_list_of_timer_info
C++ type: QList<QAbstractEventDispatcher::TimerInfo>
q_locale
C++ type: QLocale
q_lock_file
C++ type: QLockFile
q_map_of_int_q_variant
C++ type: QMap<int, QVariant>
q_map_of_q_string_q_variant
C++ type: QMap<QString, QVariant>
q_meta_method
C++ type: QMetaMethod
q_meta_object
C++ type: QMetaObject
q_meta_type
C++ type: QMetaType
q_mime_database
C++ type: QMimeDatabase
q_mutex
C++ type: QMutex
q_operating_system_version
C++ type: QOperatingSystemVersion
q_process
C++ type: QProcess
q_random_generator
C++ type: QRandomGenerator
q_read_write_lock
C++ type: QReadWriteLock
q_reg_exp
C++ type: QRegExp
q_regular_expression
C++ type: QRegularExpression
q_resource
C++ type: QResource
q_sequential_iterable
C++ type: QSequentialIterable
q_set_of_q_abstract_state
C++ type: QSet<QAbstractState*>
q_settings
C++ type: QSettings
q_shared_memory
C++ type: QSharedMemory
q_socket_notifier
C++ type: QSocketNotifier
q_standard_paths
C++ type: QStandardPaths
q_state
C++ type: QState
q_state_machine
C++ type: QStateMachine
q_string
C++ type: QString
q_sys_info
C++ type: QSysInfo
q_system_semaphore
C++ type: QSystemSemaphore
q_text_boundary_finder
C++ type: QTextBoundaryFinder
q_text_codec
C++ type: QTextCodec
q_text_stream
C++ type: QTextStream
q_text_stream_functions
C++ namespace: QTextStreamFunctions
q_thread
C++ type: QThread
q_time_line
C++ type: QTimeLine
q_time_zone
C++ type: QTimeZone
q_url
C++ type: QUrl
q_uuid
C++ type: QUuid
q_variant
C++ type: QVariant
q_xml_stream_reader
C++ type: QXmlStreamReader

Macros

q_critical
Creates a QDebug that logs a critical message with attached information about current file, line, and module.
q_debug
Creates a QDebug that logs a debug message with attached information about current file, line, and module.
q_info
Creates a QDebug that logs an informational message with attached information about current file, line, and module.
q_init_resource
Initializes Qt resources specified by the .qrc file with the specified base name.
q_message_logger
Creates a QMessageLogger with attached information about current file, line, and module.
q_warning
Creates a QDebug that logs a warning message with attached information about current file, line, and module.

Structs

AlignmentFlag
C++ enum: Qt::AlignmentFlag.
AnchorPoint
C++ enum: Qt::AnchorPoint.
AnonymousEnumDeclQatomicCxx11H13442
C++ enum: __anonymous_EnumDecl_qatomic_cxx11_h_134_42.
AnonymousEnumDeclQatomicCxx11H16242
C++ enum: __anonymous_EnumDecl_qatomic_cxx11_h_162_42.
AnonymousEnumDeclQatomicCxx11H19142
C++ enum: __anonymous_EnumDecl_qatomic_cxx11_h_191_42.
AnonymousEnumDeclQcalendarH935
C++ enum: __anonymous_EnumDecl_qcalendar_h_93_5.
AnonymousEnumDeclQcoreapplicationH885
C++ enum: __anonymous_EnumDecl_qcoreapplication_h_88_5.
AnonymousEnumDeclQgenericatomicH5642
C++ enum: __anonymous_EnumDecl_qgenericatomic_h_56_42.
AnonymousEnumDeclQgenericatomicH5742
C++ enum: __anonymous_EnumDecl_qgenericatomic_h_57_42.
AnonymousEnumDeclQmetatypeH17625
C++ enum: __anonymous_EnumDecl_qmetatype_h_1762_5.
AnonymousEnumDeclQtimezoneH635
C++ enum: __anonymous_EnumDecl_qtimezone_h_63_5.
AnonymousEnumDeclQtypeinfoH2551
C++ enum: __anonymous_EnumDecl_qtypeinfo_h_255_1.
ApplicationAttribute
C++ enum: Qt::ApplicationAttribute.
ApplicationState
C++ enum: Qt::ApplicationState.
ArrowType
C++ enum: Qt::ArrowType.
AspectRatioMode
C++ enum: Qt::AspectRatioMode.
Axis
C++ enum: Qt::Axis.
BGMode
C++ enum: Qt::BGMode.
BrushStyle
C++ enum: Qt::BrushStyle.
CaseSensitivity
C++ enum: Qt::CaseSensitivity.
CheckState
C++ enum: Qt::CheckState.
ChecksumType
C++ enum: Qt::ChecksumType.
ClipOperation
C++ enum: Qt::ClipOperation.
ConnectionType
C++ enum: Qt::ConnectionType.
ContextMenuPolicy
C++ enum: Qt::ContextMenuPolicy.
CoordinateSystem
C++ enum: Qt::CoordinateSystem.
Corner
C++ enum: Qt::Corner.
CursorMoveStyle
C++ enum: Qt::CursorMoveStyle.
CursorShape
C++ enum: Qt::CursorShape.
DateFormat
C++ enum: Qt::DateFormat.
DayOfWeek
C++ enum: Qt::DayOfWeek.
DockWidgetArea
C++ enum: Qt::DockWidgetArea.
DockWidgetAreaSizes
C++ enum: Qt::DockWidgetAreaSizes.
DropAction
C++ enum: Qt::DropAction.
Edge
C++ enum: Qt::Edge.
EnterKeyType
C++ enum: Qt::EnterKeyType.
EventPriority
C++ enum: Qt::EventPriority.
FillRule
C++ enum: Qt::FillRule.
FindChildError
An error returned by QObject::find_child.
FindChildOption
C++ enum: Qt::FindChildOption.
FocusPolicy
C++ enum: Qt::FocusPolicy.
FocusReason
C++ enum: Qt::FocusReason.
GestureFlag
C++ enum: Qt::GestureFlag.
GestureState
C++ enum: Qt::GestureState.
GestureType
C++ enum: Qt::GestureType.
GlobalColor
C++ enum: Qt::GlobalColor.
HighDpiScaleFactorRoundingPolicy
C++ enum: Qt::HighDpiScaleFactorRoundingPolicy.
HitTestAccuracy
C++ enum: Qt::HitTestAccuracy.
ImageConversionFlag
C++ enum: Qt::ImageConversionFlag.
InputMethodHint
C++ enum: Qt::InputMethodHint.
InputMethodQuery
C++ enum: Qt::InputMethodQuery.
ItemDataRole
C++ enum: Qt::ItemDataRole.
ItemFlag
C++ enum: Qt::ItemFlag.
ItemSelectionMode
C++ enum: Qt::ItemSelectionMode.
ItemSelectionOperation
C++ enum: Qt::ItemSelectionOperation.
Key
C++ enum: Qt::Key.
KeyboardModifier
C++ enum: Qt::KeyboardModifier.
LayoutDirection
C++ enum: Qt::LayoutDirection.
MaskMode
C++ enum: Qt::MaskMode.
MatchFlag
C++ enum: Qt::MatchFlag.
Modifier
C++ enum: Qt::Modifier.
MouseButton
C++ enum: Qt::MouseButton.
MouseEventFlag
C++ enum: Qt::MouseEventFlag.
MouseEventSource
C++ enum: Qt::MouseEventSource.
NativeGestureType
C++ enum: Qt::NativeGestureType.
NavigationMode
C++ enum: Qt::NavigationMode.
Orientation
C++ enum: Qt::Orientation.
PenCapStyle
C++ enum: Qt::PenCapStyle.
PenJoinStyle
C++ enum: Qt::PenJoinStyle.
PenStyle
C++ enum: Qt::PenStyle.
QAbstractAnimation
C++ class: QAbstractAnimation.
QAbstractEventDispatcher
C++ class: QAbstractEventDispatcher.
QAbstractItemModel
C++ class: QAbstractItemModel.
QAbstractListModel
C++ class: QAbstractListModel.
QAbstractNativeEventFilter
C++ class: QAbstractNativeEventFilter.
QAbstractProxyModel
C++ class: QAbstractProxyModel.
QAbstractState
C++ class: QAbstractState.
QAbstractTableModel
C++ class: QAbstractTableModel.
QAbstractTransition
C++ class: QAbstractTransition.
QAnimationDriver
C++ class: QAnimationDriver.
QAnimationGroup
C++ class: QAnimationGroup.
QAssociativeIterable
C++ class: QAssociativeIterable.
QBasicMutex
C++ class: QBasicMutex.
QBasicTimer
C++ class: QBasicTimer.
QBitArray
C++ class: QBitArray.
QBitRef
C++ class: QBitRef.
QBox
An owning pointer for QObject-based objects.
QBuffer
C++ class: QBuffer.
QByteArray
C++ class: QByteArray.
QByteArrayMatcher
C++ class: QByteArrayMatcher.
QByteRef
C++ class: QByteRef.
QCalendar
C++ class: QCalendar.
QCborArray
C++ class: QCborArray.
QCborError
C++ class: QCborError.
QCborKnownTags
C++ enum: QCborKnownTags.
QCborMap
C++ class: QCborMap.
QCborNegativeInteger
C++ enum: QCborNegativeInteger.
QCborParserError
C++ class: QCborParserError.
QCborSimpleType
C++ enum: QCborSimpleType.
QCborStreamReader
C++ class: QCborStreamReader.
QCborStreamWriter
C++ class: QCborStreamWriter.
QCborTag
C++ enum: QCborTag.
QCborValue
C++ class: QCborValue.
QCborValueRef
C++ class: QCborValueRef.
QChar
C++ class: QChar.
QCharRef
C++ class: QCharRef.
QChildEvent
C++ class: QChildEvent.
QCollator
C++ class: QCollator.
QCollatorSortKey
C++ class: QCollatorSortKey.
QCommandLineOption
C++ class: QCommandLineOption.
QCommandLineParser
C++ class: QCommandLineParser.
QConcatenateTablesProxyModel
C++ class: QConcatenateTablesProxyModel.
QCoreApplication
C++ class: QCoreApplication.
QCoreApplicationArgs
A struct providing valid argc and argv values for Qt application objects.
QCryptographicHash
C++ class: QCryptographicHash.
QDataStream
C++ class: QDataStream.
QDate
C++ class: QDate.
QDateTime
C++ class: QDateTime.
QDeadlineTimer
C++ class: QDeadlineTimer.
QDebug
C++ class: QDebug.
QDebugShim
Provides a std::fmt::Debug implementation for types with a QDebug operator.
QDebugStateSaver
C++ class: QDebugStateSaver.
QDeferredDeleteEvent
C++ class: QDeferredDeleteEvent.
QDir
C++ class: QDir.
QDirIterator
C++ class: QDirIterator.
QDynamicPropertyChangeEvent
C++ class: QDynamicPropertyChangeEvent.
QEasingCurve
C++ class: QEasingCurve.
QElapsedTimer
C++ class: QElapsedTimer.
QEvent
C++ class: QEvent.
QEventLoop
C++ class: QEventLoop.
QEventLoopLocker
C++ class: QEventLoopLocker.
QEventTransition
C++ class: QEventTransition.
QException
C++ class: QException.
QFactoryInterface
C++ class: QFactoryInterface.
QFile
C++ class: QFile.
QFileDevice
C++ class: QFileDevice.
QFileInfo
C++ class: QFileInfo.
QFileSelector
C++ class: QFileSelector.
QFileSystemWatcher
C++ class: QFileSystemWatcher.
QFinalState
C++ class: QFinalState.
QFlags
An OR-combination of integer values of the enum type E.
QFutureOf
C++ class: QFuture<void>.
QFutureWatcherBase
C++ class: QFutureWatcherBase.
QHashOfIntQByteArray
C++ class: QHash<int, QByteArray>.
QHashOfQStringQVariant
C++ class: QHash<QString, QVariant>.
QHistoryState
C++ class: QHistoryState.
QIODevice
C++ class: QIODevice.
QIdentityProxyModel
C++ class: QIdentityProxyModel.
QItemSelection
C++ class: QItemSelection.
QItemSelectionModel
C++ class: QItemSelectionModel.
QItemSelectionRange
C++ class: QItemSelectionRange.
QJsonArray
C++ class: QJsonArray.
QJsonDocument
C++ class: QJsonDocument.
QJsonObject
C++ class: QJsonObject.
QJsonParseError
C++ class: QJsonParseError.
QJsonValue
C++ class: QJsonValue.
QJsonValueRef
C++ class: QJsonValueRef.
QLatin1Char
C++ class: QLatin1Char.
QLatin1String
C++ class: QLatin1String.
QLibrary
C++ class: QLibrary.
QLibraryInfo
C++ class: QLibraryInfo.
QLine
C++ class: QLine.
QLineF
C++ class: QLineF.
QListOfCountry
C++ class: QList<QLocale::Country>.
QListOfDayOfWeek
C++ class: QList<Qt::DayOfWeek>.
QListOfInt
C++ class: QList<int>.
QListOfQAbstractAnimation
C++ class: QList<QAbstractAnimation*>.
QListOfQAbstractItemModel
C++ class: QList<QAbstractItemModel*>.
QListOfQAbstractState
C++ class: QList<QAbstractState*>.
QListOfQAbstractTransition
C++ class: QList<QAbstractTransition*>.
QListOfQByteArray
C++ class: QList<QByteArray>.
QListOfQCommandLineOption
C++ class: QList<QCommandLineOption>.
QListOfQFileInfo
C++ class: QList<QFileInfo>.
QListOfQItemSelectionRange
C++ class: QList<QItemSelectionRange>.
QListOfQLocale
C++ class: QList<QLocale>.
QListOfQMimeType
C++ class: QList<QMimeType>.
QListOfQModelIndex
C++ class: QList<QModelIndex>.
QListOfQObject
C++ class: QList<QObject*>.
QListOfQPairOfQStringQString
C++ class: QList<QPair<QString, QString>>.
QListOfQPersistentModelIndex
C++ class: QList<QPersistentModelIndex>.
QListOfQStorageInfo
C++ class: QList<QStorageInfo>.
QListOfQString
C++ class: QList<QString>.
QListOfQStringView
C++ class: QList<QStringView>.
QListOfQUrl
C++ class: QList<QUrl>.
QListOfQVariant
C++ class: QList<QVariant>.
QListOfTimerInfo
C++ class: QList<QAbstractEventDispatcher::TimerInfo>.
QLocale
C++ class: QLocale.
QLockFile
C++ class: QLockFile.
QLoggingCategory
C++ class: QLoggingCategory.
QMapOfIntQVariant
C++ class: QMap<int, QVariant>.
QMapOfQStringQVariant
C++ class: QMap<QString, QVariant>.
QMargins
C++ class: QMargins.
QMarginsF
C++ class: QMarginsF.
QMessageAuthenticationCode
C++ class: QMessageAuthenticationCode.
QMessageLogContext
C++ class: QMessageLogContext.
QMessageLogger
C++ class: QMessageLogger.
QMetaClassInfo
C++ class: QMetaClassInfo.
QMetaEnum
C++ class: QMetaEnum.
QMetaMethod
C++ class: QMetaMethod.
QMetaObject
C++ class: QMetaObject.
QMetaProperty
C++ class: QMetaProperty.
QMetaType
C++ class: QMetaType.
QMimeData
C++ class: QMimeData.
QMimeDatabase
C++ class: QMimeDatabase.
QMimeType
C++ class: QMimeType.
QModelIndex
C++ class: QModelIndex.
QMutex
C++ class: QMutex.
QMutexLocker
C++ class: QMutexLocker.
QObject
C++ class: QObject.
QObjectCleanupHandler
C++ class: QObjectCleanupHandler.
QOperatingSystemVersion
C++ class: QOperatingSystemVersion.
QPairOfDoubleQVariant
C++ class: QPair<double, QVariant>.
QPairOfLonglongUint
C++ class: QPair<long long, unsigned int>.
QPairOfQCborValueQCborValue
C++ class: QPair<QCborValue, QCborValue>.
QPairOfQCborValueRefQCborValueRef
C++ class: QPair<QCborValueRef, QCborValueRef>.
QPairOfQStringQJsonValue
C++ class: QPair<QString, QJsonValue>.
QPairOfQStringQString
C++ class: QPair<QString, QString>.
QParallelAnimationGroup
C++ class: QParallelAnimationGroup.
QPauseAnimation
C++ class: QPauseAnimation.
QPersistentModelIndex
C++ class: QPersistentModelIndex.
QPluginLoader
C++ class: QPluginLoader.
QPoint
C++ class: QPoint.
QPointF
C++ class: QPointF.
QPointerOfQObject
C++ class: QPointer<QObject>.
QProcess
C++ class: QProcess.
QProcessEnvironment
C++ class: QProcessEnvironment.
QPropertyAnimation
C++ class: QPropertyAnimation.
QPtr
A smart pointer that automatically sets to null when the object is deleted.
QRandomGenerator
C++ class: QRandomGenerator.
QRandomGenerator64
C++ class: QRandomGenerator64.
QReadLocker
C++ class: QReadLocker.
QReadWriteLock
C++ class: QReadWriteLock.
QRect
C++ class: QRect.
QRectF
C++ class: QRectF.
QRecursiveMutex
C++ class: QRecursiveMutex.
QRegExp
C++ class: QRegExp.
QRegularExpression
C++ class: QRegularExpression.
QRegularExpressionMatch
C++ class: QRegularExpressionMatch.
QRegularExpressionMatchIterator
C++ class: QRegularExpressionMatchIterator.
QResource
C++ class: QResource.
QRunnable
C++ class: QRunnable.
QSaveFile
C++ class: QSaveFile.
QSemaphore
C++ class: QSemaphore.
QSemaphoreReleaser
C++ class: QSemaphoreReleaser.
QSequentialAnimationGroup
C++ class: QSequentialAnimationGroup.
QSequentialIterable
C++ class: QSequentialIterable.
QSetOfQAbstractState
C++ class: QSet<QAbstractState*>.
QSettings
C++ class: QSettings.
QSharedMemory
C++ class: QSharedMemory.
QSignalBlocker
C++ class: QSignalBlocker.
QSignalMapper
C++ class: QSignalMapper.
QSignalTransition
C++ class: QSignalTransition.
QSize
C++ class: QSize.
QSizeF
C++ class: QSizeF.
QSocketDescriptor
C++ class: QSocketDescriptor.
QSocketNotifier
C++ class: QSocketNotifier.
QSortFilterProxyModel
C++ class: QSortFilterProxyModel.
QStandardPaths
C++ class: QStandardPaths.
QState
C++ class: QState.
QStateMachine
C++ class: QStateMachine.
QStaticByteArrayMatcherBase
C++ class: QStaticByteArrayMatcherBase.
QStaticPlugin
C++ class: QStaticPlugin.
QStorageInfo
C++ class: QStorageInfo.
QString
C++ class: QString.
QStringList
C++ class: QStringList.
QStringListModel
C++ class: QStringListModel.
QStringMatcher
C++ class: QStringMatcher.
QStringRef
C++ class: QStringRef.
QStringView
C++ class: QStringView.
QSysInfo
C++ class: QSysInfo.
QSystemSemaphore
C++ class: QSystemSemaphore.
QTemporaryDir
C++ class: QTemporaryDir.
QTemporaryFile
C++ class: QTemporaryFile.
QTextBoundaryFinder
C++ class: QTextBoundaryFinder.
QTextCodec
C++ class: QTextCodec.
QTextDecoder
C++ class: QTextDecoder.
QTextEncoder
C++ class: QTextEncoder.
QTextStream
C++ class: QTextStream.
QTextStreamManipulator
C++ class: QTextStreamManipulator.
QThread
C++ class: QThread.
QThreadPool
C++ class: QThreadPool.
QTime
C++ class: QTime.
QTimeLine
C++ class: QTimeLine.
QTimeZone
C++ class: QTimeZone.
QTimer
C++ class: QTimer.
QTimerEvent
C++ class: QTimerEvent.
QTranslator
C++ class: QTranslator.
QTransposeProxyModel
C++ class: QTransposeProxyModel.
QUnhandledException
C++ class: QUnhandledException.
QUrl
C++ class: QUrl.
QUrlQuery
C++ class: QUrlQuery.
QUrlTwoFlagsOfUrlFormattingOptionComponentFormattingOption
C++ class: QUrlTwoFlags<QUrl::UrlFormattingOption, QUrl::ComponentFormattingOption>.
QUuid
C++ class: QUuid.
QVariant
C++ class: QVariant.
QVariantAnimation
C++ class: QVariantAnimation.
QVectorOfInt
C++ class: QVector<int>.
QVectorOfOffsetData
C++ class: QVector<QTimeZone::OffsetData>.
QVectorOfQCborValue
C++ class: QVector<QCborValue>.
QVectorOfQPairOfDoubleQVariant
C++ class: QVector<QPair<double, QVariant>>.
QVectorOfQPointF
C++ class: QVector<QPointF>.
QVectorOfQStaticPlugin
C++ class: QVector<QStaticPlugin>.
QVectorOfQStringRef
C++ class: QVector<QStringRef>.
QVectorOfQXmlStreamAttribute
C++ class: QVector<QXmlStreamAttribute>.
QVectorOfQXmlStreamEntityDeclaration
C++ class: QVector<QXmlStreamEntityDeclaration>.
QVectorOfQXmlStreamNamespaceDeclaration
C++ class: QVector<QXmlStreamNamespaceDeclaration>.
QVectorOfQXmlStreamNotationDeclaration
C++ class: QVector<QXmlStreamNotationDeclaration>.
QVectorOfUint
C++ class: QVector<unsigned int>.
QVersionNumber
C++ class: QVersionNumber.
QWaitCondition
C++ class: QWaitCondition.
QWriteLocker
C++ class: QWriteLocker.
QXmlStreamAttribute
C++ class: QXmlStreamAttribute.
QXmlStreamAttributes
C++ class: QXmlStreamAttributes.
QXmlStreamEntityDeclaration
C++ class: QXmlStreamEntityDeclaration.
QXmlStreamEntityResolver
C++ class: QXmlStreamEntityResolver.
QXmlStreamNamespaceDeclaration
C++ class: QXmlStreamNamespaceDeclaration.
QXmlStreamNotationDeclaration
C++ class: QXmlStreamNotationDeclaration.
QXmlStreamReader
C++ class: QXmlStreamReader.
QXmlStreamStringRef
C++ class: QXmlStreamStringRef.
QXmlStreamWriter
C++ class: QXmlStreamWriter.
Qfloat16
C++ class: qfloat16.
QtMsgType
C++ enum: QtMsgType.
Receiver
Reference to a particular signal or slot of a particular object.
ReturnByValueConstant
C++ enum: Qt::ReturnByValueConstant.
ScreenOrientation
C++ enum: Qt::ScreenOrientation.
ScrollBarPolicy
C++ enum: Qt::ScrollBarPolicy.
ScrollPhase
C++ enum: Qt::ScrollPhase.
ShortcutContext
C++ enum: Qt::ShortcutContext.
Signal
Reference to a particular signal of a particular object.
SignalNoArgs
Emits a Qt signal with no arguments.
SignalOfBool
Emits a Qt signal with arguments bool.
SignalOfCaseSensitivity
Emits a Qt signal with arguments crate::CaseSensitivity.
SignalOfDirection
Emits a Qt signal with arguments crate::q_abstract_animation::Direction.
SignalOfDouble
Emits a Qt signal with arguments ::std::os::raw::c_double.
SignalOfInt
Emits a Qt signal with arguments ::std::os::raw::c_int.
SignalOfIntExitStatus
Emits a Qt signal with arguments ::std::os::raw::c_int,crate::q_process::ExitStatus.
SignalOfIntInt
Emits a Qt signal with arguments ::std::os::raw::c_int,::std::os::raw::c_int.
SignalOfIntLonglong
Emits a Qt signal with arguments ::std::os::raw::c_int,::std::os::raw::c_longlong.
SignalOfLonglong
Emits a Qt signal with arguments ::std::os::raw::c_longlong.
SignalOfOrientation
Emits a Qt signal with arguments crate::Orientation.
SignalOfOrientationInt
Emits a Qt signal with arguments crate::Orientation,::std::os::raw::c_int.
SignalOfOrientationIntInt
Emits a Qt signal with arguments crate::Orientation,::std::os::raw::c_int,::std::os::raw::c_int.
SignalOfProcessError
Emits a Qt signal with arguments crate::q_process::ProcessError.
SignalOfProcessState
Emits a Qt signal with arguments crate::q_process::ProcessState.
SignalOfQAbstractAnimation
Emits a Qt signal with arguments *mut crate::QAbstractAnimation.
SignalOfQAbstractItemModel
Emits a Qt signal with arguments *mut crate::QAbstractItemModel.
SignalOfQItemSelection
Emits a Qt signal with arguments *const crate::QItemSelection.
SignalOfQItemSelectionQItemSelection
Emits a Qt signal with arguments *const crate::QItemSelection,*const crate::QItemSelection.
SignalOfQListOfQPersistentModelIndex
Emits a Qt signal with arguments *const crate::QListOfQPersistentModelIndex.
SignalOfQListOfQPersistentModelIndexLayoutChangeHint
Emits a Qt signal with arguments *const crate::QListOfQPersistentModelIndex,crate::q_abstract_item_model::LayoutChangeHint.
SignalOfQModelIndex
Emits a Qt signal with arguments *const crate::QModelIndex.
SignalOfQModelIndexInt
Emits a Qt signal with arguments *const crate::QModelIndex,::std::os::raw::c_int.
SignalOfQModelIndexIntInt
Emits a Qt signal with arguments *const crate::QModelIndex,::std::os::raw::c_int,::std::os::raw::c_int.
SignalOfQModelIndexIntIntQModelIndex
Emits a Qt signal with arguments *const crate::QModelIndex,::std::os::raw::c_int,::std::os::raw::c_int,*const crate::QModelIndex.
SignalOfQModelIndexIntIntQModelIndexInt
Emits a Qt signal with arguments *const crate::QModelIndex,::std::os::raw::c_int,::std::os::raw::c_int,*const crate::QModelIndex,::std::os::raw::c_int.
SignalOfQModelIndexQModelIndex
Emits a Qt signal with arguments *const crate::QModelIndex,*const crate::QModelIndex.
SignalOfQModelIndexQModelIndexQVectorOfInt
Emits a Qt signal with arguments *const crate::QModelIndex,*const crate::QModelIndex,*const crate::QVectorOfInt.
SignalOfQObject
Emits a Qt signal with arguments *mut crate::QObject.
SignalOfQSocketDescriptor
Emits a Qt signal with arguments *const crate::QSocketDescriptor.
SignalOfQSocketDescriptorType
Emits a Qt signal with arguments *const crate::QSocketDescriptor,crate::q_socket_notifier::Type.
SignalOfQString
Emits a Qt signal with arguments *const crate::QString.
SignalOfQVariant
Emits a Qt signal with arguments *const crate::QVariant.
SignalOfState
Emits a Qt signal with arguments crate::q_abstract_animation::State.
SignalOfState2
Emits a Qt signal with arguments crate::q_time_line::State.
SignalOfStateState
Emits a Qt signal with arguments crate::q_abstract_animation::State,crate::q_abstract_animation::State.
SizeHint
C++ enum: Qt::SizeHint.
SizeMode
C++ enum: Qt::SizeMode.
SlotNoArgs
Binds a Qt signal with no arguments to a Rust closure.
SlotOfBool
Binds a Qt signal with arguments bool to a Rust closure.
SlotOfCaseSensitivity
Binds a Qt signal with arguments crate::CaseSensitivity to a Rust closure.
SlotOfDirection
Binds a Qt signal with arguments crate::q_abstract_animation::Direction to a Rust closure.
SlotOfDouble
Binds a Qt signal with arguments ::std::os::raw::c_double to a Rust closure.
SlotOfInt
Binds a Qt signal with arguments ::std::os::raw::c_int to a Rust closure.
SlotOfIntExitStatus
Binds a Qt signal with arguments ::std::os::raw::c_int,crate::q_process::ExitStatus to a Rust closure.
SlotOfIntInt
Binds a Qt signal with arguments ::std::os::raw::c_int,::std::os::raw::c_int to a Rust closure.
SlotOfIntLonglong
Binds a Qt signal with arguments ::std::os::raw::c_int,::std::os::raw::c_longlong to a Rust closure.
SlotOfLonglong
Binds a Qt signal with arguments ::std::os::raw::c_longlong to a Rust closure.
SlotOfOrientation
Binds a Qt signal with arguments crate::Orientation to a Rust closure.
SlotOfOrientationInt
Binds a Qt signal with arguments crate::Orientation,::std::os::raw::c_int to a Rust closure.
SlotOfOrientationIntInt
Binds a Qt signal with arguments crate::Orientation,::std::os::raw::c_int,::std::os::raw::c_int to a Rust closure.
SlotOfProcessError
Binds a Qt signal with arguments crate::q_process::ProcessError to a Rust closure.
SlotOfProcessState
Binds a Qt signal with arguments crate::q_process::ProcessState to a Rust closure.
SlotOfQAbstractAnimation
Binds a Qt signal with arguments *mut crate::QAbstractAnimation to a Rust closure.
SlotOfQAbstractItemModel
Binds a Qt signal with arguments *mut crate::QAbstractItemModel to a Rust closure.
SlotOfQItemSelection
Binds a Qt signal with arguments *const crate::QItemSelection to a Rust closure.
SlotOfQItemSelectionQItemSelection
Binds a Qt signal with arguments *const crate::QItemSelection,*const crate::QItemSelection to a Rust closure.
SlotOfQListOfQPersistentModelIndex
Binds a Qt signal with arguments *const crate::QListOfQPersistentModelIndex to a Rust closure.
SlotOfQListOfQPersistentModelIndexLayoutChangeHint
Binds a Qt signal with arguments *const crate::QListOfQPersistentModelIndex,crate::q_abstract_item_model::LayoutChangeHint to a Rust closure.
SlotOfQModelIndex
Binds a Qt signal with arguments *const crate::QModelIndex to a Rust closure.
SlotOfQModelIndexInt
Binds a Qt signal with arguments *const crate::QModelIndex,::std::os::raw::c_int to a Rust closure.
SlotOfQModelIndexIntInt
Binds a Qt signal with arguments *const crate::QModelIndex,::std::os::raw::c_int,::std::os::raw::c_int to a Rust closure.
SlotOfQModelIndexIntIntQModelIndex
Binds a Qt signal with arguments *const crate::QModelIndex,::std::os::raw::c_int,::std::os::raw::c_int,*const crate::QModelIndex to a Rust closure.
SlotOfQModelIndexIntIntQModelIndexInt
Binds a Qt signal with arguments *const crate::QModelIndex,::std::os::raw::c_int,::std::os::raw::c_int,*const crate::QModelIndex,::std::os::raw::c_int to a Rust closure.
SlotOfQModelIndexQModelIndex
Binds a Qt signal with arguments *const crate::QModelIndex,*const crate::QModelIndex to a Rust closure.
SlotOfQModelIndexQModelIndexQVectorOfInt
Binds a Qt signal with arguments *const crate::QModelIndex,*const crate::QModelIndex,*const crate::QVectorOfInt to a Rust closure.
SlotOfQObject
Binds a Qt signal with arguments *mut crate::QObject to a Rust closure.
SlotOfQSocketDescriptor
Binds a Qt signal with arguments *const crate::QSocketDescriptor to a Rust closure.
SlotOfQSocketDescriptorType
Binds a Qt signal with arguments *const crate::QSocketDescriptor,crate::q_socket_notifier::Type to a Rust closure.
SlotOfQString
Binds a Qt signal with arguments *const crate::QString to a Rust closure.
SlotOfQVariant
Binds a Qt signal with arguments *const crate::QVariant to a Rust closure.
SlotOfState
Binds a Qt signal with arguments crate::q_abstract_animation::State to a Rust closure.
SlotOfState2
Binds a Qt signal with arguments crate::q_time_line::State to a Rust closure.
SlotOfStateState
Binds a Qt signal with arguments crate::q_abstract_animation::State,crate::q_abstract_animation::State to a Rust closure.
SortOrder
C++ enum: Qt::SortOrder.
SplitBehaviorFlags
C++ enum: Qt::SplitBehaviorFlags.
TabFocusBehavior
C++ enum: Qt::TabFocusBehavior.
TextElideMode
C++ enum: Qt::TextElideMode.
TextFlag
C++ enum: Qt::TextFlag.
TextFormat
C++ enum: Qt::TextFormat.
TextInteractionFlag
C++ enum: Qt::TextInteractionFlag.
TileRule
C++ enum: Qt::TileRule.
TimeSpec
C++ enum: Qt::TimeSpec.
TimerType
C++ enum: Qt::TimerType.
ToolBarArea
C++ enum: Qt::ToolBarArea.
ToolBarAreaSizes
C++ enum: Qt::ToolBarAreaSizes.
ToolButtonStyle
C++ enum: Qt::ToolButtonStyle.
TouchPointState
C++ enum: Qt::TouchPointState.
TransformationMode
C++ enum: Qt::TransformationMode.
UIEffect
C++ enum: Qt::UIEffect.
WhiteSpaceMode
C++ enum: Qt::WhiteSpaceMode.
WidgetAttribute
C++ enum: Qt::WidgetAttribute.
WindowFrameSection
C++ enum: Qt::WindowFrameSection.
WindowModality
C++ enum: Qt::WindowModality.
WindowState
C++ enum: Qt::WindowState.
WindowType
C++ enum: Qt::WindowType.

Traits

ArgumentsCompatible
Argument types compatible for signal connection.
AsReceiver
Values that can be used for specifying the receiving side of a Qt signal connection.

Functions

bin
Calls C++ function: QTextStream& Qt::bin(QTextStream& s).
bom
Calls C++ function: QTextStream& Qt::bom(QTextStream& s).
center
Calls C++ function: QTextStream& Qt::center(QTextStream& s).
dec
Calls C++ function: QTextStream& Qt::dec(QTextStream& s).
endl
Calls C++ function: QTextStream& Qt::endl(QTextStream& s).
fixed
Calls C++ function: QTextStream& Qt::fixed(QTextStream& s).
flush
Calls C++ function: QTextStream& Qt::flush(QTextStream& s).
forcepoint
Calls C++ function: QTextStream& Qt::forcepoint(QTextStream& s).
forcesign
Calls C++ function: QTextStream& Qt::forcesign(QTextStream& s).
hex
Calls C++ function: QTextStream& Qt::hex(QTextStream& s).
left
Calls C++ function: QTextStream& Qt::left(QTextStream& s).
lowercasebase
Calls C++ function: QTextStream& Qt::lowercasebase(QTextStream& s).
lowercasedigits
Calls C++ function: QTextStream& Qt::lowercasedigits(QTextStream& s).
noforcepoint
Calls C++ function: QTextStream& Qt::noforcepoint(QTextStream& s).
noforcesign
Calls C++ function: QTextStream& Qt::noforcesign(QTextStream& s).
noshowbase
Calls C++ function: QTextStream& Qt::noshowbase(QTextStream& s).
oct
Calls C++ function: QTextStream& Qt::oct(QTextStream& s).
q_acos
Calls C++ function: double qAcos(double v).
q_add_post_routine
Calls C++ function: void qAddPostRoutine(void (*FN_PTR)() arg1).
q_add_pre_routine
Calls C++ function: void qAddPreRoutine(void (*FN_PTR)() arg1).
q_app_name
Calls C++ function: QString qAppName().
q_asin
Calls C++ function: double qAsin(double v).
q_atan
Calls C++ function: double qAtan(double v).
q_atan2
Calls C++ function: double qAtan2(double y, double x).
q_ceil
Calls C++ function: int qCeil(double v).
q_checksum_2a
Calls C++ function: unsigned short qChecksum(const char* s, unsigned int len).
q_checksum_3a
Calls C++ function: unsigned short qChecksum(const char* s, unsigned int len, Qt::ChecksumType standard).
q_compress_q_byte_array
Calls C++ function: QByteArray qCompress(const QByteArray& data).
q_compress_q_byte_array_int
Calls C++ function: QByteArray qCompress(const QByteArray& data, int compressionLevel = …).
q_compress_uchar2_int
Calls C++ function: QByteArray qCompress(const unsigned char* data, int nbytes, int compressionLevel = …).
q_compress_uchar_int
Calls C++ function: QByteArray qCompress(const unsigned char* data, int nbytes).
q_cos
Calls C++ function: double qCos(double v).
q_count_leading_zero_bits_uchar
Calls C++ function: unsigned int qCountLeadingZeroBits(unsigned char v).
q_count_leading_zero_bits_uint
Calls C++ function: unsigned int qCountLeadingZeroBits(unsigned int v).
q_count_leading_zero_bits_ulong
Calls C++ function: unsigned int qCountLeadingZeroBits(unsigned long v).
q_count_leading_zero_bits_ulonglong
Calls C++ function: unsigned int qCountLeadingZeroBits(unsigned long long v).
q_count_leading_zero_bits_ushort
Calls C++ function: unsigned int qCountLeadingZeroBits(unsigned short v).
q_count_trailing_zero_bits_uchar
Calls C++ function: unsigned int qCountTrailingZeroBits(unsigned char v).
q_count_trailing_zero_bits_uint
Calls C++ function: unsigned int qCountTrailingZeroBits(unsigned int v).
q_count_trailing_zero_bits_ulong
Calls C++ function: unsigned int qCountTrailingZeroBits(unsigned long v).
q_count_trailing_zero_bits_ulonglong
Calls C++ function: unsigned int qCountTrailingZeroBits(unsigned long long v).
q_count_trailing_zero_bits_ushort
Calls C++ function: unsigned int qCountTrailingZeroBits(unsigned short v).
q_degrees_to_radians_double
Calls C++ function: double qDegreesToRadians(double degrees).
q_degrees_to_radians_float
Calls C++ function: float qDegreesToRadians(float degrees).
q_environment_variable_1a
Calls C++ function: QString qEnvironmentVariable(const char* varName).
q_environment_variable_2a
Calls C++ function: QString qEnvironmentVariable(const char* varName, const QString& defaultValue).
q_environment_variable_int_value_1a
Calls C++ function: int qEnvironmentVariableIntValue(const char* varName).
q_environment_variable_int_value_2a
Calls C++ function: int qEnvironmentVariableIntValue(const char* varName, bool* ok = …).
q_environment_variable_is_empty
Calls C++ function: bool qEnvironmentVariableIsEmpty(const char* varName).
q_environment_variable_is_set
Calls C++ function: bool qEnvironmentVariableIsSet(const char* varName).
q_exp
Calls C++ function: double qExp(double v).
q_fabs
Calls C++ function: double qFabs(double v).
q_fast_cos
Calls C++ function: double qFastCos(double x).
q_fast_sin
Calls C++ function: double qFastSin(double x).
q_float_distance_2_double
Calls C++ function: unsigned long long qFloatDistance(double a, double b).
q_float_distance_2_float
Calls C++ function: unsigned int qFloatDistance(float a, float b).
q_float_from_float16
Calls C++ function: void qFloatFromFloat16(float* arg1, const qfloat16* arg2, long long length).
q_float_to_float16
Calls C++ function: void qFloatToFloat16(qfloat16* arg1, const float* arg2, long long length).
q_floor
Calls C++ function: int qFloor(double v).
q_format_log_message
Calls C++ function: QString qFormatLogMessage(QtMsgType type, const QMessageLogContext& context, const QString& buf).
q_fp_classify_double
Calls C++ function: int qFpClassify(double val).
q_fp_classify_float
Calls C++ function: int qFpClassify(float val).
q_fp_classify_qfloat16
Calls C++ function: int qFpClassify(qfloat16 f).
q_free_aligned
Calls C++ function: void qFreeAligned(void* ptr).
q_fuzzy_compare_2_double
Calls C++ function: bool qFuzzyCompare(double p1, double p2).
q_fuzzy_compare_2_float
Calls C++ function: bool qFuzzyCompare(float p1, float p2).
q_fuzzy_compare_2_qfloat16
Calls C++ function: bool qFuzzyCompare(qfloat16 p1, qfloat16 p2).
q_fuzzy_is_null_double
Calls C++ function: bool qFuzzyIsNull(double d).
q_fuzzy_is_null_float
Calls C++ function: bool qFuzzyIsNull(float f).
q_fuzzy_is_null_qfloat16
Calls C++ function: bool qFuzzyIsNull(qfloat16 f).
q_global_q_hash_seed
Calls C++ function: int qGlobalQHashSeed().
q_hash_2_uint
Calls C++ function: unsigned int qHash(unsigned int key, unsigned int seed = …).
q_hash_bits_2a
Calls C++ function: unsigned int qHashBits(const void* p, unsigned long size).
q_hash_bits_3a
Calls C++ function: unsigned int qHashBits(const void* p, unsigned long size, unsigned int seed = …).
q_hash_char
Calls C++ function: unsigned int qHash(char key).
q_hash_char_uint
Calls C++ function: unsigned int qHash(char key, unsigned int seed = …).
q_hash_double
Calls C++ function: unsigned int qHash(double key).
q_hash_double_uint
Calls C++ function: unsigned int qHash(double key, unsigned int seed = …).
q_hash_float
Calls C++ function: unsigned int qHash(float key).
q_hash_float_uint
Calls C++ function: unsigned int qHash(float key, unsigned int seed = …).
q_hash_from_base64_result
Calls C++ function: unsigned int qHash(const QByteArray::FromBase64Result& key).
q_hash_from_base64_result_uint
Calls C++ function: unsigned int qHash(const QByteArray::FromBase64Result& key, unsigned int seed = …).
q_hash_int
Calls C++ function: unsigned int qHash(int key).
q_hash_int_uint
Calls C++ function: unsigned int qHash(int key, unsigned int seed = …).
q_hash_long
Calls C++ function: unsigned int qHash(long key).
q_hash_long_uint
Calls C++ function: unsigned int qHash(long key, unsigned int seed = …).
q_hash_longlong
Calls C++ function: unsigned int qHash(long long key).
q_hash_longlong_uint
Calls C++ function: unsigned int qHash(long long key, unsigned int seed = …).
q_hash_q_bit_array
Calls C++ function: unsigned int qHash(const QBitArray& key).
q_hash_q_bit_array_uint
Calls C++ function: unsigned int qHash(const QBitArray& key, unsigned int seed = …).
q_hash_q_byte_array
Calls C++ function: unsigned int qHash(const QByteArray& key).
q_hash_q_byte_array_uint
Calls C++ function: unsigned int qHash(const QByteArray& key, unsigned int seed = …).
q_hash_q_cbor_array
Calls C++ function: unsigned int qHash(const QCborArray& array).
q_hash_q_cbor_array_uint
Calls C++ function: unsigned int qHash(const QCborArray& array, unsigned int seed = …).
q_hash_q_cbor_map
Calls C++ function: unsigned int qHash(const QCborMap& map).
q_hash_q_cbor_map_uint
Calls C++ function: unsigned int qHash(const QCborMap& map, unsigned int seed = …).
q_hash_q_cbor_simple_type
Calls C++ function: unsigned int qHash(QCborSimpleType tag).
q_hash_q_cbor_simple_type_uint
Calls C++ function: unsigned int qHash(QCborSimpleType tag, unsigned int seed = …).
q_hash_q_cbor_tag
Calls C++ function: unsigned int qHash(QCborTag tag).
q_hash_q_cbor_tag_uint
Calls C++ function: unsigned int qHash(QCborTag tag, unsigned int seed = …).
q_hash_q_cbor_value
Calls C++ function: unsigned int qHash(const QCborValue& value).
q_hash_q_cbor_value_uint
Calls C++ function: unsigned int qHash(const QCborValue& value, unsigned int seed = …).
q_hash_q_char
Calls C++ function: unsigned int qHash(QChar key).
q_hash_q_char_uint
Calls C++ function: unsigned int qHash(QChar key, unsigned int seed = …).
q_hash_q_date
Calls C++ function: unsigned int qHash(const QDate& key).
q_hash_q_date_time
Calls C++ function: unsigned int qHash(const QDateTime& key).
q_hash_q_date_time_uint
Calls C++ function: unsigned int qHash(const QDateTime& key, unsigned int seed = …).
q_hash_q_date_uint
Calls C++ function: unsigned int qHash(const QDate& key, unsigned int seed = …).
q_hash_q_hash_of_int_q_byte_array
Calls C++ function: unsigned int qHash(const QHash<int, QByteArray>& key).
q_hash_q_hash_of_int_q_byte_array_uint
Calls C++ function: unsigned int qHash(const QHash<int, QByteArray>& key, unsigned int seed = …).
q_hash_q_item_selection_range
Calls C++ function: unsigned int qHash(const QItemSelectionRange& arg1).
q_hash_q_json_array
Calls C++ function: unsigned int qHash(const QJsonArray& array).
q_hash_q_json_array_uint
Calls C++ function: unsigned int qHash(const QJsonArray& array, unsigned int seed = …).
q_hash_q_json_object
Calls C++ function: unsigned int qHash(const QJsonObject& object).
q_hash_q_json_object_uint
Calls C++ function: unsigned int qHash(const QJsonObject& object, unsigned int seed = …).
q_hash_q_json_value
Calls C++ function: unsigned int qHash(const QJsonValue& value).
q_hash_q_json_value_uint
Calls C++ function: unsigned int qHash(const QJsonValue& value, unsigned int seed = …).
q_hash_q_latin1_string
Calls C++ function: unsigned int qHash(QLatin1String key).
q_hash_q_latin1_string_uint
Calls C++ function: unsigned int qHash(QLatin1String key, unsigned int seed = …).
q_hash_q_list_of_country
Calls C++ function: unsigned int qHash(const QList<QLocale::Country>& key).
q_hash_q_list_of_country_uint
Calls C++ function: unsigned int qHash(const QList<QLocale::Country>& key, unsigned int seed = …).
q_hash_q_list_of_day_of_week
Calls C++ function: unsigned int qHash(const QList<Qt::DayOfWeek>& key).
q_hash_q_list_of_day_of_week_uint
Calls C++ function: unsigned int qHash(const QList<Qt::DayOfWeek>& key, unsigned int seed = …).
q_hash_q_list_of_int
Calls C++ function: unsigned int qHash(const QList<int>& key).
q_hash_q_list_of_int_uint
Calls C++ function: unsigned int qHash(const QList<int>& key, unsigned int seed = …).
q_hash_q_list_of_q_abstract_animation
Calls C++ function: unsigned int qHash(const QList<QAbstractAnimation*>& key).
q_hash_q_list_of_q_abstract_animation_uint
Calls C++ function: unsigned int qHash(const QList<QAbstractAnimation*>& key, unsigned int seed = …).
q_hash_q_list_of_q_abstract_item_model
Calls C++ function: unsigned int qHash(const QList<QAbstractItemModel*>& key).
q_hash_q_list_of_q_abstract_item_model_uint
Calls C++ function: unsigned int qHash(const QList<QAbstractItemModel*>& key, unsigned int seed = …).
q_hash_q_list_of_q_abstract_state
Calls C++ function: unsigned int qHash(const QList<QAbstractState*>& key).
q_hash_q_list_of_q_abstract_state_uint
Calls C++ function: unsigned int qHash(const QList<QAbstractState*>& key, unsigned int seed = …).
q_hash_q_list_of_q_abstract_transition
Calls C++ function: unsigned int qHash(const QList<QAbstractTransition*>& key).
q_hash_q_list_of_q_abstract_transition_uint
Calls C++ function: unsigned int qHash(const QList<QAbstractTransition*>& key, unsigned int seed = …).
q_hash_q_list_of_q_byte_array
Calls C++ function: unsigned int qHash(const QList<QByteArray>& key).
q_hash_q_list_of_q_byte_array_uint
Calls C++ function: unsigned int qHash(const QList<QByteArray>& key, unsigned int seed = …).
q_hash_q_list_of_q_item_selection_range
Calls C++ function: unsigned int qHash(const QList<QItemSelectionRange>& key).
q_hash_q_list_of_q_item_selection_range_uint
Calls C++ function: unsigned int qHash(const QList<QItemSelectionRange>& key, unsigned int seed = …).
q_hash_q_list_of_q_locale
Calls C++ function: unsigned int qHash(const QList<QLocale>& key).
q_hash_q_list_of_q_locale_uint
Calls C++ function: unsigned int qHash(const QList<QLocale>& key, unsigned int seed = …).
q_hash_q_list_of_q_mime_type
Calls C++ function: unsigned int qHash(const QList<QMimeType>& key).
q_hash_q_list_of_q_mime_type_uint
Calls C++ function: unsigned int qHash(const QList<QMimeType>& key, unsigned int seed = …).
q_hash_q_list_of_q_model_index
Calls C++ function: unsigned int qHash(const QList<QModelIndex>& key).
q_hash_q_list_of_q_model_index_uint
Calls C++ function: unsigned int qHash(const QList<QModelIndex>& key, unsigned int seed = …).
q_hash_q_list_of_q_object
Calls C++ function: unsigned int qHash(const QList<QObject*>& key).
q_hash_q_list_of_q_object_uint
Calls C++ function: unsigned int qHash(const QList<QObject*>& key, unsigned int seed = …).
q_hash_q_list_of_q_pair_of_q_string_q_string
Calls C++ function: unsigned int qHash(const QList<QPair<QString, QString>>& key).
q_hash_q_list_of_q_pair_of_q_string_q_string_uint
Calls C++ function: unsigned int qHash(const QList<QPair<QString, QString>>& key, unsigned int seed = …).
q_hash_q_list_of_q_persistent_model_index
Calls C++ function: unsigned int qHash(const QList<QPersistentModelIndex>& key).
q_hash_q_list_of_q_persistent_model_index_uint
Calls C++ function: unsigned int qHash(const QList<QPersistentModelIndex>& key, unsigned int seed = …).
q_hash_q_list_of_q_string
Calls C++ function: unsigned int qHash(const QList<QString>& key).
q_hash_q_list_of_q_string_uint
Calls C++ function: unsigned int qHash(const QList<QString>& key, unsigned int seed = …).
q_hash_q_list_of_q_string_view
Calls C++ function: unsigned int qHash(const QList<QStringView>& key).
q_hash_q_list_of_q_string_view_uint
Calls C++ function: unsigned int qHash(const QList<QStringView>& key, unsigned int seed = …).
q_hash_q_list_of_q_url
Calls C++ function: unsigned int qHash(const QList<QUrl>& key).
q_hash_q_list_of_q_url_uint
Calls C++ function: unsigned int qHash(const QList<QUrl>& key, unsigned int seed = …).
q_hash_q_locale
Calls C++ function: unsigned int qHash(const QLocale& key).
q_hash_q_locale_uint
Calls C++ function: unsigned int qHash(const QLocale& key, unsigned int seed = …).
q_hash_q_mime_type
Calls C++ function: unsigned int qHash(const QMimeType& key).
q_hash_q_mime_type_uint
Calls C++ function: unsigned int qHash(const QMimeType& key, unsigned int seed = …).
q_hash_q_model_index
Calls C++ function: unsigned int qHash(const QModelIndex& index).
q_hash_q_pair_of_longlong_uint
Calls C++ function: unsigned int qHash(const QPair<long long, unsigned int>& key).
q_hash_q_pair_of_longlong_uint_uint
Calls C++ function: unsigned int qHash(const QPair<long long, unsigned int>& key, unsigned int seed = …).
q_hash_q_pair_of_q_cbor_value_q_cbor_value
Calls C++ function: unsigned int qHash(const QPair<QCborValue, QCborValue>& key).
q_hash_q_pair_of_q_cbor_value_q_cbor_value_uint
Calls C++ function: unsigned int qHash(const QPair<QCborValue, QCborValue>& key, unsigned int seed = …).
q_hash_q_pair_of_q_cbor_value_ref_q_cbor_value_ref
Calls C++ function: unsigned int qHash(const QPair<QCborValueRef, QCborValueRef>& key).
q_hash_q_pair_of_q_cbor_value_ref_q_cbor_value_ref_uint
Calls C++ function: unsigned int qHash(const QPair<QCborValueRef, QCborValueRef>& key, unsigned int seed = …).
q_hash_q_pair_of_q_string_q_json_value
Calls C++ function: unsigned int qHash(const QPair<QString, QJsonValue>& key).
q_hash_q_pair_of_q_string_q_json_value_uint
Calls C++ function: unsigned int qHash(const QPair<QString, QJsonValue>& key, unsigned int seed = …).
q_hash_q_pair_of_q_string_q_string
Calls C++ function: unsigned int qHash(const QPair<QString, QString>& key).
q_hash_q_pair_of_q_string_q_string_uint
Calls C++ function: unsigned int qHash(const QPair<QString, QString>& key, unsigned int seed = …).
q_hash_q_persistent_model_index
Calls C++ function: unsigned int qHash(const QPersistentModelIndex& index).
q_hash_q_persistent_model_index_uint
Calls C++ function: unsigned int qHash(const QPersistentModelIndex& index, unsigned int seed = …).
q_hash_q_reg_exp
Calls C++ function: unsigned int qHash(const QRegExp& key).
q_hash_q_reg_exp_uint
Calls C++ function: unsigned int qHash(const QRegExp& key, unsigned int seed = …).
q_hash_q_regular_expression
Calls C++ function: unsigned int qHash(const QRegularExpression& key).
q_hash_q_regular_expression_uint
Calls C++ function: unsigned int qHash(const QRegularExpression& key, unsigned int seed = …).
q_hash_q_set_of_q_abstract_state
Calls C++ function: unsigned int qHash(const QSet<QAbstractState*>& key).
q_hash_q_set_of_q_abstract_state_uint
Calls C++ function: unsigned int qHash(const QSet<QAbstractState*>& key, unsigned int seed = …).
q_hash_q_string
Calls C++ function: unsigned int qHash(const QString& key).
q_hash_q_string_ref
Calls C++ function: unsigned int qHash(const QStringRef& key).
q_hash_q_string_ref_uint
Calls C++ function: unsigned int qHash(const QStringRef& key, unsigned int seed = …).
q_hash_q_string_uint
Calls C++ function: unsigned int qHash(const QString& key, unsigned int seed = …).
q_hash_q_string_view
Calls C++ function: unsigned int qHash(QStringView key).
q_hash_q_string_view_uint
Calls C++ function: unsigned int qHash(QStringView key, unsigned int seed = …).
q_hash_q_time
Calls C++ function: unsigned int qHash(const QTime& key).
q_hash_q_time_uint
Calls C++ function: unsigned int qHash(const QTime& key, unsigned int seed = …).
q_hash_q_url
Calls C++ function: unsigned int qHash(const QUrl& url).
q_hash_q_url_query
Calls C++ function: unsigned int qHash(const QUrlQuery& key).
q_hash_q_url_query_uint
Calls C++ function: unsigned int qHash(const QUrlQuery& key, unsigned int seed = …).
q_hash_q_url_uint
Calls C++ function: unsigned int qHash(const QUrl& url, unsigned int seed = …).
q_hash_q_uuid
Calls C++ function: unsigned int qHash(const QUuid& uuid).
q_hash_q_uuid_uint
Calls C++ function: unsigned int qHash(const QUuid& uuid, unsigned int seed = …).
q_hash_q_vector_of_int
Calls C++ function: unsigned int qHash(const QVector<int>& key).
q_hash_q_vector_of_int_uint
Calls C++ function: unsigned int qHash(const QVector<int>& key, unsigned int seed = …).
q_hash_q_vector_of_q_cbor_value
Calls C++ function: unsigned int qHash(const QVector<QCborValue>& key).
q_hash_q_vector_of_q_cbor_value_uint
Calls C++ function: unsigned int qHash(const QVector<QCborValue>& key, unsigned int seed = …).
q_hash_q_vector_of_q_string_ref
Calls C++ function: unsigned int qHash(const QVector<QStringRef>& key).
q_hash_q_vector_of_q_string_ref_uint
Calls C++ function: unsigned int qHash(const QVector<QStringRef>& key, unsigned int seed = …).
q_hash_q_vector_of_uint
Calls C++ function: unsigned int qHash(const QVector<unsigned int>& key).
q_hash_q_vector_of_uint_uint
Calls C++ function: unsigned int qHash(const QVector<unsigned int>& key, unsigned int seed = …).
q_hash_q_version_number
Calls C++ function: unsigned int qHash(const QVersionNumber& key).
q_hash_q_version_number_uint
Calls C++ function: unsigned int qHash(const QVersionNumber& key, unsigned int seed = …).
q_hash_schar
Calls C++ function: unsigned int qHash(signed char key).
q_hash_schar_uint
Calls C++ function: unsigned int qHash(signed char key, unsigned int seed = …).
q_hash_short
Calls C++ function: unsigned int qHash(short key).
q_hash_short_uint
Calls C++ function: unsigned int qHash(short key, unsigned int seed = …).
q_hash_uchar
Calls C++ function: unsigned int qHash(unsigned char key).
q_hash_uchar_uint
Calls C++ function: unsigned int qHash(unsigned char key, unsigned int seed = …).
q_hash_uint
Calls C++ function: unsigned int qHash(unsigned int key).
q_hash_ulong
Calls C++ function: unsigned int qHash(unsigned long key).
q_hash_ulong_uint
Calls C++ function: unsigned int qHash(unsigned long key, unsigned int seed = …).
q_hash_ulonglong
Calls C++ function: unsigned int qHash(unsigned long long key).
q_hash_ulonglong_uint
Calls C++ function: unsigned int qHash(unsigned long long key, unsigned int seed = …).
q_hash_ushort
Calls C++ function: unsigned int qHash(unsigned short key).
q_hash_ushort_uint
Calls C++ function: unsigned int qHash(unsigned short key, unsigned int seed = …).
q_inf
Calls C++ function: double qInf().
q_int_cast_double
Calls C++ function: int qIntCast(double f).
q_int_cast_float
Calls C++ function: int qIntCast(float f).
q_int_cast_qfloat16
Calls C++ function: int qIntCast(qfloat16 f).
q_is_finite_double
Calls C++ function: bool qIsFinite(double d).
q_is_finite_float
Calls C++ function: bool qIsFinite(float f).
q_is_finite_qfloat16
Calls C++ function: bool qIsFinite(qfloat16 f).
q_is_inf_double
Calls C++ function: bool qIsInf(double d).
q_is_inf_float
Calls C++ function: bool qIsInf(float f).
q_is_inf_qfloat16
Calls C++ function: bool qIsInf(qfloat16 f).
q_is_nan_double
Calls C++ function: bool qIsNaN(double d).
q_is_nan_float
Calls C++ function: bool qIsNaN(float f).
q_is_nan_qfloat16
Calls C++ function: bool qIsNaN(qfloat16 f).
q_is_null_double
Calls C++ function: bool qIsNull(double d).
q_is_null_float
Calls C++ function: bool qIsNull(float f).
q_is_null_qfloat16
Calls C++ function: bool qIsNull(qfloat16 f).
q_ln
Calls C++ function: double qLn(double v).
q_make_pair_2_q_cbor_value
Calls C++ function: QPair<QCborValue, QCborValue> qMakePair(const QCborValue& x, const QCborValue& y).
q_make_pair_2_q_cbor_value_ref
Calls C++ function: QPair<QCborValueRef, QCborValueRef> qMakePair(const QCborValueRef& x, const QCborValueRef& y).
q_make_pair_2_q_string
Calls C++ function: QPair<QString, QString> qMakePair(const QString& x, const QString& y).
q_make_pair_double_q_variant
Calls C++ function: QPair<double, QVariant> qMakePair(const double& x, const QVariant& y).
q_make_pair_longlong_uint
Calls C++ function: QPair<long long, unsigned int> qMakePair(const long long& x, const unsigned int& y).
q_make_pair_q_string_q_json_value
Calls C++ function: QPair<QString, QJsonValue> qMakePair(const QString& x, const QJsonValue& y).
q_malloc_aligned
Calls C++ function: void* qMallocAligned(unsigned long size, unsigned long alignment).
q_next_power_of_two_int
Calls C++ function: unsigned int qNextPowerOfTwo(int v).
q_next_power_of_two_longlong
Calls C++ function: unsigned long long qNextPowerOfTwo(long long v).
q_next_power_of_two_uint
Calls C++ function: unsigned int qNextPowerOfTwo(unsigned int v).
q_next_power_of_two_ulonglong
Calls C++ function: unsigned long long qNextPowerOfTwo(unsigned long long v).
q_plugin_arch_requirements
Calls C++ function: unsigned char qPluginArchRequirements().
q_pointer_from_variant_q_object
Calls C++ function: QPointer<QObject> qPointerFromVariant<QObject>(const QVariant& variant).
q_population_count_uchar
Calls C++ function: unsigned int qPopulationCount(unsigned char v).
q_population_count_uint
Calls C++ function: unsigned int qPopulationCount(unsigned int v).
q_population_count_ulong
Calls C++ function: unsigned int qPopulationCount(unsigned long v).
q_population_count_ulonglong
Calls C++ function: unsigned int qPopulationCount(unsigned long long v).
q_population_count_ushort
Calls C++ function: unsigned int qPopulationCount(unsigned short v).
q_pow
Calls C++ function: double qPow(double x, double y).
q_q_nan
Calls C++ function: double qQNaN().
q_radians_to_degrees_double
Calls C++ function: double qRadiansToDegrees(double radians).
q_radians_to_degrees_float
Calls C++ function: float qRadiansToDegrees(float radians).
q_realloc_aligned
Calls C++ function: void* qReallocAligned(void* ptr, unsigned long size, unsigned long oldsize, unsigned long alignment).
q_register_static_plugin_function
Calls C++ function: void qRegisterStaticPluginFunction(QStaticPlugin staticPlugin).
q_remove_post_routine
Calls C++ function: void qRemovePostRoutine(void (*FN_PTR)() arg1).
q_round64_double
Calls C++ function: long long qRound64(double d).
q_round64_float
Calls C++ function: long long qRound64(float d).
q_round64_qfloat16
Calls C++ function: long long qRound64(qfloat16 d).
q_round_double
Calls C++ function: int qRound(double d).
q_round_float
Calls C++ function: int qRound(float d).
q_round_qfloat16
Calls C++ function: int qRound(qfloat16 d).
q_s_nan
Calls C++ function: double qSNaN().
q_set_global_q_hash_seed
Calls C++ function: void qSetGlobalQHashSeed(int newSeed).
q_set_message_pattern
Calls C++ function: void qSetMessagePattern(const QString& messagePattern).
q_shared_build
Calls C++ function: bool qSharedBuild().
q_sin
Calls C++ function: double qSin(double v).
q_sqrt
Calls C++ function: double qSqrt(double v).
q_tan
Calls C++ function: double qTan(double v).
q_uncompress_1a
Calls C++ function: QByteArray qUncompress(const QByteArray& data).
q_uncompress_2a
Calls C++ function: QByteArray qUncompress(const unsigned char* data, int nbytes).
qbswap_double
Calls C++ function: double qbswap(double source).
qbswap_float
Calls C++ function: float qbswap(float source).
qbswap_int
Calls C++ function: int qbswap(int source).
qbswap_longlong
Calls C++ function: long long qbswap(long long source).
qbswap_qfloat16
Calls C++ function: qfloat16 qbswap(qfloat16 source).
qbswap_schar
Calls C++ function: signed char qbswap(signed char source).
qbswap_short
Calls C++ function: short qbswap(short source).
qbswap_uchar
Calls C++ function: unsigned char qbswap(unsigned char source).
qbswap_uint
Calls C++ function: unsigned int qbswap(unsigned int source).
qbswap_ulonglong
Calls C++ function: unsigned long long qbswap(unsigned long long source).
qbswap_ushort
Calls C++ function: unsigned short qbswap(unsigned short source).
qdbg
Returns an object that implements std::fmt::Debug for a value that has a QDebug operator.
qgetenv
Calls C++ function: QByteArray qgetenv(const char* varName).
qputenv
Calls C++ function: bool qputenv(const char* varName, const QByteArray& value).
qrand
Calls C++ function: int qrand().
qs
Creates a QString from a Rust string.
qsrand
Calls C++ function: void qsrand(unsigned int seed).
qstrcmp_2_char
Calls C++ function: int qstrcmp(const char* str1, const char* str2).
qstrcmp_2_q_byte_array
Calls C++ function: int qstrcmp(const QByteArray& str1, const QByteArray& str2).
qstrcmp_char_q_byte_array
Calls C++ function: int qstrcmp(const char* str1, const QByteArray& str2).
qstrcmp_q_byte_array_char
Calls C++ function: int qstrcmp(const QByteArray& str1, const char* str2).
qstrcpy
Calls C++ function: char* qstrcpy(char* dst, const char* src).
qstrdup
Calls C++ function: char* qstrdup(const char* arg1).
qstricmp
Calls C++ function: int qstricmp(const char* arg1, const char* arg2).
qstrlen
Calls C++ function: unsigned int qstrlen(const char* str).
qstrncmp
Calls C++ function: int qstrncmp(const char* str1, const char* str2, unsigned int len).
qstrncpy
Calls C++ function: char* qstrncpy(char* dst, const char* src, unsigned int len).
qstrnicmp_2_char_uint
Calls C++ function: int qstrnicmp(const char* arg1, const char* arg2, unsigned int len).
qstrnicmp_char_longlong_char
Calls C++ function: int qstrnicmp(const char* arg1, long long arg2, const char* arg3).
qstrnicmp_char_longlong_char_longlong
Calls C++ function: int qstrnicmp(const char* arg1, long long arg2, const char* arg3, long long arg4 = …).
qstrnlen
Calls C++ function: unsigned int qstrnlen(const char* str, unsigned int maxlen).
qt_get_qt_meta_object
Calls C++ function: const QMetaObject* qt_getQtMetaObject().
qt_message_output
Calls C++ function: void qt_message_output(QtMsgType arg1, const QMessageLogContext& context, const QString& message).
qt_q_meta_enum_debug_operator
Calls C++ function: QDebug qt_QMetaEnum_debugOperator(QDebug& arg1, int value, const QMetaObject* meta, const char* name).
qt_q_meta_enum_flag_debug_operator_3a
Calls C++ function: void qt_QMetaEnum_flagDebugOperator(QDebug& debug, unsigned long sizeofT, int value).
qt_q_meta_enum_flag_debug_operator_4a
Calls C++ function: QDebug qt_QMetaEnum_flagDebugOperator(QDebug& dbg, unsigned long long value, const QMetaObject* meta, const char* name).
qt_tr_id_1a
Calls C++ function: QString qtTrId(const char* id).
qt_tr_id_2a
Calls C++ function: QString qtTrId(const char* id, int n = …).
qunsetenv
Calls C++ function: bool qunsetenv(const char* varName).
reset
Calls C++ function: QTextStream& Qt::reset(QTextStream& s).
right
Calls C++ function: QTextStream& Qt::right(QTextStream& s).
scientific
Calls C++ function: QTextStream& Qt::scientific(QTextStream& s).
showbase
Calls C++ function: QTextStream& Qt::showbase(QTextStream& s).
uppercasebase
Calls C++ function: QTextStream& Qt::uppercasebase(QTextStream& s).
uppercasedigits
Calls C++ function: QTextStream& Qt::uppercasedigits(QTextStream& s).
ws
Calls C++ function: QTextStream& Qt::ws(QTextStream& s).

Attribute Macros

slot
Generates a method that returns a slot object bound to self.