PenJoinStyle

Struct PenJoinStyle 

pub struct PenJoinStyle(/* private fields */);
This enum type defines the pen join styles supported by Qt, i.e. which joins between two connected lines can be drawn using QPainter.

C++ enum: Qt::PenJoinStyle.

C++ documentation:

This enum type defines the pen join styles supported by Qt, i.e. which joins between two connected lines can be drawn using QPainter.

Qt::BevelJoinQt::MiterJoinQt::RoundJoin

See also QPen.

Implementations

Source

impl PenJoinStyle

pub fn to_int(&self) -> c_int

Source

impl PenJoinStyle

pub const MiterJoin: PenJoinStyle

The outer edges of the lines are extended to meet at an angle, and this area is filled. (C++ enum variant: MiterJoin = 0)

pub const BevelJoin: PenJoinStyle

The triangular notch between the two lines is filled. (C++ enum variant: BevelJoin = 64)

pub const RoundJoin: PenJoinStyle

A circular arc between the two lines is filled. (C++ enum variant: RoundJoin = 128)

pub const SvgMiterJoin: PenJoinStyle

A miter join corresponding to the definition of a miter join in the SVG 1.2 Tiny specification. (C++ enum variant: SvgMiterJoin = 256)

pub const MPenJoinStyle: PenJoinStyle

C++ enum variant: MPenJoinStyle = 448