QAbstractEventDispatcher

Struct QAbstractEventDispatcher 

pub struct QAbstractEventDispatcher { /* private fields */ }
C++ class: QAbstractEventDispatcher.

Implementations

Source

impl QAbstractEventDispatcher

pub fn about_to_block(&self) -> Signal<()>

Returns a built-in Qt signal QAbstractEventDispatcher::aboutToBlock that can be passed to qt_core::Signal::connect.

pub fn awake(&self) -> Signal<()>

Returns a built-in Qt signal QAbstractEventDispatcher::awake that can be passed to qt_core::Signal::connect.

pub unsafe fn closing_down(&self)

Calls C++ function: virtual void QAbstractEventDispatcher::closingDown().

pub unsafe fn filter_native_event( &self, event_type: impl CastInto<Ref<QByteArray>>, message: *mut c_void, result: *mut c_long, ) -> bool

Calls C++ function: bool QAbstractEventDispatcher::filterNativeEvent(const QByteArray& eventType, void* message, long* result).

pub unsafe fn flush(&self)

Calls C++ function: pure virtual void QAbstractEventDispatcher::flush().

pub unsafe fn has_pending_events(&self) -> bool

Calls C++ function: pure virtual bool QAbstractEventDispatcher::hasPendingEvents().

pub unsafe fn install_native_event_filter( &self, filter_obj: impl CastInto<Ptr<QAbstractNativeEventFilter>>, )

Calls C++ function: void QAbstractEventDispatcher::installNativeEventFilter(QAbstractNativeEventFilter* filterObj).

pub unsafe fn instance_1a( thread: impl CastInto<Ptr<QThread>>, ) -> QPtr<QAbstractEventDispatcher>

Calls C++ function: static QAbstractEventDispatcher* QAbstractEventDispatcher::instance(QThread* thread = …).

pub unsafe fn instance_0a() -> QPtr<QAbstractEventDispatcher>

Calls C++ function: static QAbstractEventDispatcher* QAbstractEventDispatcher::instance().

pub unsafe fn interrupt(&self)

Calls C++ function: pure virtual void QAbstractEventDispatcher::interrupt().

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QAbstractEventDispatcher::metaObject() const.

pub unsafe fn process_events(&self, flags: QFlags<ProcessEventsFlag>) -> bool

Calls C++ function: pure virtual bool QAbstractEventDispatcher::processEvents(QFlags<QEventLoop::ProcessEventsFlag> flags).

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QAbstractEventDispatcher::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QAbstractEventDispatcher::qt_metacast(const char* arg1).

pub unsafe fn register_socket_notifier( &self, notifier: impl CastInto<Ptr<QSocketNotifier>>, )

Calls C++ function: pure virtual void QAbstractEventDispatcher::registerSocketNotifier(QSocketNotifier* notifier).

pub unsafe fn register_timer_3a( &self, interval: c_int, timer_type: TimerType, object: impl CastInto<Ptr<QObject>>, ) -> c_int

Calls C++ function: int QAbstractEventDispatcher::registerTimer(int interval, Qt::TimerType timerType, QObject* object).

pub unsafe fn register_timer_4a( &self, timer_id: c_int, interval: c_int, timer_type: TimerType, object: impl CastInto<Ptr<QObject>>, )

Calls C++ function: pure virtual void QAbstractEventDispatcher::registerTimer(int timerId, int interval, Qt::TimerType timerType, QObject* object).

pub unsafe fn registered_timers( &self, object: impl CastInto<Ptr<QObject>>, ) -> CppBox<QListOfTimerInfo>

Calls C++ function: pure virtual QList<QAbstractEventDispatcher::TimerInfo> QAbstractEventDispatcher::registeredTimers(QObject* object) const.

pub unsafe fn remaining_time(&self, timer_id: c_int) -> c_int

Calls C++ function: pure virtual int QAbstractEventDispatcher::remainingTime(int timerId).

pub unsafe fn remove_native_event_filter( &self, filter_obj: impl CastInto<Ptr<QAbstractNativeEventFilter>>, )

Calls C++ function: void QAbstractEventDispatcher::removeNativeEventFilter(QAbstractNativeEventFilter* filterObj).

pub unsafe fn starting_up(&self)

Calls C++ function: virtual void QAbstractEventDispatcher::startingUp().

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QAbstractEventDispatcher::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QAbstractEventDispatcher::trUtf8(const char* s, const char* c, int n).

pub unsafe fn unregister_socket_notifier( &self, notifier: impl CastInto<Ptr<QSocketNotifier>>, )

Calls C++ function: pure virtual void QAbstractEventDispatcher::unregisterSocketNotifier(QSocketNotifier* notifier).

pub unsafe fn unregister_timer(&self, timer_id: c_int) -> bool

Calls C++ function: pure virtual bool QAbstractEventDispatcher::unregisterTimer(int timerId).

pub unsafe fn unregister_timers( &self, object: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: pure virtual bool QAbstractEventDispatcher::unregisterTimers(QObject* object).

pub unsafe fn wake_up(&self)

Calls C++ function: pure virtual void QAbstractEventDispatcher::wakeUp().

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const c_char) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: c_int)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.