QConcatenateTablesProxyModel

Struct QConcatenateTablesProxyModel 

pub struct QConcatenateTablesProxyModel { /* private fields */ }
C++ class: QConcatenateTablesProxyModel.

Implementations

Source

impl QConcatenateTablesProxyModel

pub unsafe fn add_source_model( &self, source_model: impl CastInto<Ptr<QAbstractItemModel>>, )

Calls C++ function: void QConcatenateTablesProxyModel::addSourceModel(QAbstractItemModel* sourceModel).

pub unsafe fn can_drop_mime_data( &self, data: impl CastInto<Ptr<QMimeData>>, action: DropAction, row: c_int, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QConcatenateTablesProxyModel::canDropMimeData(const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent) const.

pub unsafe fn column_count_1a( &self, parent: impl CastInto<Ref<QModelIndex>>, ) -> c_int

Calls C++ function: virtual int QConcatenateTablesProxyModel::columnCount(const QModelIndex& parent = …) const.

pub unsafe fn column_count_0a(&self) -> c_int

Calls C++ function: virtual int QConcatenateTablesProxyModel::columnCount() const.

pub unsafe fn data_2a( &self, index: impl CastInto<Ref<QModelIndex>>, role: c_int, ) -> CppBox<QVariant>

Calls C++ function: virtual QVariant QConcatenateTablesProxyModel::data(const QModelIndex& index, int role = …) const.

pub unsafe fn data_1a( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QVariant>

Calls C++ function: virtual QVariant QConcatenateTablesProxyModel::data(const QModelIndex& index) const.

pub unsafe fn drop_mime_data( &self, data: impl CastInto<Ptr<QMimeData>>, action: DropAction, row: c_int, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QConcatenateTablesProxyModel::dropMimeData(const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent).

pub unsafe fn flags( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> QFlags<ItemFlag>

Calls C++ function: virtual QFlags<Qt::ItemFlag> QConcatenateTablesProxyModel::flags(const QModelIndex& index) const.

pub unsafe fn header_data_3a( &self, section: c_int, orientation: Orientation, role: c_int, ) -> CppBox<QVariant>

Calls C++ function: virtual QVariant QConcatenateTablesProxyModel::headerData(int section, Qt::Orientation orientation, int role = …) const.

pub unsafe fn header_data_2a( &self, section: c_int, orientation: Orientation, ) -> CppBox<QVariant>

Calls C++ function: virtual QVariant QConcatenateTablesProxyModel::headerData(int section, Qt::Orientation orientation) const.

pub unsafe fn index_3a( &self, row: c_int, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QModelIndex>

Calls C++ function: virtual QModelIndex QConcatenateTablesProxyModel::index(int row, int column, const QModelIndex& parent = …) const.

pub unsafe fn index_2a(&self, row: c_int, column: c_int) -> CppBox<QModelIndex>

Calls C++ function: virtual QModelIndex QConcatenateTablesProxyModel::index(int row, int column) const.

pub unsafe fn item_data( &self, proxy_index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QMapOfIntQVariant>

Calls C++ function: virtual QMap<int, QVariant> QConcatenateTablesProxyModel::itemData(const QModelIndex& proxyIndex) const.

pub unsafe fn map_from_source( &self, source_index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QModelIndex>

Calls C++ function: QModelIndex QConcatenateTablesProxyModel::mapFromSource(const QModelIndex& sourceIndex) const.

pub unsafe fn map_to_source( &self, proxy_index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QModelIndex>

Calls C++ function: QModelIndex QConcatenateTablesProxyModel::mapToSource(const QModelIndex& proxyIndex) const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QConcatenateTablesProxyModel::metaObject() const.

pub unsafe fn mime_data( &self, indexes: impl CastInto<Ref<QListOfQModelIndex>>, ) -> QPtr<QMimeData>

Calls C++ function: virtual QMimeData* QConcatenateTablesProxyModel::mimeData(const QList<QModelIndex>& indexes) const.

pub unsafe fn mime_types(&self) -> CppBox<QStringList>

Calls C++ function: virtual QStringList QConcatenateTablesProxyModel::mimeTypes() const.

pub unsafe fn new_1a( parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QConcatenateTablesProxyModel>

Calls C++ function: [constructor] void QConcatenateTablesProxyModel::QConcatenateTablesProxyModel(QObject* parent = …).

pub unsafe fn new_0a() -> QBox<QConcatenateTablesProxyModel>

Calls C++ function: [constructor] void QConcatenateTablesProxyModel::QConcatenateTablesProxyModel().

pub unsafe fn parent( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QModelIndex>

Calls C++ function: virtual QModelIndex QConcatenateTablesProxyModel::parent(const QModelIndex& index) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QConcatenateTablesProxyModel::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QConcatenateTablesProxyModel::qt_metacast(const char* arg1).

pub unsafe fn remove_source_model( &self, source_model: impl CastInto<Ptr<QAbstractItemModel>>, )

Calls C++ function: void QConcatenateTablesProxyModel::removeSourceModel(QAbstractItemModel* sourceModel).

pub unsafe fn row_count_1a( &self, parent: impl CastInto<Ref<QModelIndex>>, ) -> c_int

Calls C++ function: virtual int QConcatenateTablesProxyModel::rowCount(const QModelIndex& parent = …) const.

pub unsafe fn row_count_0a(&self) -> c_int

Calls C++ function: virtual int QConcatenateTablesProxyModel::rowCount() const.

pub unsafe fn set_data_3a( &self, index: impl CastInto<Ref<QModelIndex>>, value: impl CastInto<Ref<QVariant>>, role: c_int, ) -> bool

Calls C++ function: virtual bool QConcatenateTablesProxyModel::setData(const QModelIndex& index, const QVariant& value, int role = …).

pub unsafe fn set_data_2a( &self, index: impl CastInto<Ref<QModelIndex>>, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: virtual bool QConcatenateTablesProxyModel::setData(const QModelIndex& index, const QVariant& value).

pub unsafe fn set_item_data( &self, index: impl CastInto<Ref<QModelIndex>>, roles: impl CastInto<Ref<QMapOfIntQVariant>>, ) -> bool

Calls C++ function: virtual bool QConcatenateTablesProxyModel::setItemData(const QModelIndex& index, const QMap<int, QVariant>& roles).

pub unsafe fn source_models(&self) -> CppBox<QListOfQAbstractItemModel>

Calls C++ function: QList<QAbstractItemModel*> QConcatenateTablesProxyModel::sourceModels() const.

pub unsafe fn span( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QSize>

Calls C++ function: virtual QSize QConcatenateTablesProxyModel::span(const QModelIndex& index) const.

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QConcatenateTablesProxyModel::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QConcatenateTablesProxyModel::trUtf8(const char* s, const char* c, int n).

Methods from Deref<Target = QAbstractItemModel>

pub fn header_data_changed(&self) -> Signal<(Orientation, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::headerDataChanged that can be passed to qt_core::Signal::connect.

pub fn rows_about_to_be_inserted( &self, ) -> Signal<(*const QModelIndex, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::rowsAboutToBeInserted that can be passed to qt_core::Signal::connect.

pub fn rows_inserted(&self) -> Signal<(*const QModelIndex, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::rowsInserted that can be passed to qt_core::Signal::connect.

pub fn rows_about_to_be_removed( &self, ) -> Signal<(*const QModelIndex, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::rowsAboutToBeRemoved that can be passed to qt_core::Signal::connect.

pub fn rows_removed(&self) -> Signal<(*const QModelIndex, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::rowsRemoved that can be passed to qt_core::Signal::connect.

pub fn columns_about_to_be_inserted( &self, ) -> Signal<(*const QModelIndex, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::columnsAboutToBeInserted that can be passed to qt_core::Signal::connect.

pub fn columns_inserted(&self) -> Signal<(*const QModelIndex, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::columnsInserted that can be passed to qt_core::Signal::connect.

pub fn columns_about_to_be_removed( &self, ) -> Signal<(*const QModelIndex, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::columnsAboutToBeRemoved that can be passed to qt_core::Signal::connect.

pub fn columns_removed(&self) -> Signal<(*const QModelIndex, c_int, c_int)>

Returns a built-in Qt signal QAbstractItemModel::columnsRemoved that can be passed to qt_core::Signal::connect.

pub fn model_about_to_be_reset(&self) -> Signal<()>

Returns a built-in Qt signal QAbstractItemModel::modelAboutToBeReset that can be passed to qt_core::Signal::connect.

pub fn model_reset(&self) -> Signal<()>

Returns a built-in Qt signal QAbstractItemModel::modelReset that can be passed to qt_core::Signal::connect.

pub fn rows_about_to_be_moved( &self, ) -> Signal<(*const QModelIndex, c_int, c_int, *const QModelIndex, c_int)>

Returns a built-in Qt signal QAbstractItemModel::rowsAboutToBeMoved that can be passed to qt_core::Signal::connect.

pub fn rows_moved( &self, ) -> Signal<(*const QModelIndex, c_int, c_int, *const QModelIndex, c_int)>

Returns a built-in Qt signal QAbstractItemModel::rowsMoved that can be passed to qt_core::Signal::connect.

pub fn columns_about_to_be_moved( &self, ) -> Signal<(*const QModelIndex, c_int, c_int, *const QModelIndex, c_int)>

Returns a built-in Qt signal QAbstractItemModel::columnsAboutToBeMoved that can be passed to qt_core::Signal::connect.

pub fn columns_moved( &self, ) -> Signal<(*const QModelIndex, c_int, c_int, *const QModelIndex, c_int)>

Returns a built-in Qt signal QAbstractItemModel::columnsMoved that can be passed to qt_core::Signal::connect.

pub fn slot_submit(&self) -> Receiver<()>

Returns a built-in Qt slot QAbstractItemModel::submit that can be passed to qt_core::Signal::connect.

pub fn slot_revert(&self) -> Receiver<()>

Returns a built-in Qt slot QAbstractItemModel::revert that can be passed to qt_core::Signal::connect.

pub fn slot_reset_internal_data(&self) -> Receiver<()>

Returns a built-in Qt slot QAbstractItemModel::resetInternalData that can be passed to qt_core::Signal::connect.

pub fn data_changed( &self, ) -> Signal<(*const QModelIndex, *const QModelIndex, *const QVectorOfInt)>

Returns a built-in Qt signal QAbstractItemModel::dataChanged that can be passed to qt_core::Signal::connect.

pub fn layout_changed( &self, ) -> Signal<(*const QListOfQPersistentModelIndex, LayoutChangeHint)>

Returns a built-in Qt signal QAbstractItemModel::layoutChanged that can be passed to qt_core::Signal::connect.

pub fn layout_about_to_be_changed( &self, ) -> Signal<(*const QListOfQPersistentModelIndex, LayoutChangeHint)>

Returns a built-in Qt signal QAbstractItemModel::layoutAboutToBeChanged that can be passed to qt_core::Signal::connect.

pub unsafe fn buddy( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QModelIndex>

Calls C++ function: virtual QModelIndex QAbstractItemModel::buddy(const QModelIndex& index) const.

pub unsafe fn can_drop_mime_data( &self, data: impl CastInto<Ptr<QMimeData>>, action: DropAction, row: c_int, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::canDropMimeData(const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent) const.

pub unsafe fn can_fetch_more( &self, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::canFetchMore(const QModelIndex& parent) const.

pub unsafe fn check_index_2a( &self, index: impl CastInto<Ref<QModelIndex>>, options: QFlags<CheckIndexOption>, ) -> bool

Calls C++ function: bool QAbstractItemModel::checkIndex(const QModelIndex& index, QFlags<QAbstractItemModel::CheckIndexOption> options = …) const.

pub unsafe fn check_index_1a( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: bool QAbstractItemModel::checkIndex(const QModelIndex& index) const.

pub unsafe fn column_count_1a( &self, parent: impl CastInto<Ref<QModelIndex>>, ) -> c_int

Calls C++ function: pure virtual int QAbstractItemModel::columnCount(const QModelIndex& parent = …) const.

pub unsafe fn column_count_0a(&self) -> c_int

Calls C++ function: pure virtual int QAbstractItemModel::columnCount() const.

pub unsafe fn data_2a( &self, index: impl CastInto<Ref<QModelIndex>>, role: c_int, ) -> CppBox<QVariant>

Calls C++ function: pure virtual QVariant QAbstractItemModel::data(const QModelIndex& index, int role = …) const.

pub unsafe fn data_1a( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QVariant>

Calls C++ function: pure virtual QVariant QAbstractItemModel::data(const QModelIndex& index) const.

pub unsafe fn drop_mime_data( &self, data: impl CastInto<Ptr<QMimeData>>, action: DropAction, row: c_int, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::dropMimeData(const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent).

pub unsafe fn fetch_more(&self, parent: impl CastInto<Ref<QModelIndex>>)

Calls C++ function: virtual void QAbstractItemModel::fetchMore(const QModelIndex& parent).

pub unsafe fn flags( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> QFlags<ItemFlag>

Calls C++ function: virtual QFlags<Qt::ItemFlag> QAbstractItemModel::flags(const QModelIndex& index) const.

pub unsafe fn has_children_1a( &self, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::hasChildren(const QModelIndex& parent = …) const.

pub unsafe fn has_children_0a(&self) -> bool

Calls C++ function: virtual bool QAbstractItemModel::hasChildren() const.

pub unsafe fn has_index_3a( &self, row: c_int, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: bool QAbstractItemModel::hasIndex(int row, int column, const QModelIndex& parent = …) const.

pub unsafe fn has_index_2a(&self, row: c_int, column: c_int) -> bool

Calls C++ function: bool QAbstractItemModel::hasIndex(int row, int column) const.

pub unsafe fn header_data_3a( &self, section: c_int, orientation: Orientation, role: c_int, ) -> CppBox<QVariant>

Calls C++ function: virtual QVariant QAbstractItemModel::headerData(int section, Qt::Orientation orientation, int role = …) const.

pub unsafe fn header_data_2a( &self, section: c_int, orientation: Orientation, ) -> CppBox<QVariant>

Calls C++ function: virtual QVariant QAbstractItemModel::headerData(int section, Qt::Orientation orientation) const.

pub unsafe fn index_3a( &self, row: c_int, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QModelIndex>

Calls C++ function: pure virtual QModelIndex QAbstractItemModel::index(int row, int column, const QModelIndex& parent = …) const.

pub unsafe fn index_2a(&self, row: c_int, column: c_int) -> CppBox<QModelIndex>

Calls C++ function: pure virtual QModelIndex QAbstractItemModel::index(int row, int column) const.

pub unsafe fn insert_column_2a( &self, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: bool QAbstractItemModel::insertColumn(int column, const QModelIndex& parent = …).

pub unsafe fn insert_column_1a(&self, column: c_int) -> bool

Calls C++ function: bool QAbstractItemModel::insertColumn(int column).

pub unsafe fn insert_columns_3a( &self, column: c_int, count: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::insertColumns(int column, int count, const QModelIndex& parent = …).

pub unsafe fn insert_columns_2a(&self, column: c_int, count: c_int) -> bool

Calls C++ function: virtual bool QAbstractItemModel::insertColumns(int column, int count).

pub unsafe fn insert_row_2a( &self, row: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: bool QAbstractItemModel::insertRow(int row, const QModelIndex& parent = …).

pub unsafe fn insert_row_1a(&self, row: c_int) -> bool

Calls C++ function: bool QAbstractItemModel::insertRow(int row).

pub unsafe fn insert_rows_3a( &self, row: c_int, count: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::insertRows(int row, int count, const QModelIndex& parent = …).

pub unsafe fn insert_rows_2a(&self, row: c_int, count: c_int) -> bool

Calls C++ function: virtual bool QAbstractItemModel::insertRows(int row, int count).

pub unsafe fn item_data( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QMapOfIntQVariant>

Calls C++ function: virtual QMap<int, QVariant> QAbstractItemModel::itemData(const QModelIndex& index) const.

pub unsafe fn match_5a( &self, start: impl CastInto<Ref<QModelIndex>>, role: c_int, value: impl CastInto<Ref<QVariant>>, hits: c_int, flags: QFlags<MatchFlag>, ) -> CppBox<QListOfQModelIndex>

Calls C++ function: virtual QList<QModelIndex> QAbstractItemModel::match(const QModelIndex& start, int role, const QVariant& value, int hits = …, QFlags<Qt::MatchFlag> flags = …) const.

pub unsafe fn match_4a( &self, start: impl CastInto<Ref<QModelIndex>>, role: c_int, value: impl CastInto<Ref<QVariant>>, hits: c_int, ) -> CppBox<QListOfQModelIndex>

Calls C++ function: virtual QList<QModelIndex> QAbstractItemModel::match(const QModelIndex& start, int role, const QVariant& value, int hits = …) const.

pub unsafe fn match_3a( &self, start: impl CastInto<Ref<QModelIndex>>, role: c_int, value: impl CastInto<Ref<QVariant>>, ) -> CppBox<QListOfQModelIndex>

Calls C++ function: virtual QList<QModelIndex> QAbstractItemModel::match(const QModelIndex& start, int role, const QVariant& value) const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QAbstractItemModel::metaObject() const.

pub unsafe fn mime_data( &self, indexes: impl CastInto<Ref<QListOfQModelIndex>>, ) -> QPtr<QMimeData>

Calls C++ function: virtual QMimeData* QAbstractItemModel::mimeData(const QList<QModelIndex>& indexes) const.

pub unsafe fn mime_types(&self) -> CppBox<QStringList>

Calls C++ function: virtual QStringList QAbstractItemModel::mimeTypes() const.

pub unsafe fn move_column( &self, source_parent: impl CastInto<Ref<QModelIndex>>, source_column: c_int, destination_parent: impl CastInto<Ref<QModelIndex>>, destination_child: c_int, ) -> bool

Calls C++ function: bool QAbstractItemModel::moveColumn(const QModelIndex& sourceParent, int sourceColumn, const QModelIndex& destinationParent, int destinationChild).

pub unsafe fn move_columns( &self, source_parent: impl CastInto<Ref<QModelIndex>>, source_column: c_int, count: c_int, destination_parent: impl CastInto<Ref<QModelIndex>>, destination_child: c_int, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::moveColumns(const QModelIndex& sourceParent, int sourceColumn, int count, const QModelIndex& destinationParent, int destinationChild).

pub unsafe fn move_row( &self, source_parent: impl CastInto<Ref<QModelIndex>>, source_row: c_int, destination_parent: impl CastInto<Ref<QModelIndex>>, destination_child: c_int, ) -> bool

Calls C++ function: bool QAbstractItemModel::moveRow(const QModelIndex& sourceParent, int sourceRow, const QModelIndex& destinationParent, int destinationChild).

pub unsafe fn move_rows( &self, source_parent: impl CastInto<Ref<QModelIndex>>, source_row: c_int, count: c_int, destination_parent: impl CastInto<Ref<QModelIndex>>, destination_child: c_int, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::moveRows(const QModelIndex& sourceParent, int sourceRow, int count, const QModelIndex& destinationParent, int destinationChild).

pub unsafe fn parent( &self, child: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QModelIndex>

Calls C++ function: pure virtual QModelIndex QAbstractItemModel::parent(const QModelIndex& child) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QAbstractItemModel::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QAbstractItemModel::qt_metacast(const char* arg1).

pub unsafe fn remove_column_2a( &self, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: bool QAbstractItemModel::removeColumn(int column, const QModelIndex& parent = …).

pub unsafe fn remove_column_1a(&self, column: c_int) -> bool

Calls C++ function: bool QAbstractItemModel::removeColumn(int column).

pub unsafe fn remove_columns_3a( &self, column: c_int, count: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::removeColumns(int column, int count, const QModelIndex& parent = …).

pub unsafe fn remove_columns_2a(&self, column: c_int, count: c_int) -> bool

Calls C++ function: virtual bool QAbstractItemModel::removeColumns(int column, int count).

pub unsafe fn remove_row_2a( &self, row: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: bool QAbstractItemModel::removeRow(int row, const QModelIndex& parent = …).

pub unsafe fn remove_row_1a(&self, row: c_int) -> bool

Calls C++ function: bool QAbstractItemModel::removeRow(int row).

pub unsafe fn remove_rows_3a( &self, row: c_int, count: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::removeRows(int row, int count, const QModelIndex& parent = …).

pub unsafe fn remove_rows_2a(&self, row: c_int, count: c_int) -> bool

Calls C++ function: virtual bool QAbstractItemModel::removeRows(int row, int count).

pub unsafe fn revert(&self)

Calls C++ function: virtual [slot] void QAbstractItemModel::revert().

pub unsafe fn role_names(&self) -> CppBox<QHashOfIntQByteArray>

Calls C++ function: virtual QHash<int, QByteArray> QAbstractItemModel::roleNames() const.

pub unsafe fn row_count_1a( &self, parent: impl CastInto<Ref<QModelIndex>>, ) -> c_int

Calls C++ function: pure virtual int QAbstractItemModel::rowCount(const QModelIndex& parent = …) const.

pub unsafe fn row_count_0a(&self) -> c_int

Calls C++ function: pure virtual int QAbstractItemModel::rowCount() const.

pub unsafe fn set_data_3a( &self, index: impl CastInto<Ref<QModelIndex>>, value: impl CastInto<Ref<QVariant>>, role: c_int, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::setData(const QModelIndex& index, const QVariant& value, int role = …).

pub unsafe fn set_data_2a( &self, index: impl CastInto<Ref<QModelIndex>>, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::setData(const QModelIndex& index, const QVariant& value).

pub unsafe fn set_header_data_4a( &self, section: c_int, orientation: Orientation, value: impl CastInto<Ref<QVariant>>, role: c_int, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::setHeaderData(int section, Qt::Orientation orientation, const QVariant& value, int role = …).

pub unsafe fn set_header_data_3a( &self, section: c_int, orientation: Orientation, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::setHeaderData(int section, Qt::Orientation orientation, const QVariant& value).

pub unsafe fn set_item_data( &self, index: impl CastInto<Ref<QModelIndex>>, roles: impl CastInto<Ref<QMapOfIntQVariant>>, ) -> bool

Calls C++ function: virtual bool QAbstractItemModel::setItemData(const QModelIndex& index, const QMap<int, QVariant>& roles).

pub unsafe fn sibling( &self, row: c_int, column: c_int, idx: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QModelIndex>

Calls C++ function: virtual QModelIndex QAbstractItemModel::sibling(int row, int column, const QModelIndex& idx) const.

pub unsafe fn sort_2a(&self, column: c_int, order: SortOrder)

Calls C++ function: virtual void QAbstractItemModel::sort(int column, Qt::SortOrder order = …).

pub unsafe fn sort_1a(&self, column: c_int)

Calls C++ function: virtual void QAbstractItemModel::sort(int column).

pub unsafe fn span( &self, index: impl CastInto<Ref<QModelIndex>>, ) -> CppBox<QSize>

Calls C++ function: virtual QSize QAbstractItemModel::span(const QModelIndex& index) const.

pub unsafe fn submit(&self) -> bool

Calls C++ function: virtual [slot] bool QAbstractItemModel::submit().

pub unsafe fn supported_drag_actions(&self) -> QFlags<DropAction>

Calls C++ function: virtual QFlags<Qt::DropAction> QAbstractItemModel::supportedDragActions() const.

pub unsafe fn supported_drop_actions(&self) -> QFlags<DropAction>

Calls C++ function: virtual QFlags<Qt::DropAction> QAbstractItemModel::supportedDropActions() const.

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const c_char) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: c_int)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.