pub struct QCoreApplicationArgs { /* private fields */ }Expand description
A struct providing valid argc and argv values for Qt application
objects.
QCoreApplication shouldn’t be used directly. Instead, use init function on
the application types (qt_core::QCoreApplication,
qt_gui::QGuiApplication, and qt_widgets::QApplication).
Constructors of Qt application classes
require argc and argv values that are available in C++’s main function but
not available in Rust. Qt also expects argc and argv to be encoded in a particular
(local 8-bit) encoding. argc and argv must be valid for the entire
life of the application. This struct stores list of arguments in a format compatible with
argc and argv, and can be used to initialize Qt application objects.
QCoreApplicationArgs must live longer than the application object.
Implementations