QFile

Struct QFile 

pub struct QFile { /* private fields */ }
C++ class: QFile.

Implementations

Source

impl QFile

pub unsafe fn copy_mut(&self, new_name: impl CastInto<Ref<QString>>) -> bool

Calls C++ function: bool QFile::copy(const QString& newName).

pub unsafe fn copy( file_name: impl CastInto<Ref<QString>>, new_name: impl CastInto<Ref<QString>>, ) -> bool

Calls C++ function: static bool QFile::copy(const QString& fileName, const QString& newName).

pub unsafe fn decode_name_q_byte_array( local_file_name: impl CastInto<Ref<QByteArray>>, ) -> CppBox<QString>

Calls C++ function: static QString QFile::decodeName(const QByteArray& localFileName).

pub unsafe fn decode_name_char( local_file_name: *const c_char, ) -> CppBox<QString>

Calls C++ function: static QString QFile::decodeName(const char* localFileName).

pub unsafe fn encode_name( file_name: impl CastInto<Ref<QString>>, ) -> CppBox<QByteArray>

Calls C++ function: static QByteArray QFile::encodeName(const QString& fileName).

pub unsafe fn exists_0a(&self) -> bool

Calls C++ function: bool QFile::exists() const.

pub unsafe fn exists_1a(file_name: impl CastInto<Ref<QString>>) -> bool

Calls C++ function: static bool QFile::exists(const QString& fileName).

pub unsafe fn file_name(&self) -> CppBox<QString>

Calls C++ function: virtual QString QFile::fileName() const.

Calls C++ function: bool QFile::link(const QString& newName).

Calls C++ function: static bool QFile::link(const QString& oldname, const QString& newName).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QFile::metaObject() const.

pub unsafe fn move_to_trash_0a(&self) -> bool

Calls C++ function: bool QFile::moveToTrash().

pub unsafe fn move_to_trash_2a( file_name: impl CastInto<Ref<QString>>, path_in_trash: impl CastInto<Ptr<QString>>, ) -> bool

Calls C++ function: static bool QFile::moveToTrash(const QString& fileName, QString* pathInTrash = …).

pub unsafe fn move_to_trash_1a(file_name: impl CastInto<Ref<QString>>) -> bool

Calls C++ function: static bool QFile::moveToTrash(const QString& fileName).

pub unsafe fn new() -> QBox<QFile>

Calls C++ function: [constructor] void QFile::QFile().

pub unsafe fn from_q_string(name: impl CastInto<Ref<QString>>) -> QBox<QFile>

Calls C++ function: [constructor] void QFile::QFile(const QString& name).

pub unsafe fn from_q_object(parent: impl CastInto<Ptr<QObject>>) -> QBox<QFile>

Calls C++ function: [constructor] void QFile::QFile(QObject* parent).

pub unsafe fn from_q_string_q_object( name: impl CastInto<Ref<QString>>, parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QFile>

Calls C++ function: [constructor] void QFile::QFile(const QString& name, QObject* parent).

pub unsafe fn open_1a(&self, flags: QFlags<OpenModeFlag>) -> bool

Calls C++ function: virtual bool QFile::open(QFlags<QIODevice::OpenModeFlag> flags).

pub unsafe fn open_3a( &self, fd: c_int, io_flags: QFlags<OpenModeFlag>, handle_flags: QFlags<FileHandleFlag>, ) -> bool

Calls C++ function: bool QFile::open(int fd, QFlags<QIODevice::OpenModeFlag> ioFlags, QFlags<QFileDevice::FileHandleFlag> handleFlags = …).

pub unsafe fn open_2a(&self, fd: c_int, io_flags: QFlags<OpenModeFlag>) -> bool

Calls C++ function: bool QFile::open(int fd, QFlags<QIODevice::OpenModeFlag> ioFlags).

pub unsafe fn permissions_0a(&self) -> QFlags<Permission>

Calls C++ function: virtual QFlags<QFileDevice::Permission> QFile::permissions() const.

pub unsafe fn permissions_1a( filename: impl CastInto<Ref<QString>>, ) -> QFlags<Permission>

Calls C++ function: static QFlags<QFileDevice::Permission> QFile::permissions(const QString& filename).

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QFile::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QFile::qt_metacast(const char* arg1).

Calls C++ function: QString QFile::readLink() const.

Calls C++ function: static QString QFile::readLink(const QString& fileName).

pub unsafe fn remove_mut(&self) -> bool

Calls C++ function: bool QFile::remove().

pub unsafe fn remove(file_name: impl CastInto<Ref<QString>>) -> bool

Calls C++ function: static bool QFile::remove(const QString& fileName).

pub unsafe fn rename_mut(&self, new_name: impl CastInto<Ref<QString>>) -> bool

Calls C++ function: bool QFile::rename(const QString& newName).

pub unsafe fn rename( old_name: impl CastInto<Ref<QString>>, new_name: impl CastInto<Ref<QString>>, ) -> bool

Calls C++ function: static bool QFile::rename(const QString& oldName, const QString& newName).

pub unsafe fn resize_mut(&self, sz: c_longlong) -> bool

Calls C++ function: virtual bool QFile::resize(long long sz).

pub unsafe fn resize( filename: impl CastInto<Ref<QString>>, sz: c_longlong, ) -> bool

Calls C++ function: static bool QFile::resize(const QString& filename, long long sz).

pub unsafe fn set_file_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QFile::setFileName(const QString& name).

pub unsafe fn set_permissions_mut( &self, permission_spec: QFlags<Permission>, ) -> bool

Calls C++ function: virtual bool QFile::setPermissions(QFlags<QFileDevice::Permission> permissionSpec).

pub unsafe fn set_permissions( filename: impl CastInto<Ref<QString>>, permission_spec: QFlags<Permission>, ) -> bool

Calls C++ function: static bool QFile::setPermissions(const QString& filename, QFlags<QFileDevice::Permission> permissionSpec).

pub unsafe fn size(&self) -> c_longlong

Calls C++ function: virtual long long QFile::size() const.

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

Calls C++ function: QString QFile::symLinkTarget() const.

Calls C++ function: static QString QFile::symLinkTarget(const QString& fileName).

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QFile::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QFile::trUtf8(const char* s, const char* c, int n).

Methods from Deref<Target = QFileDevice>

pub unsafe fn at_end(&self) -> bool

Calls C++ function: virtual bool QFileDevice::atEnd() const.

pub unsafe fn close(&self)

Calls C++ function: virtual void QFileDevice::close().

pub unsafe fn error(&self) -> FileError

Calls C++ function: QFileDevice::FileError QFileDevice::error() const.

pub unsafe fn file_name(&self) -> CppBox<QString>

Calls C++ function: virtual QString QFileDevice::fileName() const.

pub unsafe fn file_time(&self, time: FileTime) -> CppBox<QDateTime>

Calls C++ function: QDateTime QFileDevice::fileTime(QFileDevice::FileTime time) const.

pub unsafe fn flush(&self) -> bool

Calls C++ function: bool QFileDevice::flush().

pub unsafe fn handle(&self) -> c_int

Calls C++ function: int QFileDevice::handle() const.

pub unsafe fn is_sequential(&self) -> bool

Calls C++ function: virtual bool QFileDevice::isSequential() const.

pub unsafe fn map_3a( &self, offset: c_longlong, size: c_longlong, flags: MemoryMapFlags, ) -> *mut c_uchar

Calls C++ function: unsigned char* QFileDevice::map(long long offset, long long size, QFileDevice::MemoryMapFlags flags = …).

pub unsafe fn map_2a( &self, offset: c_longlong, size: c_longlong, ) -> *mut c_uchar

Calls C++ function: unsigned char* QFileDevice::map(long long offset, long long size).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QFileDevice::metaObject() const.

pub unsafe fn permissions(&self) -> QFlags<Permission>

Calls C++ function: virtual QFlags<QFileDevice::Permission> QFileDevice::permissions() const.

pub unsafe fn pos(&self) -> c_longlong

Calls C++ function: virtual long long QFileDevice::pos() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QFileDevice::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QFileDevice::qt_metacast(const char* arg1).

pub unsafe fn resize(&self, sz: c_longlong) -> bool

Calls C++ function: virtual bool QFileDevice::resize(long long sz).

pub unsafe fn seek(&self, offset: c_longlong) -> bool

Calls C++ function: virtual bool QFileDevice::seek(long long offset).

pub unsafe fn set_file_time( &self, new_date: impl CastInto<Ref<QDateTime>>, file_time: FileTime, ) -> bool

Calls C++ function: bool QFileDevice::setFileTime(const QDateTime& newDate, QFileDevice::FileTime fileTime).

pub unsafe fn set_permissions( &self, permission_spec: QFlags<Permission>, ) -> bool

Calls C++ function: virtual bool QFileDevice::setPermissions(QFlags<QFileDevice::Permission> permissionSpec).

pub unsafe fn size(&self) -> c_longlong

Calls C++ function: virtual long long QFileDevice::size() const.

pub unsafe fn unmap(&self, address: *mut c_uchar) -> bool

Calls C++ function: bool QFileDevice::unmap(unsigned char* address).

pub unsafe fn unset_error(&self)

Calls C++ function: void QFileDevice::unsetError().

Methods from Deref<Target = QIODevice>

pub fn ready_read(&self) -> Signal<()>

Returns a built-in Qt signal QIODevice::readyRead that can be passed to qt_core::Signal::connect.

pub fn channel_ready_read(&self) -> Signal<(c_int,)>

Returns a built-in Qt signal QIODevice::channelReadyRead that can be passed to qt_core::Signal::connect.

pub fn bytes_written(&self) -> Signal<(c_longlong,)>

Returns a built-in Qt signal QIODevice::bytesWritten that can be passed to qt_core::Signal::connect.

pub fn channel_bytes_written(&self) -> Signal<(c_int, c_longlong)>

Returns a built-in Qt signal QIODevice::channelBytesWritten that can be passed to qt_core::Signal::connect.

pub fn about_to_close(&self) -> Signal<()>

Returns a built-in Qt signal QIODevice::aboutToClose that can be passed to qt_core::Signal::connect.

pub fn read_channel_finished(&self) -> Signal<()>

Returns a built-in Qt signal QIODevice::readChannelFinished that can be passed to qt_core::Signal::connect.

pub unsafe fn at_end(&self) -> bool

Calls C++ function: virtual bool QIODevice::atEnd() const.

pub unsafe fn bytes_available(&self) -> c_longlong

Calls C++ function: virtual long long QIODevice::bytesAvailable() const.

pub unsafe fn bytes_to_write(&self) -> c_longlong

Calls C++ function: virtual long long QIODevice::bytesToWrite() const.

pub unsafe fn can_read_line(&self) -> bool

Calls C++ function: virtual bool QIODevice::canReadLine() const.

pub unsafe fn close(&self)

Calls C++ function: virtual void QIODevice::close().

pub unsafe fn commit_transaction(&self)

Calls C++ function: void QIODevice::commitTransaction().

pub unsafe fn current_read_channel(&self) -> c_int

Calls C++ function: int QIODevice::currentReadChannel() const.

pub unsafe fn current_write_channel(&self) -> c_int

Calls C++ function: int QIODevice::currentWriteChannel() const.

pub unsafe fn error_string(&self) -> CppBox<QString>

Calls C++ function: QString QIODevice::errorString() const.

pub unsafe fn get_char(&self, c: *mut c_char) -> bool

Calls C++ function: bool QIODevice::getChar(char* c).

pub unsafe fn is_open(&self) -> bool

Calls C++ function: bool QIODevice::isOpen() const.

pub unsafe fn is_readable(&self) -> bool

Calls C++ function: bool QIODevice::isReadable() const.

pub unsafe fn is_sequential(&self) -> bool

Calls C++ function: virtual bool QIODevice::isSequential() const.

pub unsafe fn is_text_mode_enabled(&self) -> bool

Calls C++ function: bool QIODevice::isTextModeEnabled() const.

pub unsafe fn is_transaction_started(&self) -> bool

Calls C++ function: bool QIODevice::isTransactionStarted() const.

pub unsafe fn is_writable(&self) -> bool

Calls C++ function: bool QIODevice::isWritable() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QIODevice::metaObject() const.

pub unsafe fn open(&self, mode: QFlags<OpenModeFlag>) -> bool

Calls C++ function: virtual bool QIODevice::open(QFlags<QIODevice::OpenModeFlag> mode).

pub unsafe fn open_mode(&self) -> QFlags<OpenModeFlag>

Calls C++ function: QFlags<QIODevice::OpenModeFlag> QIODevice::openMode() const.

pub unsafe fn peek_2a( &self, data: *mut c_char, maxlen: c_longlong, ) -> c_longlong

Calls C++ function: long long QIODevice::peek(char* data, long long maxlen).

pub unsafe fn peek_1a(&self, maxlen: c_longlong) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::peek(long long maxlen).

pub unsafe fn pos(&self) -> c_longlong

Calls C++ function: virtual long long QIODevice::pos() const.

pub unsafe fn put_char(&self, c: c_char) -> bool

Calls C++ function: bool QIODevice::putChar(char c).

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QIODevice::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QIODevice::qt_metacast(const char* arg1).

pub unsafe fn read_2a( &self, data: *mut c_char, maxlen: c_longlong, ) -> c_longlong

Calls C++ function: long long QIODevice::read(char* data, long long maxlen).

pub unsafe fn read_1a(&self, maxlen: c_longlong) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::read(long long maxlen).

pub unsafe fn read_all(&self) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::readAll().

pub unsafe fn read_channel_count(&self) -> c_int

Calls C++ function: int QIODevice::readChannelCount() const.

pub unsafe fn read_line_2a( &self, data: *mut c_char, maxlen: c_longlong, ) -> c_longlong

Calls C++ function: long long QIODevice::readLine(char* data, long long maxlen).

pub unsafe fn read_line_1a(&self, maxlen: c_longlong) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::readLine(long long maxlen = …).

pub unsafe fn read_line_0a(&self) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::readLine().

pub unsafe fn reset(&self) -> bool

Calls C++ function: virtual bool QIODevice::reset().

pub unsafe fn rollback_transaction(&self)

Calls C++ function: void QIODevice::rollbackTransaction().

pub unsafe fn seek(&self, pos: c_longlong) -> bool

Calls C++ function: virtual bool QIODevice::seek(long long pos).

pub unsafe fn set_current_read_channel(&self, channel: c_int)

Calls C++ function: void QIODevice::setCurrentReadChannel(int channel).

pub unsafe fn set_current_write_channel(&self, channel: c_int)

Calls C++ function: void QIODevice::setCurrentWriteChannel(int channel).

pub unsafe fn set_text_mode_enabled(&self, enabled: bool)

Calls C++ function: void QIODevice::setTextModeEnabled(bool enabled).

pub unsafe fn size(&self) -> c_longlong

Calls C++ function: virtual long long QIODevice::size() const.

pub unsafe fn skip(&self, max_size: c_longlong) -> c_longlong

Calls C++ function: long long QIODevice::skip(long long maxSize).

pub unsafe fn start_transaction(&self)

Calls C++ function: void QIODevice::startTransaction().

pub unsafe fn unget_char(&self, c: c_char)

Calls C++ function: void QIODevice::ungetChar(char c).

pub unsafe fn wait_for_bytes_written(&self, msecs: c_int) -> bool

Calls C++ function: virtual bool QIODevice::waitForBytesWritten(int msecs).

pub unsafe fn wait_for_ready_read(&self, msecs: c_int) -> bool

Calls C++ function: virtual bool QIODevice::waitForReadyRead(int msecs).

pub unsafe fn write_char_longlong( &self, data: *const c_char, len: c_longlong, ) -> c_longlong

Calls C++ function: long long QIODevice::write(const char* data, long long len).

pub unsafe fn write_char(&self, data: *const c_char) -> c_longlong

Calls C++ function: long long QIODevice::write(const char* data).

pub unsafe fn write_q_byte_array( &self, data: impl CastInto<Ref<QByteArray>>, ) -> c_longlong

Calls C++ function: long long QIODevice::write(const QByteArray& data).

pub unsafe fn write_channel_count(&self) -> c_int

Calls C++ function: int QIODevice::writeChannelCount() const.

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const c_char) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: c_int)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.