pub struct QItemSelectionModel { /* private fields */ }Expand description
C++ class: QItemSelectionModel.
Implementations
Sourceimpl QItemSelectionModel
impl QItemSelectionModel
Sourcepub fn slot_set_current_index(&self) -> Receiver<(*const QModelIndex, c_int)>
pub fn slot_set_current_index(&self) -> Receiver<(*const QModelIndex, c_int)>
Returns a built-in Qt slot QItemSelectionModel::setCurrentIndex that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_select(&self) -> Receiver<(*const QModelIndex, c_int)>
pub fn slot_select(&self) -> Receiver<(*const QModelIndex, c_int)>
Returns a built-in Qt slot QItemSelectionModel::select that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_select2(&self) -> Receiver<(*const QItemSelection, c_int)>
pub fn slot_select2(&self) -> Receiver<(*const QItemSelection, c_int)>
Returns a built-in Qt slot QItemSelectionModel::select that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_clear(&self) -> Receiver<()>
pub fn slot_clear(&self) -> Receiver<()>
Returns a built-in Qt slot QItemSelectionModel::clear that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_reset(&self) -> Receiver<()>
pub fn slot_reset(&self) -> Receiver<()>
Returns a built-in Qt slot QItemSelectionModel::reset that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_clear_selection(&self) -> Receiver<()>
pub fn slot_clear_selection(&self) -> Receiver<()>
Returns a built-in Qt slot QItemSelectionModel::clearSelection that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_clear_current_index(&self) -> Receiver<()>
pub fn slot_clear_current_index(&self) -> Receiver<()>
Returns a built-in Qt slot QItemSelectionModel::clearCurrentIndex that can be passed to qt_core::Signal::connect.
Sourcepub fn selection_changed(
&self,
) -> Signal<(*const QItemSelection, *const QItemSelection)>
pub fn selection_changed( &self, ) -> Signal<(*const QItemSelection, *const QItemSelection)>
Returns a built-in Qt signal QItemSelectionModel::selectionChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn current_changed(
&self,
) -> Signal<(*const QModelIndex, *const QModelIndex)>
pub fn current_changed( &self, ) -> Signal<(*const QModelIndex, *const QModelIndex)>
Returns a built-in Qt signal QItemSelectionModel::currentChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn current_row_changed(
&self,
) -> Signal<(*const QModelIndex, *const QModelIndex)>
pub fn current_row_changed( &self, ) -> Signal<(*const QModelIndex, *const QModelIndex)>
Returns a built-in Qt signal QItemSelectionModel::currentRowChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn current_column_changed(
&self,
) -> Signal<(*const QModelIndex, *const QModelIndex)>
pub fn current_column_changed( &self, ) -> Signal<(*const QModelIndex, *const QModelIndex)>
Returns a built-in Qt signal QItemSelectionModel::currentColumnChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn model_changed(&self) -> Signal<(*mut QAbstractItemModel,)>
pub fn model_changed(&self) -> Signal<(*mut QAbstractItemModel,)>
Returns a built-in Qt signal QItemSelectionModel::modelChanged that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn clear(&self)
pub unsafe fn clear(&self)
Calls C++ function: virtual [slot] void QItemSelectionModel::clear().
Sourcepub unsafe fn clear_current_index(&self)
pub unsafe fn clear_current_index(&self)
Calls C++ function: virtual [slot] void QItemSelectionModel::clearCurrentIndex().
Sourcepub unsafe fn clear_selection(&self)
pub unsafe fn clear_selection(&self)
Calls C++ function: [slot] void QItemSelectionModel::clearSelection().
Sourcepub unsafe fn column_intersects_selection_2a(
&self,
column: c_int,
parent: impl CastInto<Ref<QModelIndex>>,
) -> bool
pub unsafe fn column_intersects_selection_2a( &self, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool
Calls C++ function: bool QItemSelectionModel::columnIntersectsSelection(int column, const QModelIndex& parent = …) const.
Sourcepub unsafe fn column_intersects_selection_1a(&self, column: c_int) -> bool
pub unsafe fn column_intersects_selection_1a(&self, column: c_int) -> bool
Calls C++ function: bool QItemSelectionModel::columnIntersectsSelection(int column) const.
Sourcepub unsafe fn current_index(&self) -> CppBox<QModelIndex>
pub unsafe fn current_index(&self) -> CppBox<QModelIndex>
Calls C++ function: QModelIndex QItemSelectionModel::currentIndex() const.
Sourcepub unsafe fn has_selection(&self) -> bool
pub unsafe fn has_selection(&self) -> bool
Calls C++ function: bool QItemSelectionModel::hasSelection() const.
Sourcepub unsafe fn is_column_selected_2a(
&self,
column: c_int,
parent: impl CastInto<Ref<QModelIndex>>,
) -> bool
pub unsafe fn is_column_selected_2a( &self, column: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool
Calls C++ function: bool QItemSelectionModel::isColumnSelected(int column, const QModelIndex& parent = …) const.
Sourcepub unsafe fn is_column_selected_1a(&self, column: c_int) -> bool
pub unsafe fn is_column_selected_1a(&self, column: c_int) -> bool
Calls C++ function: bool QItemSelectionModel::isColumnSelected(int column) const.
Sourcepub unsafe fn is_row_selected_2a(
&self,
row: c_int,
parent: impl CastInto<Ref<QModelIndex>>,
) -> bool
pub unsafe fn is_row_selected_2a( &self, row: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool
Calls C++ function: bool QItemSelectionModel::isRowSelected(int row, const QModelIndex& parent = …) const.
Sourcepub unsafe fn is_row_selected_1a(&self, row: c_int) -> bool
pub unsafe fn is_row_selected_1a(&self, row: c_int) -> bool
Calls C++ function: bool QItemSelectionModel::isRowSelected(int row) const.
Sourcepub unsafe fn is_selected(&self, index: impl CastInto<Ref<QModelIndex>>) -> bool
pub unsafe fn is_selected(&self, index: impl CastInto<Ref<QModelIndex>>) -> bool
Calls C++ function: bool QItemSelectionModel::isSelected(const QModelIndex& index) const.
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QItemSelectionModel::metaObject() const.
Sourcepub unsafe fn model(&self) -> QPtr<QAbstractItemModel>
pub unsafe fn model(&self) -> QPtr<QAbstractItemModel>
Calls C++ function: const QAbstractItemModel* QItemSelectionModel::model() const.
Sourcepub unsafe fn model_mut(&self) -> QPtr<QAbstractItemModel>
pub unsafe fn model_mut(&self) -> QPtr<QAbstractItemModel>
Calls C++ function: QAbstractItemModel* QItemSelectionModel::model().
Sourcepub unsafe fn new_1a(
model: impl CastInto<Ptr<QAbstractItemModel>>,
) -> QBox<QItemSelectionModel>
pub unsafe fn new_1a( model: impl CastInto<Ptr<QAbstractItemModel>>, ) -> QBox<QItemSelectionModel>
Calls C++ function: [constructor] void QItemSelectionModel::QItemSelectionModel(QAbstractItemModel* model = …).
Sourcepub unsafe fn new_2a(
model: impl CastInto<Ptr<QAbstractItemModel>>,
parent: impl CastInto<Ptr<QObject>>,
) -> QBox<QItemSelectionModel>
pub unsafe fn new_2a( model: impl CastInto<Ptr<QAbstractItemModel>>, parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QItemSelectionModel>
Calls C++ function: [constructor] void QItemSelectionModel::QItemSelectionModel(QAbstractItemModel* model, QObject* parent).
Sourcepub unsafe fn new_0a() -> QBox<QItemSelectionModel>
pub unsafe fn new_0a() -> QBox<QItemSelectionModel>
Calls C++ function: [constructor] void QItemSelectionModel::QItemSelectionModel().
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QItemSelectionModel::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QItemSelectionModel::qt_metacast(const char* arg1).
Sourcepub unsafe fn reset(&self)
pub unsafe fn reset(&self)
Calls C++ function: virtual [slot] void QItemSelectionModel::reset().
Sourcepub unsafe fn row_intersects_selection_2a(
&self,
row: c_int,
parent: impl CastInto<Ref<QModelIndex>>,
) -> bool
pub unsafe fn row_intersects_selection_2a( &self, row: c_int, parent: impl CastInto<Ref<QModelIndex>>, ) -> bool
Calls C++ function: bool QItemSelectionModel::rowIntersectsSelection(int row, const QModelIndex& parent = …) const.
Sourcepub unsafe fn row_intersects_selection_1a(&self, row: c_int) -> bool
pub unsafe fn row_intersects_selection_1a(&self, row: c_int) -> bool
Calls C++ function: bool QItemSelectionModel::rowIntersectsSelection(int row) const.
Sourcepub unsafe fn select_q_model_index_q_flags_selection_flag(
&self,
index: impl CastInto<Ref<QModelIndex>>,
command: QFlags<SelectionFlag>,
)
pub unsafe fn select_q_model_index_q_flags_selection_flag( &self, index: impl CastInto<Ref<QModelIndex>>, command: QFlags<SelectionFlag>, )
Calls C++ function: virtual [slot] void QItemSelectionModel::select(const QModelIndex& index, QFlags<QItemSelectionModel::SelectionFlag> command).
Sourcepub unsafe fn select_q_item_selection_q_flags_selection_flag(
&self,
selection: impl CastInto<Ref<QItemSelection>>,
command: QFlags<SelectionFlag>,
)
pub unsafe fn select_q_item_selection_q_flags_selection_flag( &self, selection: impl CastInto<Ref<QItemSelection>>, command: QFlags<SelectionFlag>, )
Calls C++ function: virtual [slot] void QItemSelectionModel::select(const QItemSelection& selection, QFlags<QItemSelectionModel::SelectionFlag> command).
Sourcepub unsafe fn selected_columns_1a(
&self,
row: c_int,
) -> CppBox<QListOfQModelIndex>
pub unsafe fn selected_columns_1a( &self, row: c_int, ) -> CppBox<QListOfQModelIndex>
Calls C++ function: QList<QModelIndex> QItemSelectionModel::selectedColumns(int row = …) const.
Sourcepub unsafe fn selected_columns_0a(&self) -> CppBox<QListOfQModelIndex>
pub unsafe fn selected_columns_0a(&self) -> CppBox<QListOfQModelIndex>
Calls C++ function: QList<QModelIndex> QItemSelectionModel::selectedColumns() const.
Sourcepub unsafe fn selected_indexes(&self) -> CppBox<QListOfQModelIndex>
pub unsafe fn selected_indexes(&self) -> CppBox<QListOfQModelIndex>
Calls C++ function: QList<QModelIndex> QItemSelectionModel::selectedIndexes() const.
Sourcepub unsafe fn selected_rows_1a(
&self,
column: c_int,
) -> CppBox<QListOfQModelIndex>
pub unsafe fn selected_rows_1a( &self, column: c_int, ) -> CppBox<QListOfQModelIndex>
Calls C++ function: QList<QModelIndex> QItemSelectionModel::selectedRows(int column = …) const.
Sourcepub unsafe fn selected_rows_0a(&self) -> CppBox<QListOfQModelIndex>
pub unsafe fn selected_rows_0a(&self) -> CppBox<QListOfQModelIndex>
Calls C++ function: QList<QModelIndex> QItemSelectionModel::selectedRows() const.
Sourcepub unsafe fn selection(&self) -> CppBox<QItemSelection>
pub unsafe fn selection(&self) -> CppBox<QItemSelection>
Calls C++ function: QItemSelection QItemSelectionModel::selection() const.
Sourcepub unsafe fn set_current_index(
&self,
index: impl CastInto<Ref<QModelIndex>>,
command: QFlags<SelectionFlag>,
)
pub unsafe fn set_current_index( &self, index: impl CastInto<Ref<QModelIndex>>, command: QFlags<SelectionFlag>, )
Calls C++ function: virtual [slot] void QItemSelectionModel::setCurrentIndex(const QModelIndex& index, QFlags<QItemSelectionModel::SelectionFlag> command).
Sourcepub unsafe fn set_model(&self, model: impl CastInto<Ptr<QAbstractItemModel>>)
pub unsafe fn set_model(&self, model: impl CastInto<Ptr<QAbstractItemModel>>)
Calls C++ function: void QItemSelectionModel::setModel(QAbstractItemModel* model).
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Methods from Deref<Target = QObject>
Sourcepub unsafe fn find_child<T>(
&self,
name: &str,
) -> Result<QPtr<T>, FindChildError>
pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>
Finds a child of self with the specified object name
and casts it to type T.
The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.
Returns an error if there is no child object with object name name or
the found object cannot be cast to T.
Sourcepub fn destroyed(&self) -> Signal<(*mut QObject,)>
pub fn destroyed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.
Sourcepub fn object_name_changed(&self) -> Signal<(*const QString,)>
pub fn object_name_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_delete_later(&self) -> Receiver<()>
pub fn slot_delete_later(&self) -> Receiver<()>
Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn block_signals(&self, b: bool) -> bool
pub unsafe fn block_signals(&self, b: bool) -> bool
Calls C++ function: bool QObject::blockSignals(bool b).
Sourcepub unsafe fn children(&self) -> Ref<QListOfQObject>
pub unsafe fn children(&self) -> Ref<QListOfQObject>
Calls C++ function: const QList<QObject*>& QObject::children() const.
Sourcepub unsafe fn delete_later(&self)
pub unsafe fn delete_later(&self)
Calls C++ function: [slot] void QObject::deleteLater().
Sourcepub unsafe fn disconnect_char_q_object_char(
&self,
signal: *const c_char,
receiver: impl CastInto<Ptr<QObject>>,
member: *const c_char,
) -> bool
pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.
Sourcepub unsafe fn disconnect_q_object_char(
&self,
receiver: impl CastInto<Ptr<QObject>>,
member: *const c_char,
) -> bool
pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.
Sourcepub unsafe fn disconnect_char_q_object(
&self,
signal: *const c_char,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.
Sourcepub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool
pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …) const.
Sourcepub unsafe fn disconnect(&self) -> bool
pub unsafe fn disconnect(&self) -> bool
Calls C++ function: bool QObject::disconnect() const.
Sourcepub unsafe fn disconnect_q_object(
&self,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.
Sourcepub unsafe fn dump_object_info_mut(&self)
pub unsafe fn dump_object_info_mut(&self)
Calls C++ function: void QObject::dumpObjectInfo().
Sourcepub unsafe fn dump_object_info(&self)
pub unsafe fn dump_object_info(&self)
Calls C++ function: void QObject::dumpObjectInfo() const.
Sourcepub unsafe fn dump_object_tree_mut(&self)
pub unsafe fn dump_object_tree_mut(&self)
Calls C++ function: void QObject::dumpObjectTree().
Sourcepub unsafe fn dump_object_tree(&self)
pub unsafe fn dump_object_tree(&self)
Calls C++ function: void QObject::dumpObjectTree() const.
Sourcepub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.
Sourcepub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QObject::event(QEvent* event).
Sourcepub unsafe fn event_filter(
&self,
watched: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).
Sourcepub unsafe fn find_child_q_object_2a(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_child_q_object_1a(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_string_q_flags_find_child_option(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegExp>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_string(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp(
&self,
re: impl CastInto<Ref<QRegExp>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.
Sourcepub unsafe fn inherits(&self, classname: *const c_char) -> bool
pub unsafe fn inherits(&self, classname: *const c_char) -> bool
Calls C++ function: bool QObject::inherits(const char* classname) const.
Sourcepub unsafe fn install_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QObject>>,
)
pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )
Calls C++ function: void QObject::installEventFilter(QObject* filterObj).
Sourcepub unsafe fn is_widget_type(&self) -> bool
pub unsafe fn is_widget_type(&self) -> bool
Calls C++ function: bool QObject::isWidgetType() const.
Sourcepub unsafe fn is_window_type(&self) -> bool
pub unsafe fn is_window_type(&self) -> bool
Calls C++ function: bool QObject::isWindowType() const.
Sourcepub unsafe fn kill_timer(&self, id: c_int)
pub unsafe fn kill_timer(&self, id: c_int)
Calls C++ function: void QObject::killTimer(int id).
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.
Sourcepub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
Calls C++ function: void QObject::moveToThread(QThread* thread).
Sourcepub unsafe fn object_name(&self) -> CppBox<QString>
pub unsafe fn object_name(&self) -> CppBox<QString>
Calls C++ function: QString QObject::objectName() const.
Sourcepub unsafe fn parent(&self) -> QPtr<QObject>
pub unsafe fn parent(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::parent() const.
Sourcepub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>
pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>
Calls C++ function: QVariant QObject::property(const char* name) const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::removeEventFilter(QObject* obj).
Sourcepub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QObject::setObjectName(const QString& name).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::setParent(QObject* parent).
Sourcepub unsafe fn set_property(
&self,
name: *const c_char,
value: impl CastInto<Ref<QVariant>>,
) -> bool
pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool
Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).
Sourcepub unsafe fn signals_blocked(&self) -> bool
pub unsafe fn signals_blocked(&self) -> bool
Calls C++ function: bool QObject::signalsBlocked() const.
Sourcepub unsafe fn start_timer_2a(
&self,
interval: c_int,
timer_type: TimerType,
) -> c_int
pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int
Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).
Sourcepub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int
pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int
Calls C++ function: int QObject::startTimer(int interval).