QProcess

Struct QProcess 

pub struct QProcess { /* private fields */ }
C++ class: QProcess.

Implementations

Source

impl QProcess

pub fn slot_terminate(&self) -> Receiver<()>

Returns a built-in Qt slot QProcess::terminate that can be passed to qt_core::Signal::connect.

pub fn slot_kill(&self) -> Receiver<()>

Returns a built-in Qt slot QProcess::kill that can be passed to qt_core::Signal::connect.

pub fn started(&self) -> Signal<()>

Returns a built-in Qt signal QProcess::started that can be passed to qt_core::Signal::connect.

pub fn finished(&self) -> Signal<(c_int,)>

Returns a built-in Qt signal QProcess::finished that can be passed to qt_core::Signal::connect.

pub fn finished2(&self) -> Signal<(c_int, ExitStatus)>

Returns a built-in Qt signal QProcess::finished that can be passed to qt_core::Signal::connect.

pub fn error(&self) -> Signal<(ProcessError,)>

Returns a built-in Qt signal QProcess::error that can be passed to qt_core::Signal::connect.

pub fn error_occurred(&self) -> Signal<(ProcessError,)>

Returns a built-in Qt signal QProcess::errorOccurred that can be passed to qt_core::Signal::connect.

pub fn state_changed(&self) -> Signal<(ProcessState,)>

Returns a built-in Qt signal QProcess::stateChanged that can be passed to qt_core::Signal::connect.

pub fn ready_read_standard_output(&self) -> Signal<()>

Returns a built-in Qt signal QProcess::readyReadStandardOutput that can be passed to qt_core::Signal::connect.

pub fn ready_read_standard_error(&self) -> Signal<()>

Returns a built-in Qt signal QProcess::readyReadStandardError that can be passed to qt_core::Signal::connect.

pub unsafe fn arguments(&self) -> CppBox<QStringList>

Calls C++ function: QStringList QProcess::arguments() const.

pub unsafe fn at_end(&self) -> bool

Calls C++ function: virtual bool QProcess::atEnd() const.

pub unsafe fn bytes_available(&self) -> c_longlong

Calls C++ function: virtual long long QProcess::bytesAvailable() const.

pub unsafe fn bytes_to_write(&self) -> c_longlong

Calls C++ function: virtual long long QProcess::bytesToWrite() const.

pub unsafe fn can_read_line(&self) -> bool

Calls C++ function: virtual bool QProcess::canReadLine() const.

pub unsafe fn close(&self)

Calls C++ function: virtual void QProcess::close().

pub unsafe fn close_read_channel(&self, channel: ProcessChannel)

Calls C++ function: void QProcess::closeReadChannel(QProcess::ProcessChannel channel).

pub unsafe fn close_write_channel(&self)

Calls C++ function: void QProcess::closeWriteChannel().

pub unsafe fn environment(&self) -> CppBox<QStringList>

Calls C++ function: QStringList QProcess::environment() const.

pub unsafe fn error2(&self) -> ProcessError

Calls C++ function: QProcess::ProcessError QProcess::error() const.

pub unsafe fn execute_2a( program: impl CastInto<Ref<QString>>, arguments: impl CastInto<Ref<QStringList>>, ) -> c_int

Calls C++ function: static int QProcess::execute(const QString& program, const QStringList& arguments).

pub unsafe fn execute_1a(command: impl CastInto<Ref<QString>>) -> c_int

Calls C++ function: static int QProcess::execute(const QString& command).

pub unsafe fn exit_code(&self) -> c_int

Calls C++ function: int QProcess::exitCode() const.

pub unsafe fn exit_status(&self) -> ExitStatus

Calls C++ function: QProcess::ExitStatus QProcess::exitStatus() const.

pub unsafe fn input_channel_mode(&self) -> InputChannelMode

Calls C++ function: QProcess::InputChannelMode QProcess::inputChannelMode() const.

pub unsafe fn is_sequential(&self) -> bool

Calls C++ function: virtual bool QProcess::isSequential() const.

pub unsafe fn kill(&self)

Calls C++ function: [slot] void QProcess::kill().

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QProcess::metaObject() const.

pub unsafe fn new_1a(parent: impl CastInto<Ptr<QObject>>) -> QBox<QProcess>

Calls C++ function: [constructor] void QProcess::QProcess(QObject* parent = …).

pub unsafe fn new_0a() -> QBox<QProcess>

Calls C++ function: [constructor] void QProcess::QProcess().

pub unsafe fn null_device() -> CppBox<QString>

Calls C++ function: static QString QProcess::nullDevice().

pub unsafe fn open_1a(&self, mode: QFlags<OpenModeFlag>) -> bool

Calls C++ function: virtual bool QProcess::open(QFlags<QIODevice::OpenModeFlag> mode = …).

pub unsafe fn open_0a(&self) -> bool

Calls C++ function: virtual bool QProcess::open().

pub unsafe fn process_channel_mode(&self) -> ProcessChannelMode

Calls C++ function: QProcess::ProcessChannelMode QProcess::processChannelMode() const.

pub unsafe fn process_environment(&self) -> CppBox<QProcessEnvironment>

Calls C++ function: QProcessEnvironment QProcess::processEnvironment() const.

pub unsafe fn process_id(&self) -> c_longlong

Calls C++ function: long long QProcess::processId() const.

pub unsafe fn program(&self) -> CppBox<QString>

Calls C++ function: QString QProcess::program() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QProcess::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QProcess::qt_metacast(const char* arg1).

pub unsafe fn read_all_standard_error(&self) -> CppBox<QByteArray>

Calls C++ function: QByteArray QProcess::readAllStandardError().

pub unsafe fn read_all_standard_output(&self) -> CppBox<QByteArray>

Calls C++ function: QByteArray QProcess::readAllStandardOutput().

pub unsafe fn read_channel(&self) -> ProcessChannel

Calls C++ function: QProcess::ProcessChannel QProcess::readChannel() const.

pub unsafe fn read_channel_mode(&self) -> ProcessChannelMode

Calls C++ function: QProcess::ProcessChannelMode QProcess::readChannelMode() const.

pub unsafe fn set_arguments(&self, arguments: impl CastInto<Ref<QStringList>>)

Calls C++ function: void QProcess::setArguments(const QStringList& arguments).

pub unsafe fn set_environment( &self, environment: impl CastInto<Ref<QStringList>>, )

Calls C++ function: void QProcess::setEnvironment(const QStringList& environment).

pub unsafe fn set_input_channel_mode(&self, mode: InputChannelMode)

Calls C++ function: void QProcess::setInputChannelMode(QProcess::InputChannelMode mode).

pub unsafe fn set_process_channel_mode(&self, mode: ProcessChannelMode)

Calls C++ function: void QProcess::setProcessChannelMode(QProcess::ProcessChannelMode mode).

pub unsafe fn set_process_environment( &self, environment: impl CastInto<Ref<QProcessEnvironment>>, )

Calls C++ function: void QProcess::setProcessEnvironment(const QProcessEnvironment& environment).

pub unsafe fn set_program(&self, program: impl CastInto<Ref<QString>>)

Calls C++ function: void QProcess::setProgram(const QString& program).

pub unsafe fn set_read_channel(&self, channel: ProcessChannel)

Calls C++ function: void QProcess::setReadChannel(QProcess::ProcessChannel channel).

pub unsafe fn set_read_channel_mode(&self, mode: ProcessChannelMode)

Calls C++ function: void QProcess::setReadChannelMode(QProcess::ProcessChannelMode mode).

pub unsafe fn set_standard_error_file_2a( &self, file_name: impl CastInto<Ref<QString>>, mode: QFlags<OpenModeFlag>, )

Calls C++ function: void QProcess::setStandardErrorFile(const QString& fileName, QFlags<QIODevice::OpenModeFlag> mode = …).

pub unsafe fn set_standard_error_file_1a( &self, file_name: impl CastInto<Ref<QString>>, )

Calls C++ function: void QProcess::setStandardErrorFile(const QString& fileName).

pub unsafe fn set_standard_input_file( &self, file_name: impl CastInto<Ref<QString>>, )

Calls C++ function: void QProcess::setStandardInputFile(const QString& fileName).

pub unsafe fn set_standard_output_file_2a( &self, file_name: impl CastInto<Ref<QString>>, mode: QFlags<OpenModeFlag>, )

Calls C++ function: void QProcess::setStandardOutputFile(const QString& fileName, QFlags<QIODevice::OpenModeFlag> mode = …).

pub unsafe fn set_standard_output_file_1a( &self, file_name: impl CastInto<Ref<QString>>, )

Calls C++ function: void QProcess::setStandardOutputFile(const QString& fileName).

pub unsafe fn set_standard_output_process( &self, destination: impl CastInto<Ptr<QProcess>>, )

Calls C++ function: void QProcess::setStandardOutputProcess(QProcess* destination).

pub unsafe fn set_working_directory(&self, dir: impl CastInto<Ref<QString>>)

Calls C++ function: void QProcess::setWorkingDirectory(const QString& dir).

pub unsafe fn split_command( command: impl CastInto<Ref<QStringView>>, ) -> CppBox<QStringList>

Calls C++ function: static QStringList QProcess::splitCommand(QStringView command).

pub unsafe fn start_q_string_q_string_list_q_flags_open_mode_flag( &self, program: impl CastInto<Ref<QString>>, arguments: impl CastInto<Ref<QStringList>>, mode: QFlags<OpenModeFlag>, )

Calls C++ function: void QProcess::start(const QString& program, const QStringList& arguments, QFlags<QIODevice::OpenModeFlag> mode = …).

pub unsafe fn start_q_string_q_flags_open_mode_flag( &self, command: impl CastInto<Ref<QString>>, mode: QFlags<OpenModeFlag>, )

Calls C++ function: void QProcess::start(const QString& command, QFlags<QIODevice::OpenModeFlag> mode = …).

pub unsafe fn start_q_flags_open_mode_flag(&self, mode: QFlags<OpenModeFlag>)

Calls C++ function: void QProcess::start(QFlags<QIODevice::OpenModeFlag> mode = …).

pub unsafe fn start_q_string_q_string_list( &self, program: impl CastInto<Ref<QString>>, arguments: impl CastInto<Ref<QStringList>>, )

Calls C++ function: void QProcess::start(const QString& program, const QStringList& arguments).

pub unsafe fn start_q_string(&self, command: impl CastInto<Ref<QString>>)

Calls C++ function: void QProcess::start(const QString& command).

pub unsafe fn start(&self)

Calls C++ function: void QProcess::start().

pub unsafe fn start_detached_1a_mut(&self, pid: *mut c_longlong) -> bool

Calls C++ function: bool QProcess::startDetached(long long* pid = …).

pub unsafe fn start_detached_4a( program: impl CastInto<Ref<QString>>, arguments: impl CastInto<Ref<QStringList>>, working_directory: impl CastInto<Ref<QString>>, pid: *mut c_longlong, ) -> bool

Calls C++ function: static bool QProcess::startDetached(const QString& program, const QStringList& arguments, const QString& workingDirectory, long long* pid = …).

pub unsafe fn start_detached_2a( program: impl CastInto<Ref<QString>>, arguments: impl CastInto<Ref<QStringList>>, ) -> bool

Calls C++ function: static bool QProcess::startDetached(const QString& program, const QStringList& arguments).

pub unsafe fn start_detached_1a(command: impl CastInto<Ref<QString>>) -> bool

Calls C++ function: static bool QProcess::startDetached(const QString& command).

pub unsafe fn start_detached_0a_mut(&self) -> bool

Calls C++ function: bool QProcess::startDetached().

pub unsafe fn start_detached_3a( program: impl CastInto<Ref<QString>>, arguments: impl CastInto<Ref<QStringList>>, working_directory: impl CastInto<Ref<QString>>, ) -> bool

Calls C++ function: static bool QProcess::startDetached(const QString& program, const QStringList& arguments, const QString& workingDirectory).

pub unsafe fn state(&self) -> ProcessState

Calls C++ function: QProcess::ProcessState QProcess::state() const.

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn system_environment() -> CppBox<QStringList>

Calls C++ function: static QStringList QProcess::systemEnvironment().

pub unsafe fn terminate(&self)

Calls C++ function: [slot] void QProcess::terminate().

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QProcess::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QProcess::trUtf8(const char* s, const char* c, int n).

pub unsafe fn wait_for_bytes_written_1a(&self, msecs: c_int) -> bool

Calls C++ function: virtual bool QProcess::waitForBytesWritten(int msecs = …).

pub unsafe fn wait_for_bytes_written_0a(&self) -> bool

Calls C++ function: virtual bool QProcess::waitForBytesWritten().

pub unsafe fn wait_for_finished_1a(&self, msecs: c_int) -> bool

Calls C++ function: bool QProcess::waitForFinished(int msecs = …).

pub unsafe fn wait_for_finished_0a(&self) -> bool

Calls C++ function: bool QProcess::waitForFinished().

pub unsafe fn wait_for_ready_read_1a(&self, msecs: c_int) -> bool

Calls C++ function: virtual bool QProcess::waitForReadyRead(int msecs = …).

pub unsafe fn wait_for_ready_read_0a(&self) -> bool

Calls C++ function: virtual bool QProcess::waitForReadyRead().

pub unsafe fn wait_for_started_1a(&self, msecs: c_int) -> bool

Calls C++ function: bool QProcess::waitForStarted(int msecs = …).

pub unsafe fn wait_for_started_0a(&self) -> bool

Calls C++ function: bool QProcess::waitForStarted().

pub unsafe fn working_directory(&self) -> CppBox<QString>

Calls C++ function: QString QProcess::workingDirectory() const.

Methods from Deref<Target = QIODevice>

pub fn ready_read(&self) -> Signal<()>

Returns a built-in Qt signal QIODevice::readyRead that can be passed to qt_core::Signal::connect.

pub fn channel_ready_read(&self) -> Signal<(c_int,)>

Returns a built-in Qt signal QIODevice::channelReadyRead that can be passed to qt_core::Signal::connect.

pub fn bytes_written(&self) -> Signal<(c_longlong,)>

Returns a built-in Qt signal QIODevice::bytesWritten that can be passed to qt_core::Signal::connect.

pub fn channel_bytes_written(&self) -> Signal<(c_int, c_longlong)>

Returns a built-in Qt signal QIODevice::channelBytesWritten that can be passed to qt_core::Signal::connect.

pub fn about_to_close(&self) -> Signal<()>

Returns a built-in Qt signal QIODevice::aboutToClose that can be passed to qt_core::Signal::connect.

pub fn read_channel_finished(&self) -> Signal<()>

Returns a built-in Qt signal QIODevice::readChannelFinished that can be passed to qt_core::Signal::connect.

pub unsafe fn at_end(&self) -> bool

Calls C++ function: virtual bool QIODevice::atEnd() const.

pub unsafe fn bytes_available(&self) -> c_longlong

Calls C++ function: virtual long long QIODevice::bytesAvailable() const.

pub unsafe fn bytes_to_write(&self) -> c_longlong

Calls C++ function: virtual long long QIODevice::bytesToWrite() const.

pub unsafe fn can_read_line(&self) -> bool

Calls C++ function: virtual bool QIODevice::canReadLine() const.

pub unsafe fn close(&self)

Calls C++ function: virtual void QIODevice::close().

pub unsafe fn commit_transaction(&self)

Calls C++ function: void QIODevice::commitTransaction().

pub unsafe fn current_read_channel(&self) -> c_int

Calls C++ function: int QIODevice::currentReadChannel() const.

pub unsafe fn current_write_channel(&self) -> c_int

Calls C++ function: int QIODevice::currentWriteChannel() const.

pub unsafe fn error_string(&self) -> CppBox<QString>

Calls C++ function: QString QIODevice::errorString() const.

pub unsafe fn get_char(&self, c: *mut c_char) -> bool

Calls C++ function: bool QIODevice::getChar(char* c).

pub unsafe fn is_open(&self) -> bool

Calls C++ function: bool QIODevice::isOpen() const.

pub unsafe fn is_readable(&self) -> bool

Calls C++ function: bool QIODevice::isReadable() const.

pub unsafe fn is_sequential(&self) -> bool

Calls C++ function: virtual bool QIODevice::isSequential() const.

pub unsafe fn is_text_mode_enabled(&self) -> bool

Calls C++ function: bool QIODevice::isTextModeEnabled() const.

pub unsafe fn is_transaction_started(&self) -> bool

Calls C++ function: bool QIODevice::isTransactionStarted() const.

pub unsafe fn is_writable(&self) -> bool

Calls C++ function: bool QIODevice::isWritable() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QIODevice::metaObject() const.

pub unsafe fn open(&self, mode: QFlags<OpenModeFlag>) -> bool

Calls C++ function: virtual bool QIODevice::open(QFlags<QIODevice::OpenModeFlag> mode).

pub unsafe fn open_mode(&self) -> QFlags<OpenModeFlag>

Calls C++ function: QFlags<QIODevice::OpenModeFlag> QIODevice::openMode() const.

pub unsafe fn peek_2a( &self, data: *mut c_char, maxlen: c_longlong, ) -> c_longlong

Calls C++ function: long long QIODevice::peek(char* data, long long maxlen).

pub unsafe fn peek_1a(&self, maxlen: c_longlong) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::peek(long long maxlen).

pub unsafe fn pos(&self) -> c_longlong

Calls C++ function: virtual long long QIODevice::pos() const.

pub unsafe fn put_char(&self, c: c_char) -> bool

Calls C++ function: bool QIODevice::putChar(char c).

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QIODevice::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QIODevice::qt_metacast(const char* arg1).

pub unsafe fn read_2a( &self, data: *mut c_char, maxlen: c_longlong, ) -> c_longlong

Calls C++ function: long long QIODevice::read(char* data, long long maxlen).

pub unsafe fn read_1a(&self, maxlen: c_longlong) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::read(long long maxlen).

pub unsafe fn read_all(&self) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::readAll().

pub unsafe fn read_channel_count(&self) -> c_int

Calls C++ function: int QIODevice::readChannelCount() const.

pub unsafe fn read_line_2a( &self, data: *mut c_char, maxlen: c_longlong, ) -> c_longlong

Calls C++ function: long long QIODevice::readLine(char* data, long long maxlen).

pub unsafe fn read_line_1a(&self, maxlen: c_longlong) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::readLine(long long maxlen = …).

pub unsafe fn read_line_0a(&self) -> CppBox<QByteArray>

Calls C++ function: QByteArray QIODevice::readLine().

pub unsafe fn reset(&self) -> bool

Calls C++ function: virtual bool QIODevice::reset().

pub unsafe fn rollback_transaction(&self)

Calls C++ function: void QIODevice::rollbackTransaction().

pub unsafe fn seek(&self, pos: c_longlong) -> bool

Calls C++ function: virtual bool QIODevice::seek(long long pos).

pub unsafe fn set_current_read_channel(&self, channel: c_int)

Calls C++ function: void QIODevice::setCurrentReadChannel(int channel).

pub unsafe fn set_current_write_channel(&self, channel: c_int)

Calls C++ function: void QIODevice::setCurrentWriteChannel(int channel).

pub unsafe fn set_text_mode_enabled(&self, enabled: bool)

Calls C++ function: void QIODevice::setTextModeEnabled(bool enabled).

pub unsafe fn size(&self) -> c_longlong

Calls C++ function: virtual long long QIODevice::size() const.

pub unsafe fn skip(&self, max_size: c_longlong) -> c_longlong

Calls C++ function: long long QIODevice::skip(long long maxSize).

pub unsafe fn start_transaction(&self)

Calls C++ function: void QIODevice::startTransaction().

pub unsafe fn unget_char(&self, c: c_char)

Calls C++ function: void QIODevice::ungetChar(char c).

pub unsafe fn wait_for_bytes_written(&self, msecs: c_int) -> bool

Calls C++ function: virtual bool QIODevice::waitForBytesWritten(int msecs).

pub unsafe fn wait_for_ready_read(&self, msecs: c_int) -> bool

Calls C++ function: virtual bool QIODevice::waitForReadyRead(int msecs).

pub unsafe fn write_char_longlong( &self, data: *const c_char, len: c_longlong, ) -> c_longlong

Calls C++ function: long long QIODevice::write(const char* data, long long len).

pub unsafe fn write_char(&self, data: *const c_char) -> c_longlong

Calls C++ function: long long QIODevice::write(const char* data).

pub unsafe fn write_q_byte_array( &self, data: impl CastInto<Ref<QByteArray>>, ) -> c_longlong

Calls C++ function: long long QIODevice::write(const QByteArray& data).

pub unsafe fn write_channel_count(&self) -> c_int

Calls C++ function: int QIODevice::writeChannelCount() const.

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const c_char) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: c_int)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.