pub struct QPropertyAnimation { /* private fields */ }Expand description
C++ class: QPropertyAnimation.
Implementations
Sourceimpl QPropertyAnimation
impl QPropertyAnimation
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QPropertyAnimation::metaObject() const.
Sourcepub unsafe fn new_1a(
parent: impl CastInto<Ptr<QObject>>,
) -> QBox<QPropertyAnimation>
pub unsafe fn new_1a( parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QPropertyAnimation>
Calls C++ function: [constructor] void QPropertyAnimation::QPropertyAnimation(QObject* parent = …).
Sourcepub unsafe fn new_3a(
target: impl CastInto<Ptr<QObject>>,
property_name: impl CastInto<Ref<QByteArray>>,
parent: impl CastInto<Ptr<QObject>>,
) -> QBox<QPropertyAnimation>
pub unsafe fn new_3a( target: impl CastInto<Ptr<QObject>>, property_name: impl CastInto<Ref<QByteArray>>, parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QPropertyAnimation>
Calls C++ function: [constructor] void QPropertyAnimation::QPropertyAnimation(QObject* target, const QByteArray& propertyName, QObject* parent = …).
Sourcepub unsafe fn new_0a() -> QBox<QPropertyAnimation>
pub unsafe fn new_0a() -> QBox<QPropertyAnimation>
Calls C++ function: [constructor] void QPropertyAnimation::QPropertyAnimation().
Sourcepub unsafe fn new_2a(
target: impl CastInto<Ptr<QObject>>,
property_name: impl CastInto<Ref<QByteArray>>,
) -> QBox<QPropertyAnimation>
pub unsafe fn new_2a( target: impl CastInto<Ptr<QObject>>, property_name: impl CastInto<Ref<QByteArray>>, ) -> QBox<QPropertyAnimation>
Calls C++ function: [constructor] void QPropertyAnimation::QPropertyAnimation(QObject* target, const QByteArray& propertyName).
Sourcepub unsafe fn property_name(&self) -> CppBox<QByteArray>
pub unsafe fn property_name(&self) -> CppBox<QByteArray>
Calls C++ function: QByteArray QPropertyAnimation::propertyName() const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QPropertyAnimation::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QPropertyAnimation::qt_metacast(const char* arg1).
Sourcepub unsafe fn set_property_name(
&self,
property_name: impl CastInto<Ref<QByteArray>>,
)
pub unsafe fn set_property_name( &self, property_name: impl CastInto<Ref<QByteArray>>, )
Calls C++ function: void QPropertyAnimation::setPropertyName(const QByteArray& propertyName).
Sourcepub unsafe fn set_target_object(&self, target: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_target_object(&self, target: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QPropertyAnimation::setTargetObject(QObject* target).
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Sourcepub unsafe fn target_object(&self) -> QPtr<QObject>
pub unsafe fn target_object(&self) -> QPtr<QObject>
Calls C++ function: QObject* QPropertyAnimation::targetObject() const.
Methods from Deref<Target = QVariantAnimation>
Sourcepub fn value_changed(&self) -> Signal<(*const QVariant,)>
pub fn value_changed(&self) -> Signal<(*const QVariant,)>
Returns a built-in Qt signal QVariantAnimation::valueChanged that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn current_value(&self) -> CppBox<QVariant>
pub unsafe fn current_value(&self) -> CppBox<QVariant>
Calls C++ function: QVariant QVariantAnimation::currentValue() const.
Sourcepub unsafe fn duration(&self) -> c_int
pub unsafe fn duration(&self) -> c_int
Calls C++ function: virtual int QVariantAnimation::duration() const.
Sourcepub unsafe fn easing_curve(&self) -> CppBox<QEasingCurve>
pub unsafe fn easing_curve(&self) -> CppBox<QEasingCurve>
Calls C++ function: QEasingCurve QVariantAnimation::easingCurve() const.
Sourcepub unsafe fn end_value(&self) -> CppBox<QVariant>
pub unsafe fn end_value(&self) -> CppBox<QVariant>
Calls C++ function: QVariant QVariantAnimation::endValue() const.
Sourcepub unsafe fn key_value_at(&self, step: c_double) -> CppBox<QVariant>
pub unsafe fn key_value_at(&self, step: c_double) -> CppBox<QVariant>
Calls C++ function: QVariant QVariantAnimation::keyValueAt(double step) const.
Sourcepub unsafe fn key_values(&self) -> CppBox<QVectorOfQPairOfDoubleQVariant>
pub unsafe fn key_values(&self) -> CppBox<QVectorOfQPairOfDoubleQVariant>
Calls C++ function: QVector<QPair<double, QVariant>> QVariantAnimation::keyValues() const.
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QVariantAnimation::metaObject() const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QVariantAnimation::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QVariantAnimation::qt_metacast(const char* arg1).
Sourcepub unsafe fn set_duration(&self, msecs: c_int)
pub unsafe fn set_duration(&self, msecs: c_int)
Calls C++ function: void QVariantAnimation::setDuration(int msecs).
Sourcepub unsafe fn set_easing_curve(&self, easing: impl CastInto<Ref<QEasingCurve>>)
pub unsafe fn set_easing_curve(&self, easing: impl CastInto<Ref<QEasingCurve>>)
Calls C++ function: void QVariantAnimation::setEasingCurve(const QEasingCurve& easing).
Sourcepub unsafe fn set_end_value(&self, value: impl CastInto<Ref<QVariant>>)
pub unsafe fn set_end_value(&self, value: impl CastInto<Ref<QVariant>>)
Calls C++ function: void QVariantAnimation::setEndValue(const QVariant& value).
Sourcepub unsafe fn set_key_value_at(
&self,
step: c_double,
value: impl CastInto<Ref<QVariant>>,
)
pub unsafe fn set_key_value_at( &self, step: c_double, value: impl CastInto<Ref<QVariant>>, )
Calls C++ function: void QVariantAnimation::setKeyValueAt(double step, const QVariant& value).
Sourcepub unsafe fn set_key_values(
&self,
values: impl CastInto<Ref<QVectorOfQPairOfDoubleQVariant>>,
)
pub unsafe fn set_key_values( &self, values: impl CastInto<Ref<QVectorOfQPairOfDoubleQVariant>>, )
Calls C++ function: void QVariantAnimation::setKeyValues(const QVector<QPair<double, QVariant>>& values).
Sourcepub unsafe fn set_start_value(&self, value: impl CastInto<Ref<QVariant>>)
pub unsafe fn set_start_value(&self, value: impl CastInto<Ref<QVariant>>)
Calls C++ function: void QVariantAnimation::setStartValue(const QVariant& value).
Sourcepub unsafe fn start_value(&self) -> CppBox<QVariant>
pub unsafe fn start_value(&self) -> CppBox<QVariant>
Calls C++ function: QVariant QVariantAnimation::startValue() const.
Methods from Deref<Target = QAbstractAnimation>
Sourcepub fn finished(&self) -> Signal<()>
pub fn finished(&self) -> Signal<()>
Returns a built-in Qt signal QAbstractAnimation::finished that can be passed to qt_core::Signal::connect.
Sourcepub fn state_changed(&self) -> Signal<(State, State)>
pub fn state_changed(&self) -> Signal<(State, State)>
Returns a built-in Qt signal QAbstractAnimation::stateChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn current_loop_changed(&self) -> Signal<(c_int,)>
pub fn current_loop_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QAbstractAnimation::currentLoopChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn direction_changed(&self) -> Signal<(Direction,)>
pub fn direction_changed(&self) -> Signal<(Direction,)>
Returns a built-in Qt signal QAbstractAnimation::directionChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_start(&self) -> Receiver<(DeletionPolicy,)>
pub fn slot_start(&self) -> Receiver<(DeletionPolicy,)>
Returns a built-in Qt slot QAbstractAnimation::start that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_pause(&self) -> Receiver<()>
pub fn slot_pause(&self) -> Receiver<()>
Returns a built-in Qt slot QAbstractAnimation::pause that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_resume(&self) -> Receiver<()>
pub fn slot_resume(&self) -> Receiver<()>
Returns a built-in Qt slot QAbstractAnimation::resume that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_paused(&self) -> Receiver<(bool,)>
pub fn slot_set_paused(&self) -> Receiver<(bool,)>
Returns a built-in Qt slot QAbstractAnimation::setPaused that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_stop(&self) -> Receiver<()>
pub fn slot_stop(&self) -> Receiver<()>
Returns a built-in Qt slot QAbstractAnimation::stop that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_current_time(&self) -> Receiver<(c_int,)>
pub fn slot_set_current_time(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QAbstractAnimation::setCurrentTime that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn current_loop(&self) -> c_int
pub unsafe fn current_loop(&self) -> c_int
Calls C++ function: int QAbstractAnimation::currentLoop() const.
Sourcepub unsafe fn current_loop_time(&self) -> c_int
pub unsafe fn current_loop_time(&self) -> c_int
Calls C++ function: int QAbstractAnimation::currentLoopTime() const.
Sourcepub unsafe fn current_time(&self) -> c_int
pub unsafe fn current_time(&self) -> c_int
Calls C++ function: int QAbstractAnimation::currentTime() const.
Sourcepub unsafe fn direction(&self) -> Direction
pub unsafe fn direction(&self) -> Direction
Calls C++ function: QAbstractAnimation::Direction QAbstractAnimation::direction() const.
Sourcepub unsafe fn duration(&self) -> c_int
pub unsafe fn duration(&self) -> c_int
Calls C++ function: pure virtual int QAbstractAnimation::duration() const.
Sourcepub unsafe fn group(&self) -> QPtr<QAnimationGroup>
pub unsafe fn group(&self) -> QPtr<QAnimationGroup>
Calls C++ function: QAnimationGroup* QAbstractAnimation::group() const.
Sourcepub unsafe fn loop_count(&self) -> c_int
pub unsafe fn loop_count(&self) -> c_int
Calls C++ function: int QAbstractAnimation::loopCount() const.
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QAbstractAnimation::metaObject() const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QAbstractAnimation::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QAbstractAnimation::qt_metacast(const char* arg1).
Sourcepub unsafe fn set_current_time(&self, msecs: c_int)
pub unsafe fn set_current_time(&self, msecs: c_int)
Calls C++ function: [slot] void QAbstractAnimation::setCurrentTime(int msecs).
Sourcepub unsafe fn set_direction(&self, direction: Direction)
pub unsafe fn set_direction(&self, direction: Direction)
Calls C++ function: void QAbstractAnimation::setDirection(QAbstractAnimation::Direction direction).
Sourcepub unsafe fn set_loop_count(&self, loop_count: c_int)
pub unsafe fn set_loop_count(&self, loop_count: c_int)
Calls C++ function: void QAbstractAnimation::setLoopCount(int loopCount).
Sourcepub unsafe fn set_paused(&self, arg1: bool)
pub unsafe fn set_paused(&self, arg1: bool)
Calls C++ function: [slot] void QAbstractAnimation::setPaused(bool arg1).
Sourcepub unsafe fn start_1a(&self, policy: DeletionPolicy)
pub unsafe fn start_1a(&self, policy: DeletionPolicy)
Calls C++ function: [slot] void QAbstractAnimation::start(QAbstractAnimation::DeletionPolicy policy = …).
Sourcepub unsafe fn state(&self) -> State
pub unsafe fn state(&self) -> State
Calls C++ function: QAbstractAnimation::State QAbstractAnimation::state() const.
Sourcepub unsafe fn total_duration(&self) -> c_int
pub unsafe fn total_duration(&self) -> c_int
Calls C++ function: int QAbstractAnimation::totalDuration() const.
Methods from Deref<Target = QObject>
Sourcepub unsafe fn find_child<T>(
&self,
name: &str,
) -> Result<QPtr<T>, FindChildError>
pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>
Finds a child of self with the specified object name
and casts it to type T.
The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.
Returns an error if there is no child object with object name name or
the found object cannot be cast to T.
Sourcepub fn destroyed(&self) -> Signal<(*mut QObject,)>
pub fn destroyed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.
Sourcepub fn object_name_changed(&self) -> Signal<(*const QString,)>
pub fn object_name_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_delete_later(&self) -> Receiver<()>
pub fn slot_delete_later(&self) -> Receiver<()>
Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn block_signals(&self, b: bool) -> bool
pub unsafe fn block_signals(&self, b: bool) -> bool
Calls C++ function: bool QObject::blockSignals(bool b).
Sourcepub unsafe fn children(&self) -> Ref<QListOfQObject>
pub unsafe fn children(&self) -> Ref<QListOfQObject>
Calls C++ function: const QList<QObject*>& QObject::children() const.
Sourcepub unsafe fn delete_later(&self)
pub unsafe fn delete_later(&self)
Calls C++ function: [slot] void QObject::deleteLater().
Sourcepub unsafe fn disconnect_char_q_object_char(
&self,
signal: *const c_char,
receiver: impl CastInto<Ptr<QObject>>,
member: *const c_char,
) -> bool
pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.
Sourcepub unsafe fn disconnect_q_object_char(
&self,
receiver: impl CastInto<Ptr<QObject>>,
member: *const c_char,
) -> bool
pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.
Sourcepub unsafe fn disconnect_char_q_object(
&self,
signal: *const c_char,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.
Sourcepub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool
pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …) const.
Sourcepub unsafe fn disconnect(&self) -> bool
pub unsafe fn disconnect(&self) -> bool
Calls C++ function: bool QObject::disconnect() const.
Sourcepub unsafe fn disconnect_q_object(
&self,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.
Sourcepub unsafe fn dump_object_info_mut(&self)
pub unsafe fn dump_object_info_mut(&self)
Calls C++ function: void QObject::dumpObjectInfo().
Sourcepub unsafe fn dump_object_info(&self)
pub unsafe fn dump_object_info(&self)
Calls C++ function: void QObject::dumpObjectInfo() const.
Sourcepub unsafe fn dump_object_tree_mut(&self)
pub unsafe fn dump_object_tree_mut(&self)
Calls C++ function: void QObject::dumpObjectTree().
Sourcepub unsafe fn dump_object_tree(&self)
pub unsafe fn dump_object_tree(&self)
Calls C++ function: void QObject::dumpObjectTree() const.
Sourcepub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.
Sourcepub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QObject::event(QEvent* event).
Sourcepub unsafe fn event_filter(
&self,
watched: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).
Sourcepub unsafe fn find_child_q_object_2a(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_child_q_object_1a(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_string_q_flags_find_child_option(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegExp>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_string(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp(
&self,
re: impl CastInto<Ref<QRegExp>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.
Sourcepub unsafe fn inherits(&self, classname: *const c_char) -> bool
pub unsafe fn inherits(&self, classname: *const c_char) -> bool
Calls C++ function: bool QObject::inherits(const char* classname) const.
Sourcepub unsafe fn install_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QObject>>,
)
pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )
Calls C++ function: void QObject::installEventFilter(QObject* filterObj).
Sourcepub unsafe fn is_widget_type(&self) -> bool
pub unsafe fn is_widget_type(&self) -> bool
Calls C++ function: bool QObject::isWidgetType() const.
Sourcepub unsafe fn is_window_type(&self) -> bool
pub unsafe fn is_window_type(&self) -> bool
Calls C++ function: bool QObject::isWindowType() const.
Sourcepub unsafe fn kill_timer(&self, id: c_int)
pub unsafe fn kill_timer(&self, id: c_int)
Calls C++ function: void QObject::killTimer(int id).
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.
Sourcepub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
Calls C++ function: void QObject::moveToThread(QThread* thread).
Sourcepub unsafe fn object_name(&self) -> CppBox<QString>
pub unsafe fn object_name(&self) -> CppBox<QString>
Calls C++ function: QString QObject::objectName() const.
Sourcepub unsafe fn parent(&self) -> QPtr<QObject>
pub unsafe fn parent(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::parent() const.
Sourcepub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>
pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>
Calls C++ function: QVariant QObject::property(const char* name) const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::removeEventFilter(QObject* obj).
Sourcepub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QObject::setObjectName(const QString& name).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::setParent(QObject* parent).
Sourcepub unsafe fn set_property(
&self,
name: *const c_char,
value: impl CastInto<Ref<QVariant>>,
) -> bool
pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool
Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).
Sourcepub unsafe fn signals_blocked(&self) -> bool
pub unsafe fn signals_blocked(&self) -> bool
Calls C++ function: bool QObject::signalsBlocked() const.
Sourcepub unsafe fn start_timer_2a(
&self,
interval: c_int,
timer_type: TimerType,
) -> c_int
pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int
Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).
Sourcepub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int
pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int
Calls C++ function: int QObject::startTimer(int interval).