QStateMachine

Struct QStateMachine 

pub struct QStateMachine { /* private fields */ }
C++ class: QStateMachine.

Implementations

Source

impl QStateMachine

pub fn slot_start(&self) -> Receiver<()>

Returns a built-in Qt slot QStateMachine::start that can be passed to qt_core::Signal::connect.

pub fn slot_stop(&self) -> Receiver<()>

Returns a built-in Qt slot QStateMachine::stop that can be passed to qt_core::Signal::connect.

pub fn slot_set_running(&self) -> Receiver<(bool,)>

Returns a built-in Qt slot QStateMachine::setRunning that can be passed to qt_core::Signal::connect.

pub fn started(&self) -> Signal<()>

Returns a built-in Qt signal QStateMachine::started that can be passed to qt_core::Signal::connect.

pub fn stopped(&self) -> Signal<()>

Returns a built-in Qt signal QStateMachine::stopped that can be passed to qt_core::Signal::connect.

pub fn running_changed(&self) -> Signal<(bool,)>

Returns a built-in Qt signal QStateMachine::runningChanged that can be passed to qt_core::Signal::connect.

pub unsafe fn add_default_animation( &self, animation: impl CastInto<Ptr<QAbstractAnimation>>, )

Calls C++ function: void QStateMachine::addDefaultAnimation(QAbstractAnimation* animation).

pub unsafe fn add_state(&self, state: impl CastInto<Ptr<QAbstractState>>)

Calls C++ function: void QStateMachine::addState(QAbstractState* state).

pub unsafe fn cancel_delayed_event(&self, id: c_int) -> bool

Calls C++ function: bool QStateMachine::cancelDelayedEvent(int id).

pub unsafe fn clear_error(&self)

Calls C++ function: void QStateMachine::clearError().

pub unsafe fn configuration(&self) -> CppBox<QSetOfQAbstractState>

Calls C++ function: QSet<QAbstractState*> QStateMachine::configuration() const.

pub unsafe fn default_animations(&self) -> CppBox<QListOfQAbstractAnimation>

Calls C++ function: QList<QAbstractAnimation*> QStateMachine::defaultAnimations() const.

pub unsafe fn error(&self) -> Error

Calls C++ function: QStateMachine::Error QStateMachine::error() const.

pub unsafe fn error_string(&self) -> CppBox<QString>

Calls C++ function: QString QStateMachine::errorString() const.

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QStateMachine::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn global_restore_policy(&self) -> RestorePolicy

Calls C++ function: QState::RestorePolicy QStateMachine::globalRestorePolicy() const.

pub unsafe fn is_animated(&self) -> bool

Calls C++ function: bool QStateMachine::isAnimated() const.

pub unsafe fn is_running(&self) -> bool

Calls C++ function: bool QStateMachine::isRunning() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QStateMachine::metaObject() const.

pub unsafe fn from_q_object( parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QStateMachine>

Calls C++ function: [constructor] void QStateMachine::QStateMachine(QObject* parent = …).

pub unsafe fn from_child_mode_q_object( child_mode: ChildMode, parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QStateMachine>

Calls C++ function: [constructor] void QStateMachine::QStateMachine(QState::ChildMode childMode, QObject* parent = …).

pub unsafe fn new() -> QBox<QStateMachine>

Calls C++ function: [constructor] void QStateMachine::QStateMachine().

pub unsafe fn from_child_mode(child_mode: ChildMode) -> QBox<QStateMachine>

Calls C++ function: [constructor] void QStateMachine::QStateMachine(QState::ChildMode childMode).

pub unsafe fn post_delayed_event( &self, event: impl CastInto<Ptr<QEvent>>, delay: c_int, ) -> c_int

Calls C++ function: int QStateMachine::postDelayedEvent(QEvent* event, int delay).

pub unsafe fn post_event_2a( &self, event: impl CastInto<Ptr<QEvent>>, priority: EventPriority, )

Calls C++ function: void QStateMachine::postEvent(QEvent* event, QStateMachine::EventPriority priority = …).

pub unsafe fn post_event_1a(&self, event: impl CastInto<Ptr<QEvent>>)

Calls C++ function: void QStateMachine::postEvent(QEvent* event).

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QStateMachine::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QStateMachine::qt_metacast(const char* arg1).

pub unsafe fn remove_default_animation( &self, animation: impl CastInto<Ptr<QAbstractAnimation>>, )

Calls C++ function: void QStateMachine::removeDefaultAnimation(QAbstractAnimation* animation).

pub unsafe fn remove_state(&self, state: impl CastInto<Ptr<QAbstractState>>)

Calls C++ function: void QStateMachine::removeState(QAbstractState* state).

pub unsafe fn set_animated(&self, enabled: bool)

Calls C++ function: void QStateMachine::setAnimated(bool enabled).

pub unsafe fn set_global_restore_policy(&self, restore_policy: RestorePolicy)

Calls C++ function: void QStateMachine::setGlobalRestorePolicy(QState::RestorePolicy restorePolicy).

pub unsafe fn set_running(&self, running: bool)

Calls C++ function: [slot] void QStateMachine::setRunning(bool running).

pub unsafe fn start(&self)

Calls C++ function: [slot] void QStateMachine::start().

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn stop(&self)

Calls C++ function: [slot] void QStateMachine::stop().

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QStateMachine::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QStateMachine::trUtf8(const char* s, const char* c, int n).

Methods from Deref<Target = QState>

pub fn finished(&self) -> Signal<()>

Returns a built-in Qt signal QState::finished that can be passed to qt_core::Signal::connect.

pub fn properties_assigned(&self) -> Signal<()>

Returns a built-in Qt signal QState::propertiesAssigned that can be passed to qt_core::Signal::connect.

pub fn child_mode_changed(&self) -> Signal<()>

Returns a built-in Qt signal QState::childModeChanged that can be passed to qt_core::Signal::connect.

pub fn initial_state_changed(&self) -> Signal<()>

Returns a built-in Qt signal QState::initialStateChanged that can be passed to qt_core::Signal::connect.

pub fn error_state_changed(&self) -> Signal<()>

Returns a built-in Qt signal QState::errorStateChanged that can be passed to qt_core::Signal::connect.

pub unsafe fn add_transition_q_abstract_transition( &self, transition: impl CastInto<Ptr<QAbstractTransition>>, )

Calls C++ function: void QState::addTransition(QAbstractTransition* transition).

pub unsafe fn add_transition_q_object_char_q_abstract_state( &self, sender: impl CastInto<Ptr<QObject>>, signal: *const c_char, target: impl CastInto<Ptr<QAbstractState>>, ) -> QPtr<QSignalTransition>

Calls C++ function: QSignalTransition* QState::addTransition(const QObject* sender, const char* signal, QAbstractState* target).

pub unsafe fn add_transition_q_abstract_state( &self, target: impl CastInto<Ptr<QAbstractState>>, ) -> QPtr<QAbstractTransition>

Calls C++ function: QAbstractTransition* QState::addTransition(QAbstractState* target).

pub unsafe fn assign_property( &self, object: impl CastInto<Ptr<QObject>>, name: *const c_char, value: impl CastInto<Ref<QVariant>>, )

Calls C++ function: void QState::assignProperty(QObject* object, const char* name, const QVariant& value).

pub unsafe fn child_mode(&self) -> ChildMode

Calls C++ function: QState::ChildMode QState::childMode() const.

pub unsafe fn error_state(&self) -> QPtr<QAbstractState>

Calls C++ function: QAbstractState* QState::errorState() const.

pub unsafe fn initial_state(&self) -> QPtr<QAbstractState>

Calls C++ function: QAbstractState* QState::initialState() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QState::metaObject() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QState::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QState::qt_metacast(const char* arg1).

pub unsafe fn remove_transition( &self, transition: impl CastInto<Ptr<QAbstractTransition>>, )

Calls C++ function: void QState::removeTransition(QAbstractTransition* transition).

pub unsafe fn set_child_mode(&self, mode: ChildMode)

Calls C++ function: void QState::setChildMode(QState::ChildMode mode).

pub unsafe fn set_error_state(&self, state: impl CastInto<Ptr<QAbstractState>>)

Calls C++ function: void QState::setErrorState(QAbstractState* state).

pub unsafe fn set_initial_state( &self, state: impl CastInto<Ptr<QAbstractState>>, )

Calls C++ function: void QState::setInitialState(QAbstractState* state).

pub unsafe fn transitions(&self) -> CppBox<QListOfQAbstractTransition>

Calls C++ function: QList<QAbstractTransition*> QState::transitions() const.

Methods from Deref<Target = QAbstractState>

pub fn entered(&self) -> Signal<()>

Returns a built-in Qt signal QAbstractState::entered that can be passed to qt_core::Signal::connect.

pub fn exited(&self) -> Signal<()>

Returns a built-in Qt signal QAbstractState::exited that can be passed to qt_core::Signal::connect.

pub fn active_changed(&self) -> Signal<(bool,)>

Returns a built-in Qt signal QAbstractState::activeChanged that can be passed to qt_core::Signal::connect.

pub unsafe fn active(&self) -> bool

Calls C++ function: bool QAbstractState::active() const.

pub unsafe fn machine(&self) -> QPtr<QStateMachine>

Calls C++ function: QStateMachine* QAbstractState::machine() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QAbstractState::metaObject() const.

pub unsafe fn parent_state(&self) -> QPtr<QState>

Calls C++ function: QState* QAbstractState::parentState() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QAbstractState::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QAbstractState::qt_metacast(const char* arg1).

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const c_char) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: c_int)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.