QTime

Struct QTime 

pub struct QTime { /* private fields */ }
C++ class: QTime.

Implementations

Source

impl QTime

pub unsafe fn add_m_secs(&self, ms: c_int) -> CppBox<QTime>

Calls C++ function: QTime QTime::addMSecs(int ms) const.

pub unsafe fn add_secs(&self, secs: c_int) -> CppBox<QTime>

Calls C++ function: QTime QTime::addSecs(int secs) const.

pub unsafe fn copy_from(&self, other: impl CastInto<Ref<QTime>>) -> Ref<QTime>

Calls C++ function: QTime& QTime::operator=(const QTime& other).

pub unsafe fn current_time() -> CppBox<QTime>

Calls C++ function: static QTime QTime::currentTime().

pub unsafe fn elapsed(&self) -> c_int

Calls C++ function: int QTime::elapsed() const.

pub unsafe fn from_m_secs_since_start_of_day(msecs: c_int) -> CppBox<QTime>

Calls C++ function: static QTime QTime::fromMSecsSinceStartOfDay(int msecs).

pub unsafe fn from_string_q_string_date_format( s: impl CastInto<Ref<QString>>, f: DateFormat, ) -> CppBox<QTime>

Calls C++ function: static QTime QTime::fromString(const QString& s, Qt::DateFormat f = …).

pub unsafe fn from_string_2_q_string( s: impl CastInto<Ref<QString>>, format: impl CastInto<Ref<QString>>, ) -> CppBox<QTime>

Calls C++ function: static QTime QTime::fromString(const QString& s, const QString& format).

pub unsafe fn from_string_q_string( s: impl CastInto<Ref<QString>>, ) -> CppBox<QTime>

Calls C++ function: static QTime QTime::fromString(const QString& s).

pub unsafe fn hour(&self) -> c_int

Calls C++ function: int QTime::hour() const.

pub unsafe fn is_null(&self) -> bool

Calls C++ function: bool QTime::isNull() const.

pub unsafe fn is_valid_0a(&self) -> bool

Calls C++ function: bool QTime::isValid() const.

pub unsafe fn is_valid_4a(h: c_int, m: c_int, s: c_int, ms: c_int) -> bool

Calls C++ function: static bool QTime::isValid(int h, int m, int s, int ms = …).

pub unsafe fn is_valid_3a(h: c_int, m: c_int, s: c_int) -> bool

Calls C++ function: static bool QTime::isValid(int h, int m, int s).

pub unsafe fn minute(&self) -> c_int

Calls C++ function: int QTime::minute() const.

pub unsafe fn msec(&self) -> c_int

Calls C++ function: int QTime::msec() const.

pub unsafe fn msecs_since_start_of_day(&self) -> c_int

Calls C++ function: int QTime::msecsSinceStartOfDay() const.

pub unsafe fn msecs_to(&self, arg1: impl CastInto<Ref<QTime>>) -> c_int

Calls C++ function: int QTime::msecsTo(const QTime& arg1) const.

pub unsafe fn new_0a() -> CppBox<QTime>

Calls C++ function: [constructor] void QTime::QTime().

pub unsafe fn new_4a(h: c_int, m: c_int, s: c_int, ms: c_int) -> CppBox<QTime>

Calls C++ function: [constructor] void QTime::QTime(int h, int m, int s = …, int ms = …).

pub unsafe fn new_3a(h: c_int, m: c_int, s: c_int) -> CppBox<QTime>

Calls C++ function: [constructor] void QTime::QTime(int h, int m, int s = …).

pub unsafe fn new_2a(h: c_int, m: c_int) -> CppBox<QTime>

Calls C++ function: [constructor] void QTime::QTime(int h, int m).

pub unsafe fn new_copy(other: impl CastInto<Ref<QTime>>) -> CppBox<QTime>

Calls C++ function: [constructor] void QTime::QTime(const QTime& other).

pub unsafe fn restart(&self) -> c_int

Calls C++ function: int QTime::restart().

pub unsafe fn second(&self) -> c_int

Calls C++ function: int QTime::second() const.

pub unsafe fn secs_to(&self, arg1: impl CastInto<Ref<QTime>>) -> c_int

Calls C++ function: int QTime::secsTo(const QTime& arg1) const.

pub unsafe fn set_h_m_s_4a( &self, h: c_int, m: c_int, s: c_int, ms: c_int, ) -> bool

Calls C++ function: bool QTime::setHMS(int h, int m, int s, int ms = …).

pub unsafe fn set_h_m_s_3a(&self, h: c_int, m: c_int, s: c_int) -> bool

Calls C++ function: bool QTime::setHMS(int h, int m, int s).

pub unsafe fn start(&self)

Calls C++ function: void QTime::start().

pub unsafe fn to_string_date_format(&self, f: DateFormat) -> CppBox<QString>

Calls C++ function: QString QTime::toString(Qt::DateFormat f = …) const.

pub unsafe fn to_string_q_string( &self, format: impl CastInto<Ref<QString>>, ) -> CppBox<QString>

Calls C++ function: QString QTime::toString(const QString& format) const.

pub unsafe fn to_string_q_string_view( &self, format: impl CastInto<Ref<QStringView>>, ) -> CppBox<QString>

Calls C++ function: QString QTime::toString(QStringView format) const.

pub unsafe fn to_string(&self) -> CppBox<QString>

Calls C++ function: QString QTime::toString() const.