QVariantAnimation

Struct QVariantAnimation 

pub struct QVariantAnimation { /* private fields */ }
C++ class: QVariantAnimation.

Implementations

Source

impl QVariantAnimation

pub fn value_changed(&self) -> Signal<(*const QVariant,)>

Returns a built-in Qt signal QVariantAnimation::valueChanged that can be passed to qt_core::Signal::connect.

pub unsafe fn current_value(&self) -> CppBox<QVariant>

Calls C++ function: QVariant QVariantAnimation::currentValue() const.

pub unsafe fn duration(&self) -> c_int

Calls C++ function: virtual int QVariantAnimation::duration() const.

pub unsafe fn easing_curve(&self) -> CppBox<QEasingCurve>

Calls C++ function: QEasingCurve QVariantAnimation::easingCurve() const.

pub unsafe fn end_value(&self) -> CppBox<QVariant>

Calls C++ function: QVariant QVariantAnimation::endValue() const.

pub unsafe fn key_value_at(&self, step: c_double) -> CppBox<QVariant>

Calls C++ function: QVariant QVariantAnimation::keyValueAt(double step) const.

pub unsafe fn key_values(&self) -> CppBox<QVectorOfQPairOfDoubleQVariant>

Calls C++ function: QVector<QPair<double, QVariant>> QVariantAnimation::keyValues() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QVariantAnimation::metaObject() const.

pub unsafe fn new_1a( parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QVariantAnimation>

Calls C++ function: [constructor] void QVariantAnimation::QVariantAnimation(QObject* parent = …).

pub unsafe fn new_0a() -> QBox<QVariantAnimation>

Calls C++ function: [constructor] void QVariantAnimation::QVariantAnimation().

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QVariantAnimation::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QVariantAnimation::qt_metacast(const char* arg1).

pub unsafe fn set_duration(&self, msecs: c_int)

Calls C++ function: void QVariantAnimation::setDuration(int msecs).

pub unsafe fn set_easing_curve(&self, easing: impl CastInto<Ref<QEasingCurve>>)

Calls C++ function: void QVariantAnimation::setEasingCurve(const QEasingCurve& easing).

pub unsafe fn set_end_value(&self, value: impl CastInto<Ref<QVariant>>)

Calls C++ function: void QVariantAnimation::setEndValue(const QVariant& value).

pub unsafe fn set_key_value_at( &self, step: c_double, value: impl CastInto<Ref<QVariant>>, )

Calls C++ function: void QVariantAnimation::setKeyValueAt(double step, const QVariant& value).

pub unsafe fn set_key_values( &self, values: impl CastInto<Ref<QVectorOfQPairOfDoubleQVariant>>, )

Calls C++ function: void QVariantAnimation::setKeyValues(const QVector<QPair<double, QVariant>>& values).

pub unsafe fn set_start_value(&self, value: impl CastInto<Ref<QVariant>>)

Calls C++ function: void QVariantAnimation::setStartValue(const QVariant& value).

pub unsafe fn start_value(&self) -> CppBox<QVariant>

Calls C++ function: QVariant QVariantAnimation::startValue() const.

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QVariantAnimation::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QVariantAnimation::trUtf8(const char* s, const char* c, int n).

Methods from Deref<Target = QAbstractAnimation>

pub fn finished(&self) -> Signal<()>

Returns a built-in Qt signal QAbstractAnimation::finished that can be passed to qt_core::Signal::connect.

pub fn state_changed(&self) -> Signal<(State, State)>

Returns a built-in Qt signal QAbstractAnimation::stateChanged that can be passed to qt_core::Signal::connect.

pub fn current_loop_changed(&self) -> Signal<(c_int,)>

Returns a built-in Qt signal QAbstractAnimation::currentLoopChanged that can be passed to qt_core::Signal::connect.

pub fn direction_changed(&self) -> Signal<(Direction,)>

Returns a built-in Qt signal QAbstractAnimation::directionChanged that can be passed to qt_core::Signal::connect.

pub fn slot_start(&self) -> Receiver<(DeletionPolicy,)>

Returns a built-in Qt slot QAbstractAnimation::start that can be passed to qt_core::Signal::connect.

pub fn slot_pause(&self) -> Receiver<()>

Returns a built-in Qt slot QAbstractAnimation::pause that can be passed to qt_core::Signal::connect.

pub fn slot_resume(&self) -> Receiver<()>

Returns a built-in Qt slot QAbstractAnimation::resume that can be passed to qt_core::Signal::connect.

pub fn slot_set_paused(&self) -> Receiver<(bool,)>

Returns a built-in Qt slot QAbstractAnimation::setPaused that can be passed to qt_core::Signal::connect.

pub fn slot_stop(&self) -> Receiver<()>

Returns a built-in Qt slot QAbstractAnimation::stop that can be passed to qt_core::Signal::connect.

pub fn slot_set_current_time(&self) -> Receiver<(c_int,)>

Returns a built-in Qt slot QAbstractAnimation::setCurrentTime that can be passed to qt_core::Signal::connect.

pub unsafe fn current_loop(&self) -> c_int

Calls C++ function: int QAbstractAnimation::currentLoop() const.

pub unsafe fn current_loop_time(&self) -> c_int

Calls C++ function: int QAbstractAnimation::currentLoopTime() const.

pub unsafe fn current_time(&self) -> c_int

Calls C++ function: int QAbstractAnimation::currentTime() const.

pub unsafe fn direction(&self) -> Direction

Calls C++ function: QAbstractAnimation::Direction QAbstractAnimation::direction() const.

pub unsafe fn duration(&self) -> c_int

Calls C++ function: pure virtual int QAbstractAnimation::duration() const.

pub unsafe fn group(&self) -> QPtr<QAnimationGroup>

Calls C++ function: QAnimationGroup* QAbstractAnimation::group() const.

pub unsafe fn loop_count(&self) -> c_int

Calls C++ function: int QAbstractAnimation::loopCount() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QAbstractAnimation::metaObject() const.

pub unsafe fn pause(&self)

Calls C++ function: [slot] void QAbstractAnimation::pause().

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QAbstractAnimation::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QAbstractAnimation::qt_metacast(const char* arg1).

pub unsafe fn resume(&self)

Calls C++ function: [slot] void QAbstractAnimation::resume().

pub unsafe fn set_current_time(&self, msecs: c_int)

Calls C++ function: [slot] void QAbstractAnimation::setCurrentTime(int msecs).

pub unsafe fn set_direction(&self, direction: Direction)

Calls C++ function: void QAbstractAnimation::setDirection(QAbstractAnimation::Direction direction).

pub unsafe fn set_loop_count(&self, loop_count: c_int)

Calls C++ function: void QAbstractAnimation::setLoopCount(int loopCount).

pub unsafe fn set_paused(&self, arg1: bool)

Calls C++ function: [slot] void QAbstractAnimation::setPaused(bool arg1).

pub unsafe fn start_1a(&self, policy: DeletionPolicy)

Calls C++ function: [slot] void QAbstractAnimation::start(QAbstractAnimation::DeletionPolicy policy = …).

pub unsafe fn start_0a(&self)

Calls C++ function: [slot] void QAbstractAnimation::start().

pub unsafe fn state(&self) -> State

Calls C++ function: QAbstractAnimation::State QAbstractAnimation::state() const.

pub unsafe fn stop(&self)

Calls C++ function: [slot] void QAbstractAnimation::stop().

pub unsafe fn total_duration(&self) -> c_int

Calls C++ function: int QAbstractAnimation::totalDuration() const.

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const c_char) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: c_int)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.