pub struct Receiver<Arguments> { /* private fields */ }Expand description
Reference to a particular signal or slot of a particular object.
A Receiver can be used as the receiving side of a Qt signal connection.
The Arguments generic argument specifies argument types of this signal or slot.
Implementations
Sourceimpl<A> Receiver<A>
impl<A> Receiver<A>
Sourcepub unsafe fn new(
q_object: impl CastInto<Ref<QObject>>,
receiver_id: &'static CStr,
) -> Self
pub unsafe fn new( q_object: impl CastInto<Ref<QObject>>, receiver_id: &'static CStr, ) -> Self
Creates a Receiver than references a signal or a slot of q_object identified by
receiver_id.
This function should not be used manually. It’s normally called from functions
generated by ritual. receiver_id is the ID returned by Qt’s SIGNAL and SLOT
C++ macros.
Safety
q_object must contain a valid pointer to a QObject-based object. The object
must outlive the created Receiver object.