ScreenOrientation

Struct ScreenOrientation 

pub struct ScreenOrientation(/* private fields */);
This enum type specifies the various orientations a screen might have.

C++ enum: Qt::ScreenOrientation.

C++ documentation:

This enum type specifies the various orientations a screen might have.

The ScreenOrientations type is a typedef for QFlags<ScreenOrientation>. It stores an OR combination of ScreenOrientation values.

Implementations

Source

impl ScreenOrientation

pub fn to_int(&self) -> c_int

Source

impl ScreenOrientation

pub const PrimaryOrientation: ScreenOrientation

The display’s primary orientation. (C++ enum variant: PrimaryOrientation = 0)

pub const PortraitOrientation: ScreenOrientation

Portrait orientation, display height is greater than display width, rotated 90 degree clockwise relative to landscape. (C++ enum variant: PortraitOrientation = 1)

pub const LandscapeOrientation: ScreenOrientation

Landscape orientation, display width is greater than display height. (C++ enum variant: LandscapeOrientation = 2)

pub const InvertedPortraitOrientation: ScreenOrientation

Inverted portrait orientation, rotated 180 degrees relative to portrait. (C++ enum variant: InvertedPortraitOrientation = 4)

pub const InvertedLandscapeOrientation: ScreenOrientation

Inverted landscape orientation, rotated 180 degrees relative to landscape. (C++ enum variant: InvertedLandscapeOrientation = 8)