pub struct TextElideMode(/* private fields */);Expand description
This enum specifies where the ellipsis should appear when displaying texts that don't fit:
C++ enum: Qt::TextElideMode.
This enum specifies where the ellipsis should appear when displaying texts that don’t fit:
Qt::ElideMiddle is normally the most appropriate choice for URLs (e.g., "http://bugreports.qt.../QTWEBSITE-13/"), whereas Qt::ElideRight is appropriate for other strings (e.g., "Deploying Applications on Ma...").
See also QAbstractItemView::textElideMode, QFontMetrics::elidedText(), AlignmentFlag, and QTabBar::elideMode.
Implementations
Sourceimpl TextElideMode
impl TextElideMode
Sourcepub const ElideLeft: TextElideMode
pub const ElideLeft: TextElideMode
The ellipsis should appear at the beginning of the text. (C++ enum variant: ElideLeft = 0)
Sourcepub const ElideRight: TextElideMode
pub const ElideRight: TextElideMode
The ellipsis should appear at the end of the text. (C++ enum variant: ElideRight = 1)
Sourcepub const ElideMiddle: TextElideMode
pub const ElideMiddle: TextElideMode
The ellipsis should appear in the middle of the text. (C++ enum variant: ElideMiddle = 2)
Sourcepub const ElideNone: TextElideMode
pub const ElideNone: TextElideMode
Ellipsis should NOT appear in the text. (C++ enum variant: ElideNone = 3)