WindowFrameSection

Struct WindowFrameSection 

pub struct WindowFrameSection(/* private fields */);
This enum is used to describe parts of a window frame. It is returned by QGraphicsWidget::windowFrameSectionAt() to describe what section of the window frame is under the mouse.

C++ enum: Qt::WindowFrameSection.

C++ documentation:

This enum is used to describe parts of a window frame. It is returned by QGraphicsWidget::windowFrameSectionAt() to describe what section of the window frame is under the mouse.

This enum was introduced or modified in Qt 4.4.

See also QGraphicsWidget::windowFrameEvent(), QGraphicsWidget::paintWindowFrame(), and QGraphicsWidget::windowFrameSectionAt().

Implementations

Source

impl WindowFrameSection

pub fn to_int(&self) -> c_int

Source

impl WindowFrameSection

pub const NoSection: WindowFrameSection

C++ enum variant: NoSection = 0

pub const LeftSection: WindowFrameSection

C++ enum variant: LeftSection = 1

pub const TopLeftSection: WindowFrameSection

C++ enum variant: TopLeftSection = 2

pub const TopSection: WindowFrameSection

C++ enum variant: TopSection = 3

pub const TopRightSection: WindowFrameSection

C++ enum variant: TopRightSection = 4

pub const RightSection: WindowFrameSection

C++ enum variant: RightSection = 5

pub const BottomRightSection: WindowFrameSection

C++ enum variant: BottomRightSection = 6

pub const BottomSection: WindowFrameSection

C++ enum variant: BottomSection = 7

pub const BottomLeftSection: WindowFrameSection

C++ enum variant: BottomLeftSection = 8

pub const TitleBarArea: WindowFrameSection

C++ enum variant: TitleBarArea = 9