pub struct QCoreApplication { /* private fields */ }Expand description
C++ class: QCoreApplication.
Implementations
Sourceimpl QCoreApplication
impl QCoreApplication
Sourcepub fn init<F: FnOnce(Ptr<QCoreApplication>) -> i32>(f: F) -> !
pub fn init<F: FnOnce(Ptr<QCoreApplication>) -> i32>(f: F) -> !
A convenience function for performing proper initialization and de-initialization of a Qt application.
This function creates a QCoreApplication object with valid argc and argv,
calls the passed closure f(app) with the application object
and exits the process with the exit code returned by the closure.
The closure should perform the initialization of the application
and either return immediately or call QCoreApplication::exec()
and return its return value:
use qt_core::QCoreApplication;
fn main() {
QCoreApplication::init(|app| {
unsafe {
// initialization goes here
QCoreApplication::exec()
}
})
}Sourceimpl QCoreApplication
impl QCoreApplication
Sourcepub fn slot_quit(&self) -> Receiver<()>
pub fn slot_quit(&self) -> Receiver<()>
Returns a built-in Qt slot QCoreApplication::quit that can be passed to qt_core::Signal::connect.
Sourcepub fn about_to_quit(&self) -> Signal<()>
pub fn about_to_quit(&self) -> Signal<()>
Returns a built-in Qt signal QCoreApplication::aboutToQuit that can be passed to qt_core::Signal::connect.
Sourcepub fn organization_name_changed(&self) -> Signal<()>
pub fn organization_name_changed(&self) -> Signal<()>
Returns a built-in Qt signal QCoreApplication::organizationNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn organization_domain_changed(&self) -> Signal<()>
pub fn organization_domain_changed(&self) -> Signal<()>
Returns a built-in Qt signal QCoreApplication::organizationDomainChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn application_name_changed(&self) -> Signal<()>
pub fn application_name_changed(&self) -> Signal<()>
Returns a built-in Qt signal QCoreApplication::applicationNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn application_version_changed(&self) -> Signal<()>
pub fn application_version_changed(&self) -> Signal<()>
Returns a built-in Qt signal QCoreApplication::applicationVersionChanged that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn add_library_path(arg1: impl CastInto<Ref<QString>>)
pub unsafe fn add_library_path(arg1: impl CastInto<Ref<QString>>)
Calls C++ function: static void QCoreApplication::addLibraryPath(const QString& arg1).
Sourcepub unsafe fn application_dir_path() -> CppBox<QString>
pub unsafe fn application_dir_path() -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::applicationDirPath().
Sourcepub unsafe fn application_file_path() -> CppBox<QString>
pub unsafe fn application_file_path() -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::applicationFilePath().
Sourcepub unsafe fn application_name() -> CppBox<QString>
pub unsafe fn application_name() -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::applicationName().
Sourcepub unsafe fn application_pid() -> c_longlong
pub unsafe fn application_pid() -> c_longlong
Calls C++ function: static long long QCoreApplication::applicationPid().
Sourcepub unsafe fn application_version() -> CppBox<QString>
pub unsafe fn application_version() -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::applicationVersion().
Sourcepub unsafe fn arguments() -> CppBox<QStringList>
pub unsafe fn arguments() -> CppBox<QStringList>
Calls C++ function: static QStringList QCoreApplication::arguments().
Sourcepub unsafe fn closing_down() -> bool
pub unsafe fn closing_down() -> bool
Calls C++ function: static bool QCoreApplication::closingDown().
Sourcepub unsafe fn event_dispatcher() -> QPtr<QAbstractEventDispatcher>
pub unsafe fn event_dispatcher() -> QPtr<QAbstractEventDispatcher>
Calls C++ function: static QAbstractEventDispatcher* QCoreApplication::eventDispatcher().
Sourcepub unsafe fn exit_1a(retcode: c_int)
pub unsafe fn exit_1a(retcode: c_int)
Calls C++ function: static void QCoreApplication::exit(int retcode = …).
Sourcepub unsafe fn has_pending_events() -> bool
pub unsafe fn has_pending_events() -> bool
Calls C++ function: static bool QCoreApplication::hasPendingEvents().
Sourcepub unsafe fn install_native_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QAbstractNativeEventFilter>>,
)
pub unsafe fn install_native_event_filter( &self, filter_obj: impl CastInto<Ptr<QAbstractNativeEventFilter>>, )
Calls C++ function: void QCoreApplication::installNativeEventFilter(QAbstractNativeEventFilter* filterObj).
Sourcepub unsafe fn install_translator(
message_file: impl CastInto<Ptr<QTranslator>>,
) -> bool
pub unsafe fn install_translator( message_file: impl CastInto<Ptr<QTranslator>>, ) -> bool
Calls C++ function: static bool QCoreApplication::installTranslator(QTranslator* messageFile).
Sourcepub unsafe fn instance() -> QPtr<QCoreApplication>
pub unsafe fn instance() -> QPtr<QCoreApplication>
Calls C++ function: static QCoreApplication* QCoreApplication::instance().
Sourcepub unsafe fn is_quit_lock_enabled() -> bool
pub unsafe fn is_quit_lock_enabled() -> bool
Calls C++ function: static bool QCoreApplication::isQuitLockEnabled().
Sourcepub unsafe fn is_setuid_allowed() -> bool
pub unsafe fn is_setuid_allowed() -> bool
Calls C++ function: static bool QCoreApplication::isSetuidAllowed().
Sourcepub unsafe fn library_paths() -> CppBox<QStringList>
pub unsafe fn library_paths() -> CppBox<QStringList>
Calls C++ function: static QStringList QCoreApplication::libraryPaths().
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QCoreApplication::metaObject() const.
Sourcepub unsafe fn new_3a(
argc: *mut c_int,
argv: *mut *mut c_char,
arg3: c_int,
) -> QBox<QCoreApplication>
pub unsafe fn new_3a( argc: *mut c_int, argv: *mut *mut c_char, arg3: c_int, ) -> QBox<QCoreApplication>
Calls C++ function: [constructor] void QCoreApplication::QCoreApplication(int& argc, char** argv, int arg3 = …).
Sourcepub unsafe fn new_2a(
argc: *mut c_int,
argv: *mut *mut c_char,
) -> QBox<QCoreApplication>
pub unsafe fn new_2a( argc: *mut c_int, argv: *mut *mut c_char, ) -> QBox<QCoreApplication>
Calls C++ function: [constructor] void QCoreApplication::QCoreApplication(int& argc, char** argv).
Sourcepub unsafe fn notify(
&self,
arg1: impl CastInto<Ptr<QObject>>,
arg2: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn notify( &self, arg1: impl CastInto<Ptr<QObject>>, arg2: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QCoreApplication::notify(QObject* arg1, QEvent* arg2).
Sourcepub unsafe fn organization_domain() -> CppBox<QString>
pub unsafe fn organization_domain() -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::organizationDomain().
Sourcepub unsafe fn organization_name() -> CppBox<QString>
pub unsafe fn organization_name() -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::organizationName().
Sourcepub unsafe fn post_event_3a(
receiver: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
priority: c_int,
)
pub unsafe fn post_event_3a( receiver: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, priority: c_int, )
Calls C++ function: static void QCoreApplication::postEvent(QObject* receiver, QEvent* event, int priority = …).
Sourcepub unsafe fn post_event_2a(
receiver: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
)
pub unsafe fn post_event_2a( receiver: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, )
Calls C++ function: static void QCoreApplication::postEvent(QObject* receiver, QEvent* event).
Sourcepub unsafe fn process_events_1a(flags: QFlags<ProcessEventsFlag>)
pub unsafe fn process_events_1a(flags: QFlags<ProcessEventsFlag>)
Calls C++ function: static void QCoreApplication::processEvents(QFlags<QEventLoop::ProcessEventsFlag> flags = …).
Sourcepub unsafe fn process_events_2a(
flags: QFlags<ProcessEventsFlag>,
maxtime: c_int,
)
pub unsafe fn process_events_2a( flags: QFlags<ProcessEventsFlag>, maxtime: c_int, )
Calls C++ function: static void QCoreApplication::processEvents(QFlags<QEventLoop::ProcessEventsFlag> flags, int maxtime).
Sourcepub unsafe fn process_events_0a()
pub unsafe fn process_events_0a()
Calls C++ function: static void QCoreApplication::processEvents().
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QCoreApplication::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QCoreApplication::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_library_path(arg1: impl CastInto<Ref<QString>>)
pub unsafe fn remove_library_path(arg1: impl CastInto<Ref<QString>>)
Calls C++ function: static void QCoreApplication::removeLibraryPath(const QString& arg1).
Sourcepub unsafe fn remove_native_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QAbstractNativeEventFilter>>,
)
pub unsafe fn remove_native_event_filter( &self, filter_obj: impl CastInto<Ptr<QAbstractNativeEventFilter>>, )
Calls C++ function: void QCoreApplication::removeNativeEventFilter(QAbstractNativeEventFilter* filterObj).
Sourcepub unsafe fn remove_posted_events_2a(
receiver: impl CastInto<Ptr<QObject>>,
event_type: c_int,
)
pub unsafe fn remove_posted_events_2a( receiver: impl CastInto<Ptr<QObject>>, event_type: c_int, )
Calls C++ function: static void QCoreApplication::removePostedEvents(QObject* receiver, int eventType = …).
Sourcepub unsafe fn remove_posted_events_1a(receiver: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_posted_events_1a(receiver: impl CastInto<Ptr<QObject>>)
Calls C++ function: static void QCoreApplication::removePostedEvents(QObject* receiver).
Sourcepub unsafe fn remove_translator(
message_file: impl CastInto<Ptr<QTranslator>>,
) -> bool
pub unsafe fn remove_translator( message_file: impl CastInto<Ptr<QTranslator>>, ) -> bool
Calls C++ function: static bool QCoreApplication::removeTranslator(QTranslator* messageFile).
Sourcepub unsafe fn send_event(
receiver: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn send_event( receiver: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: static bool QCoreApplication::sendEvent(QObject* receiver, QEvent* event).
Sourcepub unsafe fn send_posted_events_2a(
receiver: impl CastInto<Ptr<QObject>>,
event_type: c_int,
)
pub unsafe fn send_posted_events_2a( receiver: impl CastInto<Ptr<QObject>>, event_type: c_int, )
Calls C++ function: static void QCoreApplication::sendPostedEvents(QObject* receiver = …, int event_type = …).
Sourcepub unsafe fn send_posted_events_1a(receiver: impl CastInto<Ptr<QObject>>)
pub unsafe fn send_posted_events_1a(receiver: impl CastInto<Ptr<QObject>>)
Calls C++ function: static void QCoreApplication::sendPostedEvents(QObject* receiver = …).
Sourcepub unsafe fn send_posted_events_0a()
pub unsafe fn send_posted_events_0a()
Calls C++ function: static void QCoreApplication::sendPostedEvents().
Sourcepub unsafe fn set_application_name(application: impl CastInto<Ref<QString>>)
pub unsafe fn set_application_name(application: impl CastInto<Ref<QString>>)
Calls C++ function: static void QCoreApplication::setApplicationName(const QString& application).
Sourcepub unsafe fn set_application_version(version: impl CastInto<Ref<QString>>)
pub unsafe fn set_application_version(version: impl CastInto<Ref<QString>>)
Calls C++ function: static void QCoreApplication::setApplicationVersion(const QString& version).
Sourcepub unsafe fn set_attribute_2a(attribute: ApplicationAttribute, on: bool)
pub unsafe fn set_attribute_2a(attribute: ApplicationAttribute, on: bool)
Calls C++ function: static void QCoreApplication::setAttribute(Qt::ApplicationAttribute attribute, bool on = …).
Sourcepub unsafe fn set_attribute_1a(attribute: ApplicationAttribute)
pub unsafe fn set_attribute_1a(attribute: ApplicationAttribute)
Calls C++ function: static void QCoreApplication::setAttribute(Qt::ApplicationAttribute attribute).
Sourcepub unsafe fn set_event_dispatcher(
event_dispatcher: impl CastInto<Ptr<QAbstractEventDispatcher>>,
)
pub unsafe fn set_event_dispatcher( event_dispatcher: impl CastInto<Ptr<QAbstractEventDispatcher>>, )
Calls C++ function: static void QCoreApplication::setEventDispatcher(QAbstractEventDispatcher* eventDispatcher).
Sourcepub unsafe fn set_library_paths(arg1: impl CastInto<Ref<QStringList>>)
pub unsafe fn set_library_paths(arg1: impl CastInto<Ref<QStringList>>)
Calls C++ function: static void QCoreApplication::setLibraryPaths(const QStringList& arg1).
Sourcepub unsafe fn set_organization_domain(org_domain: impl CastInto<Ref<QString>>)
pub unsafe fn set_organization_domain(org_domain: impl CastInto<Ref<QString>>)
Calls C++ function: static void QCoreApplication::setOrganizationDomain(const QString& orgDomain).
Sourcepub unsafe fn set_organization_name(org_name: impl CastInto<Ref<QString>>)
pub unsafe fn set_organization_name(org_name: impl CastInto<Ref<QString>>)
Calls C++ function: static void QCoreApplication::setOrganizationName(const QString& orgName).
Sourcepub unsafe fn set_quit_lock_enabled(enabled: bool)
pub unsafe fn set_quit_lock_enabled(enabled: bool)
Calls C++ function: static void QCoreApplication::setQuitLockEnabled(bool enabled).
Sourcepub unsafe fn set_setuid_allowed(allow: bool)
pub unsafe fn set_setuid_allowed(allow: bool)
Calls C++ function: static void QCoreApplication::setSetuidAllowed(bool allow).
Sourcepub unsafe fn starting_up() -> bool
pub unsafe fn starting_up() -> bool
Calls C++ function: static bool QCoreApplication::startingUp().
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Sourcepub unsafe fn test_attribute(attribute: ApplicationAttribute) -> bool
pub unsafe fn test_attribute(attribute: ApplicationAttribute) -> bool
Calls C++ function: static bool QCoreApplication::testAttribute(Qt::ApplicationAttribute attribute).
Sourcepub unsafe fn tr(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::tr(const char* s, const char* c, int n).
Sourcepub unsafe fn tr_utf8(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::trUtf8(const char* s, const char* c, int n).
Sourcepub unsafe fn translate_4a(
context: *const c_char,
key: *const c_char,
disambiguation: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn translate_4a( context: *const c_char, key: *const c_char, disambiguation: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QCoreApplication::translate(const char* context, const char* key, const char* disambiguation = …, int n = …).
Methods from Deref<Target = QObject>
Sourcepub unsafe fn find_child<T>(
&self,
name: &str,
) -> Result<QPtr<T>, FindChildError>
pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>
Finds a child of self with the specified object name
and casts it to type T.
The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.
Returns an error if there is no child object with object name name or
the found object cannot be cast to T.
Sourcepub fn destroyed(&self) -> Signal<(*mut QObject,)>
pub fn destroyed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.
Sourcepub fn object_name_changed(&self) -> Signal<(*const QString,)>
pub fn object_name_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_delete_later(&self) -> Receiver<()>
pub fn slot_delete_later(&self) -> Receiver<()>
Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn block_signals(&self, b: bool) -> bool
pub unsafe fn block_signals(&self, b: bool) -> bool
Calls C++ function: bool QObject::blockSignals(bool b).
Sourcepub unsafe fn children(&self) -> Ref<QListOfQObject>
pub unsafe fn children(&self) -> Ref<QListOfQObject>
Calls C++ function: const QList<QObject*>& QObject::children() const.
Sourcepub unsafe fn delete_later(&self)
pub unsafe fn delete_later(&self)
Calls C++ function: [slot] void QObject::deleteLater().
Sourcepub unsafe fn disconnect_char_q_object_char(
&self,
signal: *const c_char,
receiver: impl CastInto<Ptr<QObject>>,
member: *const c_char,
) -> bool
pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.
Sourcepub unsafe fn disconnect_q_object_char(
&self,
receiver: impl CastInto<Ptr<QObject>>,
member: *const c_char,
) -> bool
pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.
Sourcepub unsafe fn disconnect_char_q_object(
&self,
signal: *const c_char,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.
Sourcepub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool
pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …) const.
Sourcepub unsafe fn disconnect(&self) -> bool
pub unsafe fn disconnect(&self) -> bool
Calls C++ function: bool QObject::disconnect() const.
Sourcepub unsafe fn disconnect_q_object(
&self,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.
Sourcepub unsafe fn dump_object_info_mut(&self)
pub unsafe fn dump_object_info_mut(&self)
Calls C++ function: void QObject::dumpObjectInfo().
Sourcepub unsafe fn dump_object_info(&self)
pub unsafe fn dump_object_info(&self)
Calls C++ function: void QObject::dumpObjectInfo() const.
Sourcepub unsafe fn dump_object_tree_mut(&self)
pub unsafe fn dump_object_tree_mut(&self)
Calls C++ function: void QObject::dumpObjectTree().
Sourcepub unsafe fn dump_object_tree(&self)
pub unsafe fn dump_object_tree(&self)
Calls C++ function: void QObject::dumpObjectTree() const.
Sourcepub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.
Sourcepub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QObject::event(QEvent* event).
Sourcepub unsafe fn event_filter(
&self,
watched: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).
Sourcepub unsafe fn find_child_q_object_2a(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_child_q_object_1a(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_string_q_flags_find_child_option(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegExp>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_string(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp(
&self,
re: impl CastInto<Ref<QRegExp>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.
Sourcepub unsafe fn inherits(&self, classname: *const c_char) -> bool
pub unsafe fn inherits(&self, classname: *const c_char) -> bool
Calls C++ function: bool QObject::inherits(const char* classname) const.
Sourcepub unsafe fn install_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QObject>>,
)
pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )
Calls C++ function: void QObject::installEventFilter(QObject* filterObj).
Sourcepub unsafe fn is_widget_type(&self) -> bool
pub unsafe fn is_widget_type(&self) -> bool
Calls C++ function: bool QObject::isWidgetType() const.
Sourcepub unsafe fn is_window_type(&self) -> bool
pub unsafe fn is_window_type(&self) -> bool
Calls C++ function: bool QObject::isWindowType() const.
Sourcepub unsafe fn kill_timer(&self, id: c_int)
pub unsafe fn kill_timer(&self, id: c_int)
Calls C++ function: void QObject::killTimer(int id).
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.
Sourcepub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
Calls C++ function: void QObject::moveToThread(QThread* thread).
Sourcepub unsafe fn object_name(&self) -> CppBox<QString>
pub unsafe fn object_name(&self) -> CppBox<QString>
Calls C++ function: QString QObject::objectName() const.
Sourcepub unsafe fn parent(&self) -> QPtr<QObject>
pub unsafe fn parent(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::parent() const.
Sourcepub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>
pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>
Calls C++ function: QVariant QObject::property(const char* name) const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::removeEventFilter(QObject* obj).
Sourcepub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QObject::setObjectName(const QString& name).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::setParent(QObject* parent).
Sourcepub unsafe fn set_property(
&self,
name: *const c_char,
value: impl CastInto<Ref<QVariant>>,
) -> bool
pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool
Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).
Sourcepub unsafe fn signals_blocked(&self) -> bool
pub unsafe fn signals_blocked(&self) -> bool
Calls C++ function: bool QObject::signalsBlocked() const.
Sourcepub unsafe fn start_timer_2a(
&self,
interval: c_int,
timer_type: TimerType,
) -> c_int
pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int
Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).
Sourcepub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int
pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int
Calls C++ function: int QObject::startTimer(int interval).