pub struct QFutureWatcherBase { /* private fields */ }Expand description
C++ class: QFutureWatcherBase.
Implementations
Sourceimpl QFutureWatcherBase
impl QFutureWatcherBase
Sourcepub fn started(&self) -> Signal<()>
pub fn started(&self) -> Signal<()>
Returns a built-in Qt signal QFutureWatcherBase::started that can be passed to qt_core::Signal::connect.
Sourcepub fn finished(&self) -> Signal<()>
pub fn finished(&self) -> Signal<()>
Returns a built-in Qt signal QFutureWatcherBase::finished that can be passed to qt_core::Signal::connect.
Sourcepub fn canceled(&self) -> Signal<()>
pub fn canceled(&self) -> Signal<()>
Returns a built-in Qt signal QFutureWatcherBase::canceled that can be passed to qt_core::Signal::connect.
Sourcepub fn paused(&self) -> Signal<()>
pub fn paused(&self) -> Signal<()>
Returns a built-in Qt signal QFutureWatcherBase::paused that can be passed to qt_core::Signal::connect.
Sourcepub fn resumed(&self) -> Signal<()>
pub fn resumed(&self) -> Signal<()>
Returns a built-in Qt signal QFutureWatcherBase::resumed that can be passed to qt_core::Signal::connect.
Sourcepub fn result_ready_at(&self) -> Signal<(c_int,)>
pub fn result_ready_at(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QFutureWatcherBase::resultReadyAt that can be passed to qt_core::Signal::connect.
Sourcepub fn results_ready_at(&self) -> Signal<(c_int, c_int)>
pub fn results_ready_at(&self) -> Signal<(c_int, c_int)>
Returns a built-in Qt signal QFutureWatcherBase::resultsReadyAt that can be passed to qt_core::Signal::connect.
Sourcepub fn progress_range_changed(&self) -> Signal<(c_int, c_int)>
pub fn progress_range_changed(&self) -> Signal<(c_int, c_int)>
Returns a built-in Qt signal QFutureWatcherBase::progressRangeChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn progress_value_changed(&self) -> Signal<(c_int,)>
pub fn progress_value_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QFutureWatcherBase::progressValueChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn progress_text_changed(&self) -> Signal<(*const QString,)>
pub fn progress_text_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QFutureWatcherBase::progressTextChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_cancel(&self) -> Receiver<()>
pub fn slot_cancel(&self) -> Receiver<()>
Returns a built-in Qt slot QFutureWatcherBase::cancel that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_paused(&self) -> Receiver<(bool,)>
pub fn slot_set_paused(&self) -> Receiver<(bool,)>
Returns a built-in Qt slot QFutureWatcherBase::setPaused that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_pause(&self) -> Receiver<()>
pub fn slot_pause(&self) -> Receiver<()>
Returns a built-in Qt slot QFutureWatcherBase::pause that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_resume(&self) -> Receiver<()>
pub fn slot_resume(&self) -> Receiver<()>
Returns a built-in Qt slot QFutureWatcherBase::resume that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_toggle_paused(&self) -> Receiver<()>
pub fn slot_toggle_paused(&self) -> Receiver<()>
Returns a built-in Qt slot QFutureWatcherBase::togglePaused that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QFutureWatcherBase::event(QEvent* event).
Sourcepub unsafe fn is_canceled(&self) -> bool
pub unsafe fn is_canceled(&self) -> bool
Calls C++ function: bool QFutureWatcherBase::isCanceled() const.
Sourcepub unsafe fn is_finished(&self) -> bool
pub unsafe fn is_finished(&self) -> bool
Calls C++ function: bool QFutureWatcherBase::isFinished() const.
Sourcepub unsafe fn is_paused(&self) -> bool
pub unsafe fn is_paused(&self) -> bool
Calls C++ function: bool QFutureWatcherBase::isPaused() const.
Sourcepub unsafe fn is_running(&self) -> bool
pub unsafe fn is_running(&self) -> bool
Calls C++ function: bool QFutureWatcherBase::isRunning() const.
Sourcepub unsafe fn is_started(&self) -> bool
pub unsafe fn is_started(&self) -> bool
Calls C++ function: bool QFutureWatcherBase::isStarted() const.
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QFutureWatcherBase::metaObject() const.
Sourcepub unsafe fn progress_maximum(&self) -> c_int
pub unsafe fn progress_maximum(&self) -> c_int
Calls C++ function: int QFutureWatcherBase::progressMaximum() const.
Sourcepub unsafe fn progress_minimum(&self) -> c_int
pub unsafe fn progress_minimum(&self) -> c_int
Calls C++ function: int QFutureWatcherBase::progressMinimum() const.
Sourcepub unsafe fn progress_text(&self) -> CppBox<QString>
pub unsafe fn progress_text(&self) -> CppBox<QString>
Calls C++ function: QString QFutureWatcherBase::progressText() const.
Sourcepub unsafe fn progress_value(&self) -> c_int
pub unsafe fn progress_value(&self) -> c_int
Calls C++ function: int QFutureWatcherBase::progressValue() const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QFutureWatcherBase::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QFutureWatcherBase::qt_metacast(const char* arg1).
Sourcepub unsafe fn set_paused(&self, paused: bool)
pub unsafe fn set_paused(&self, paused: bool)
Calls C++ function: [slot] void QFutureWatcherBase::setPaused(bool paused).
Sourcepub unsafe fn set_pending_results_limit(&self, limit: c_int)
pub unsafe fn set_pending_results_limit(&self, limit: c_int)
Calls C++ function: void QFutureWatcherBase::setPendingResultsLimit(int limit).
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Sourcepub unsafe fn toggle_paused(&self)
pub unsafe fn toggle_paused(&self)
Calls C++ function: [slot] void QFutureWatcherBase::togglePaused().
Sourcepub unsafe fn tr(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QFutureWatcherBase::tr(const char* s, const char* c, int n).
Sourcepub unsafe fn tr_utf8(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QFutureWatcherBase::trUtf8(const char* s, const char* c, int n).
Sourcepub unsafe fn wait_for_finished(&self)
pub unsafe fn wait_for_finished(&self)
Calls C++ function: void QFutureWatcherBase::waitForFinished().
Methods from Deref<Target = QObject>
Sourcepub unsafe fn find_child<T>(
&self,
name: &str,
) -> Result<QPtr<T>, FindChildError>
pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>
Finds a child of self with the specified object name
and casts it to type T.
The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.
Returns an error if there is no child object with object name name or
the found object cannot be cast to T.
Sourcepub fn destroyed(&self) -> Signal<(*mut QObject,)>
pub fn destroyed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.
Sourcepub fn object_name_changed(&self) -> Signal<(*const QString,)>
pub fn object_name_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_delete_later(&self) -> Receiver<()>
pub fn slot_delete_later(&self) -> Receiver<()>
Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn block_signals(&self, b: bool) -> bool
pub unsafe fn block_signals(&self, b: bool) -> bool
Calls C++ function: bool QObject::blockSignals(bool b).
Sourcepub unsafe fn children(&self) -> Ref<QListOfQObject>
pub unsafe fn children(&self) -> Ref<QListOfQObject>
Calls C++ function: const QList<QObject*>& QObject::children() const.
Sourcepub unsafe fn delete_later(&self)
pub unsafe fn delete_later(&self)
Calls C++ function: [slot] void QObject::deleteLater().
Sourcepub unsafe fn disconnect_char_q_object_char(
&self,
signal: *const c_char,
receiver: impl CastInto<Ptr<QObject>>,
member: *const c_char,
) -> bool
pub unsafe fn disconnect_char_q_object_char( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.
Sourcepub unsafe fn disconnect_q_object_char(
&self,
receiver: impl CastInto<Ptr<QObject>>,
member: *const c_char,
) -> bool
pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const c_char, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.
Sourcepub unsafe fn disconnect_char_q_object(
&self,
signal: *const c_char,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_char_q_object( &self, signal: *const c_char, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.
Sourcepub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool
pub unsafe fn disconnect_char(&self, signal: *const c_char) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …) const.
Sourcepub unsafe fn disconnect(&self) -> bool
pub unsafe fn disconnect(&self) -> bool
Calls C++ function: bool QObject::disconnect() const.
Sourcepub unsafe fn disconnect_q_object(
&self,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.
Sourcepub unsafe fn dump_object_info_mut(&self)
pub unsafe fn dump_object_info_mut(&self)
Calls C++ function: void QObject::dumpObjectInfo().
Sourcepub unsafe fn dump_object_info(&self)
pub unsafe fn dump_object_info(&self)
Calls C++ function: void QObject::dumpObjectInfo() const.
Sourcepub unsafe fn dump_object_tree_mut(&self)
pub unsafe fn dump_object_tree_mut(&self)
Calls C++ function: void QObject::dumpObjectTree().
Sourcepub unsafe fn dump_object_tree(&self)
pub unsafe fn dump_object_tree(&self)
Calls C++ function: void QObject::dumpObjectTree() const.
Sourcepub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.
Sourcepub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QObject::event(QEvent* event).
Sourcepub unsafe fn event_filter(
&self,
watched: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).
Sourcepub unsafe fn find_child_q_object_2a(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_child_q_object_1a(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_string_q_flags_find_child_option(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegExp>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_string(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp(
&self,
re: impl CastInto<Ref<QRegExp>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.
Sourcepub unsafe fn inherits(&self, classname: *const c_char) -> bool
pub unsafe fn inherits(&self, classname: *const c_char) -> bool
Calls C++ function: bool QObject::inherits(const char* classname) const.
Sourcepub unsafe fn install_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QObject>>,
)
pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )
Calls C++ function: void QObject::installEventFilter(QObject* filterObj).
Sourcepub unsafe fn is_widget_type(&self) -> bool
pub unsafe fn is_widget_type(&self) -> bool
Calls C++ function: bool QObject::isWidgetType() const.
Sourcepub unsafe fn is_window_type(&self) -> bool
pub unsafe fn is_window_type(&self) -> bool
Calls C++ function: bool QObject::isWindowType() const.
Sourcepub unsafe fn kill_timer(&self, id: c_int)
pub unsafe fn kill_timer(&self, id: c_int)
Calls C++ function: void QObject::killTimer(int id).
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.
Sourcepub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
Calls C++ function: void QObject::moveToThread(QThread* thread).
Sourcepub unsafe fn object_name(&self) -> CppBox<QString>
pub unsafe fn object_name(&self) -> CppBox<QString>
Calls C++ function: QString QObject::objectName() const.
Sourcepub unsafe fn parent(&self) -> QPtr<QObject>
pub unsafe fn parent(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::parent() const.
Sourcepub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>
pub unsafe fn property(&self, name: *const c_char) -> CppBox<QVariant>
Calls C++ function: QVariant QObject::property(const char* name) const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::removeEventFilter(QObject* obj).
Sourcepub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QObject::setObjectName(const QString& name).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::setParent(QObject* parent).
Sourcepub unsafe fn set_property(
&self,
name: *const c_char,
value: impl CastInto<Ref<QVariant>>,
) -> bool
pub unsafe fn set_property( &self, name: *const c_char, value: impl CastInto<Ref<QVariant>>, ) -> bool
Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).
Sourcepub unsafe fn signals_blocked(&self) -> bool
pub unsafe fn signals_blocked(&self) -> bool
Calls C++ function: bool QObject::signalsBlocked() const.
Sourcepub unsafe fn start_timer_2a(
&self,
interval: c_int,
timer_type: TimerType,
) -> c_int
pub unsafe fn start_timer_2a( &self, interval: c_int, timer_type: TimerType, ) -> c_int
Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).
Sourcepub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int
pub unsafe fn start_timer_1a(&self, interval: c_int) -> c_int
Calls C++ function: int QObject::startTimer(int interval).