pub struct QTime { /* private fields */ }Expand description
C++ class: QTime.
Implementations
Sourceimpl QTime
impl QTime
Sourcepub unsafe fn add_m_secs(&self, ms: c_int) -> CppBox<QTime>
pub unsafe fn add_m_secs(&self, ms: c_int) -> CppBox<QTime>
Calls C++ function: QTime QTime::addMSecs(int ms) const.
Sourcepub unsafe fn add_secs(&self, secs: c_int) -> CppBox<QTime>
pub unsafe fn add_secs(&self, secs: c_int) -> CppBox<QTime>
Calls C++ function: QTime QTime::addSecs(int secs) const.
Sourcepub unsafe fn copy_from(&self, other: impl CastInto<Ref<QTime>>) -> Ref<QTime>
pub unsafe fn copy_from(&self, other: impl CastInto<Ref<QTime>>) -> Ref<QTime>
Calls C++ function: QTime& QTime::operator=(const QTime& other).
Sourcepub unsafe fn current_time() -> CppBox<QTime>
pub unsafe fn current_time() -> CppBox<QTime>
Calls C++ function: static QTime QTime::currentTime().
Sourcepub unsafe fn from_m_secs_since_start_of_day(msecs: c_int) -> CppBox<QTime>
pub unsafe fn from_m_secs_since_start_of_day(msecs: c_int) -> CppBox<QTime>
Calls C++ function: static QTime QTime::fromMSecsSinceStartOfDay(int msecs).
Sourcepub unsafe fn from_string_q_string_date_format(
s: impl CastInto<Ref<QString>>,
f: DateFormat,
) -> CppBox<QTime>
pub unsafe fn from_string_q_string_date_format( s: impl CastInto<Ref<QString>>, f: DateFormat, ) -> CppBox<QTime>
Calls C++ function: static QTime QTime::fromString(const QString& s, Qt::DateFormat f = …).
Sourcepub unsafe fn from_string_2_q_string(
s: impl CastInto<Ref<QString>>,
format: impl CastInto<Ref<QString>>,
) -> CppBox<QTime>
pub unsafe fn from_string_2_q_string( s: impl CastInto<Ref<QString>>, format: impl CastInto<Ref<QString>>, ) -> CppBox<QTime>
Calls C++ function: static QTime QTime::fromString(const QString& s, const QString& format).
Sourcepub unsafe fn from_string_q_string(
s: impl CastInto<Ref<QString>>,
) -> CppBox<QTime>
pub unsafe fn from_string_q_string( s: impl CastInto<Ref<QString>>, ) -> CppBox<QTime>
Calls C++ function: static QTime QTime::fromString(const QString& s).
Sourcepub unsafe fn is_valid_0a(&self) -> bool
pub unsafe fn is_valid_0a(&self) -> bool
Calls C++ function: bool QTime::isValid() const.
Sourcepub unsafe fn is_valid_4a(h: c_int, m: c_int, s: c_int, ms: c_int) -> bool
pub unsafe fn is_valid_4a(h: c_int, m: c_int, s: c_int, ms: c_int) -> bool
Calls C++ function: static bool QTime::isValid(int h, int m, int s, int ms = …).
Sourcepub unsafe fn is_valid_3a(h: c_int, m: c_int, s: c_int) -> bool
pub unsafe fn is_valid_3a(h: c_int, m: c_int, s: c_int) -> bool
Calls C++ function: static bool QTime::isValid(int h, int m, int s).
Sourcepub unsafe fn msecs_since_start_of_day(&self) -> c_int
pub unsafe fn msecs_since_start_of_day(&self) -> c_int
Calls C++ function: int QTime::msecsSinceStartOfDay() const.
Sourcepub unsafe fn msecs_to(&self, arg1: impl CastInto<Ref<QTime>>) -> c_int
pub unsafe fn msecs_to(&self, arg1: impl CastInto<Ref<QTime>>) -> c_int
Calls C++ function: int QTime::msecsTo(const QTime& arg1) const.
Sourcepub unsafe fn new_4a(h: c_int, m: c_int, s: c_int, ms: c_int) -> CppBox<QTime>
pub unsafe fn new_4a(h: c_int, m: c_int, s: c_int, ms: c_int) -> CppBox<QTime>
Calls C++ function: [constructor] void QTime::QTime(int h, int m, int s = …, int ms = …).
Sourcepub unsafe fn new_3a(h: c_int, m: c_int, s: c_int) -> CppBox<QTime>
pub unsafe fn new_3a(h: c_int, m: c_int, s: c_int) -> CppBox<QTime>
Calls C++ function: [constructor] void QTime::QTime(int h, int m, int s = …).
Sourcepub unsafe fn new_2a(h: c_int, m: c_int) -> CppBox<QTime>
pub unsafe fn new_2a(h: c_int, m: c_int) -> CppBox<QTime>
Calls C++ function: [constructor] void QTime::QTime(int h, int m).
Sourcepub unsafe fn new_copy(other: impl CastInto<Ref<QTime>>) -> CppBox<QTime>
pub unsafe fn new_copy(other: impl CastInto<Ref<QTime>>) -> CppBox<QTime>
Calls C++ function: [constructor] void QTime::QTime(const QTime& other).
Sourcepub unsafe fn secs_to(&self, arg1: impl CastInto<Ref<QTime>>) -> c_int
pub unsafe fn secs_to(&self, arg1: impl CastInto<Ref<QTime>>) -> c_int
Calls C++ function: int QTime::secsTo(const QTime& arg1) const.
Sourcepub unsafe fn set_h_m_s_4a(
&self,
h: c_int,
m: c_int,
s: c_int,
ms: c_int,
) -> bool
pub unsafe fn set_h_m_s_4a( &self, h: c_int, m: c_int, s: c_int, ms: c_int, ) -> bool
Calls C++ function: bool QTime::setHMS(int h, int m, int s, int ms = …).
Sourcepub unsafe fn set_h_m_s_3a(&self, h: c_int, m: c_int, s: c_int) -> bool
pub unsafe fn set_h_m_s_3a(&self, h: c_int, m: c_int, s: c_int) -> bool
Calls C++ function: bool QTime::setHMS(int h, int m, int s).
Sourcepub unsafe fn to_string_date_format(&self, f: DateFormat) -> CppBox<QString>
pub unsafe fn to_string_date_format(&self, f: DateFormat) -> CppBox<QString>
Calls C++ function: QString QTime::toString(Qt::DateFormat f = …) const.
Sourcepub unsafe fn to_string_q_string(
&self,
format: impl CastInto<Ref<QString>>,
) -> CppBox<QString>
pub unsafe fn to_string_q_string( &self, format: impl CastInto<Ref<QString>>, ) -> CppBox<QString>
Calls C++ function: QString QTime::toString(const QString& format) const.
Sourcepub unsafe fn to_string_q_string_view(
&self,
format: impl CastInto<Ref<QStringView>>,
) -> CppBox<QString>
pub unsafe fn to_string_q_string_view( &self, format: impl CastInto<Ref<QStringView>>, ) -> CppBox<QString>
Calls C++ function: QString QTime::toString(QStringView format) const.